@@ -13,22 +13,22 @@ namespace CppUnit {
 // Deletes all tests in the suite.
 void TestSuite::deleteContents()
 {
-	for (std::vector<Test*>::iterator it = _tests.begin(); it != _tests.end(); ++it)
-		delete *it;
+	for (auto* _test : _tests)
+		delete _test;
 }
 
 
 // Runs the tests and collects their result in a TestResult.
 void TestSuite::run(TestResult *result, const Test::Callback& callback)
 {
-	for (std::vector<Test*>::iterator it = _tests.begin(); it != _tests.end(); ++it)
+	for (auto* test : _tests)
 	{
 		if (result->shouldStop())
 			break;
 
-		Test *test = *it;
 		if (!setup().empty())
 			test->addSetup(setup());
+
 		test->run(result, callback);
 	}
 }
@@ -39,8 +39,8 @@ int TestSuite::countTestCases() const
 {
 	int count = 0;
 
-	for (std::vector<Test*>::const_iterator it = _tests.begin(); it != _tests.end(); ++it)
-		count += (*it)->countTestCases();
+	for (auto* _test : _tests)
+		count += _test->countTestCases();
 
 	return count;
 }
