@@ -20,10 +20,6 @@
 #define Crypto_Crypto_INCLUDED
 
 
-#define POCO_EXTERNAL_OPENSSL_DEFAULT 1
-#define POCO_EXTERNAL_OPENSSL_SLPRO 2
-
-
 //
 // Temporarily suppress deprecation warnings coming
 // from OpenSSL 3.0, until we have updated our code.
@@ -104,70 +100,6 @@ enum RSAPaddingMode
 //
 #if defined(_MSC_VER)
 	#if !defined(POCO_NO_AUTOMATIC_LIBS)
-		#if defined(POCO_INTERNAL_OPENSSL_MSVC_VER)
-			#if defined(POCO_EXTERNAL_OPENSSL)
-				#pragma message("External OpenSSL defined but internal headers used - possible mismatch!")
-			#endif // POCO_EXTERNAL_OPENSSL
-			#if !defined(_DEBUG)
-				#define POCO_DEBUG_SUFFIX ""
-				#if !defined (_DLL)
-					#define POCO_STATIC_SUFFIX "mt"
-				#else // _DLL
-					#define POCO_STATIC_SUFFIX ""
-				#endif
-			#else // _DEBUG
-				#define POCO_DEBUG_SUFFIX "d"
-				#if !defined (_DLL)
-					#define POCO_STATIC_SUFFIX "mt"
-				#else // _DLL
-					#define POCO_STATIC_SUFFIX ""
-				#endif
-			#endif
-			#pragma comment(lib, "libcrypto" POCO_STATIC_SUFFIX POCO_DEBUG_SUFFIX ".lib")
-			#pragma comment(lib, "libssl" POCO_STATIC_SUFFIX POCO_DEBUG_SUFFIX ".lib")
-			#if !defined(_WIN64) && !defined (_DLL) && \
-						(POCO_INTERNAL_OPENSSL_MSVC_VER == 120) && \
-						(POCO_MSVC_VERSION < POCO_INTERNAL_OPENSSL_MSVC_VER)
-				#pragma comment(lib, "libPreVS2013CRT" POCO_STATIC_SUFFIX POCO_DEBUG_SUFFIX ".lib")
-			#endif
-			#if !defined (_DLL) && (POCO_MSVS_VERSION >= 2015)
-				#pragma comment(lib, "legacy_stdio_definitions.lib")
-				#pragma comment(lib, "legacy_stdio_wide_specifiers.lib")
-			#endif
-		#elif defined(POCO_EXTERNAL_OPENSSL)
-			#if POCO_EXTERNAL_OPENSSL == POCO_EXTERNAL_OPENSSL_SLPRO
-				#if defined(POCO_DLL)
-					#if OPENSSL_VERSION_PREREQ(1,1)
-						#pragma comment(lib, "libcrypto.lib")
-						#pragma comment(lib, "libssl.lib")
-					#else
-						#pragma comment(lib, "libeay32.lib")
-						#pragma comment(lib, "ssleay32.lib")
-					#endif
-			  	#else
-					#if OPENSSL_VERSION_PREREQ(1,1)
-						#if defined(_WIN64)
-							#pragma comment(lib, "libcrypto64" POCO_LIB_SUFFIX)
-							#pragma comment(lib, "libssl64" POCO_LIB_SUFFIX)
-						#else
-							#pragma comment(lib, "libcrypto32" POCO_LIB_SUFFIX)
-							#pragma comment(lib, "libssl32" POCO_LIB_SUFFIX)
-						#endif
-					#else
-						#pragma comment(lib, "libeay32" POCO_LIB_SUFFIX)
-						#pragma comment(lib, "ssleay32" POCO_LIB_SUFFIX)
-					#endif
-				#endif
-			#elif POCO_EXTERNAL_OPENSSL == POCO_EXTERNAL_OPENSSL_DEFAULT
-				#if OPENSSL_VERSION_PREREQ(1,1)
-					#pragma comment(lib, "libcrypto.lib")
-					#pragma comment(lib, "libssl.lib")
-				#else
-					#pragma comment(lib, "libeay32.lib")
-					#pragma comment(lib, "ssleay32.lib")
-				#endif
-			#endif
-		#endif // POCO_INTERNAL_OPENSSL_MSVC_VER
 		#if !defined(Crypto_EXPORTS)
 			#pragma comment(lib, "PocoCrypto" POCO_LIB_SUFFIX)
 		#endif
