@@ -25,11 +25,15 @@ public:
 	ECTest(const std::string& name);
 	~ECTest();
 
+#if defined(POCO_TEST_DEPRECATED)
+
 	void testECNewKeys();
 	void testECNewKeysNoPassphrase();
 	void testECDSASignSha256();
 	void testECDSASignManipulated();
 
+#endif
+
 	void setUp();
 	void tearDown();
 
