@@ -34,6 +34,17 @@ public:
 	void testECEVPSaveLoadFile();
 	void testECEVPSaveLoadFileNoPass();
 
+	void testRSAEVPKeyFromX509();
+	void testRSAEVPKeyFromPKCS12();
+
+#if OPENSSL_VERSION_NUMBER >= 0x10000000L
+	void testRSAEVPKeyByLength();
+#if OPENSSL_VERSION_NUMBER >= 0x30000000L
+	void testECEVPKeyByLength();
+	void testEVPKeyByModulus();
+#endif // OPENSSL_VERSION_NUMBER >= 0x30000000L
+#endif // OPENSSL_VERSION_NUMBER >= 0x10000000L
+
 	void setUp();
 	void tearDown();
 
@@ -43,4 +54,4 @@ private:
 };
 
 
-#endif // EVPTest_INCLUDED
\ No newline at end of file
+#endif // EVPTest_INCLUDED
