@@ -108,6 +108,7 @@ bool Extractor::extractBoundImpl<Poco::Data::Date>(std::size_t pos, Poco::Data::
 }
 
 
+
 template<>
 bool Extractor::extractBoundImplContainer<std::vector<Poco::Data::Date> >(std::size_t pos,
 	std::vector<Poco::Data::Date>& val)
@@ -277,12 +278,9 @@ template<>
 bool Extractor::extractManualImpl<std::string>(std::size_t pos, std::string& val, SQLSMALLINT cType)
 {
 	std::size_t maxSize = _pPreparator->getMaxFieldSize();
-	std::size_t fetchedSize = 0;
-	std::size_t totalSize = 0;
 
 	SQLLEN len;
-	const int bufSize = CHUNK_SIZE;
-	Poco::Buffer<char> apChar(bufSize);
+	Poco::Buffer<char> apChar(CHUNK_SIZE);
 	char* pChar = apChar.begin();
 	SQLRETURN rc = 0;
 
@@ -291,15 +289,29 @@ bool Extractor::extractManualImpl<std::string>(std::size_t pos, std::string& val
 
 	do
 	{
-		std::memset(pChar, 0, bufSize);
+		std::memset(pChar, 0, CHUNK_SIZE);
 		len = 0;
 		rc = SQLGetData(_rStmt,
 			(SQLUSMALLINT) pos + 1,
 			cType, //C data type
 			pChar, //returned value
-			bufSize, //buffer length
+			CHUNK_SIZE, //buffer length
 			&len); //length indicator
 
+		if (SQL_SUCCESS_WITH_INFO == rc)
+		{
+			StatementDiagnostics d(_rStmt);
+			std::size_t fieldCount = d.fields().size();
+			for (int i = 0; i < fieldCount; ++i)
+			{
+				if (d.sqlState(i) == "01004"s)
+				{
+					if (len == SQL_NO_TOTAL || len > CHUNK_SIZE) // only part of data was returned
+						len = CHUNK_SIZE-1; // SQLGetData terminates the returned string
+				}
+			}
+		}
+
 		if (SQL_NO_DATA != rc && Utility::isError(rc))
 			throw StatementException(_rStmt, "ODBC::Extractor::extractManualImpl(string):SQLGetData()");
 
@@ -316,12 +328,11 @@ bool Extractor::extractManualImpl<std::string>(std::size_t pos, std::string& val
 			break;
 
 		_lengths[pos] += len;
-		fetchedSize = _lengths[pos] > CHUNK_SIZE ? CHUNK_SIZE : _lengths[pos];
-		totalSize += fetchedSize;
-		if (totalSize <= maxSize)
-			val.append(pChar, fetchedSize);
+		if (_lengths[pos] <= maxSize)
+			val.append(pChar, len);
 		else
-			throw DataException(format(FLD_SIZE_EXCEEDED_FMT, fetchedSize, maxSize));
+			throw DataException(format(FLD_SIZE_EXCEEDED_FMT, static_cast<std::size_t>(_lengths[pos]), maxSize));
+
 	}while (true);
 
 	return true;
@@ -332,12 +343,8 @@ template<>
 bool Extractor::extractManualImpl<UTF16String>(std::size_t pos, UTF16String& val, SQLSMALLINT cType)
 {
 	std::size_t maxSize = _pPreparator->getMaxFieldSize();
-	std::size_t fetchedSize = 0;
-	std::size_t totalSize = 0;
-
 	SQLLEN len;
-	const int bufSize = CHUNK_SIZE;
-	Poco::Buffer<UTF16String::value_type> apChar(bufSize);
+	Poco::Buffer<UTF16String::value_type> apChar(CHUNK_SIZE);
 	UTF16String::value_type* pChar = apChar.begin();
 	SQLRETURN rc = 0;
 
@@ -346,15 +353,29 @@ bool Extractor::extractManualImpl<UTF16String>(std::size_t pos, UTF16String& val
 
 	do
 	{
-		std::memset(pChar, 0, bufSize);
+		std::memset(pChar, 0, CHUNK_SIZE);
 		len = 0;
 		rc = SQLGetData(_rStmt,
 			(SQLUSMALLINT)pos + 1,
 			cType, //C data type
 			pChar, //returned value
-			bufSize, //buffer length
+			CHUNK_SIZE, //buffer length
 			&len); //length indicator
 
+		if (SQL_SUCCESS_WITH_INFO == rc)
+		{
+			StatementDiagnostics d(_rStmt);
+			std::size_t fieldCount = d.fields().size();
+			for (int i = 0; i < fieldCount; ++i)
+			{
+				if (d.sqlState(i) == "01004"s)
+				{
+					if (len == SQL_NO_TOTAL || len > CHUNK_SIZE) // only part of data was returned
+						len = CHUNK_SIZE - 2;
+				}
+			}
+		}
+
 		if (SQL_NO_DATA != rc && Utility::isError(rc))
 			throw StatementException(_rStmt, "ODBC::Extractor::extractManualImpl(UTF16String):SQLGetData()");
 
@@ -371,12 +392,10 @@ bool Extractor::extractManualImpl<UTF16String>(std::size_t pos, UTF16String& val
 			break;
 
 		_lengths[pos] += len;
-		fetchedSize = _lengths[pos] > CHUNK_SIZE ? CHUNK_SIZE : _lengths[pos];
-		totalSize += fetchedSize;
-		if (totalSize <= maxSize)
-			val.append(pChar, fetchedSize / sizeof(UTF16Char));
+		if (_lengths[pos] <= maxSize)
+			val.append(pChar, len / sizeof(UTF16Char));
 		else
-			throw DataException(format(FLD_SIZE_EXCEEDED_FMT, fetchedSize, maxSize));
+			throw DataException(format(FLD_SIZE_EXCEEDED_FMT, static_cast<std::size_t>(_lengths[pos]), maxSize));
 	} while (true);
 
 	return true;
@@ -390,7 +409,6 @@ bool Extractor::extractManualImpl<Poco::Data::CLOB>(std::size_t pos,
 {
 	std::size_t maxSize = _pPreparator->getMaxFieldSize();
 	std::size_t fetchedSize = 0;
-	std::size_t totalSize = 0;
 
 	SQLLEN len;
 	const int bufSize = CHUNK_SIZE;
@@ -406,14 +424,12 @@ bool Extractor::extractManualImpl<Poco::Data::CLOB>(std::size_t pos,
 		std::memset(pChar, 0, bufSize);
 		len = 0;
 		rc = SQLGetData(_rStmt,
-			(SQLUSMALLINT) pos + 1,
+			(SQLUSMALLINT)pos + 1,
 			cType, //C data type
 			pChar, //returned value
 			bufSize, //buffer length
 			&len); //length indicator
 
-		_lengths[pos] += len;
-
 		if (SQL_NO_DATA != rc && Utility::isError(rc))
 			throw StatementException(_rStmt, "ODBC::Extractor::extractManualImpl(CLOB):SQLGetData()");
 
@@ -427,13 +443,13 @@ bool Extractor::extractManualImpl<Poco::Data::CLOB>(std::size_t pos,
 			break;
 
 		fetchedSize = len > CHUNK_SIZE ? CHUNK_SIZE : len;
-		totalSize += fetchedSize;
-		if (totalSize <= maxSize)
+		_lengths[pos] += fetchedSize;
+		if (_lengths[pos] <= maxSize)
 			val.appendRaw(pChar, fetchedSize);
 		else
 			throw DataException(format(FLD_SIZE_EXCEEDED_FMT, fetchedSize, maxSize));
 
-	}while (true);
+	} while (true);
 
 	return true;
 }
@@ -663,7 +679,34 @@ bool Extractor::extract(std::size_t pos, std::list<long>& val)
 	else
 		throw InvalidAccessException("Direct container extraction only allowed for bound mode.");
 }
-#endif
+
+
+bool Extractor::extract(std::size_t pos, std::vector<unsigned long>& val)
+{
+	if (Preparator::DE_BOUND == _dataExtraction)
+		return extractBoundImplContainer(pos, val);
+	else
+		throw InvalidAccessException("Direct container extraction only allowed for bound mode.");
+}
+
+
+bool Extractor::extract(std::size_t pos, std::deque<unsigned long>& val)
+{
+	if (Preparator::DE_BOUND == _dataExtraction)
+		return extractBoundImplContainer(pos, val);
+	else
+		throw InvalidAccessException("Direct container extraction only allowed for bound mode.");
+}
+
+
+bool Extractor::extract(std::size_t pos, std::list<unsigned long>& val)
+{
+	if (Preparator::DE_BOUND == _dataExtraction)
+		return extractBoundImplContainer(pos, val);
+	else
+		throw InvalidAccessException("Direct container extraction only allowed for bound mode.");
+}
+#endif // POCO_INT64_IS_LONG
 
 
 bool Extractor::extract(std::size_t pos, double& val)
@@ -721,7 +764,7 @@ bool Extractor::extract(std::size_t pos, std::string& val)
 		else
 			ret = extractBoundImpl(pos, result);
 		transcode(result, val);
-		
+
 	}
 
 	return ret;
@@ -1328,13 +1371,13 @@ bool Extractor::extract(std::size_t pos, std::list<Poco::Any>& val)
 }
 
 
-bool Extractor::extract(std::size_t pos, Poco::DynamicAny& val)
+bool Extractor::extract(std::size_t pos, Poco::Dynamic::Var& val)
 {
 	return extractImpl(pos, val);
 }
 
 
-bool Extractor::extract(std::size_t pos, std::vector<Poco::DynamicAny>& val)
+bool Extractor::extract(std::size_t pos, std::vector<Poco::Dynamic::Var>& val)
 {
 	if (Preparator::DE_BOUND == _dataExtraction)
 		return extractBoundImpl(pos, val);
@@ -1343,7 +1386,7 @@ bool Extractor::extract(std::size_t pos, std::vector<Poco::DynamicAny>& val)
 }
 
 
-bool Extractor::extract(std::size_t pos, std::deque<Poco::DynamicAny>& val)
+bool Extractor::extract(std::size_t pos, std::deque<Poco::Dynamic::Var>& val)
 {
 	if (Preparator::DE_BOUND == _dataExtraction)
 		return extractBoundImpl(pos, val);
@@ -1352,7 +1395,7 @@ bool Extractor::extract(std::size_t pos, std::deque<Poco::DynamicAny>& val)
 }
 
 
-bool Extractor::extract(std::size_t pos, std::list<Poco::DynamicAny>& val)
+bool Extractor::extract(std::size_t pos, std::list<Poco::Dynamic::Var>& val)
 {
 	if (Preparator::DE_BOUND == _dataExtraction)
 		return extractBoundImpl(pos, val);
@@ -1361,6 +1404,151 @@ bool Extractor::extract(std::size_t pos, std::list<Poco::DynamicAny>& val)
 }
 
 
+bool Extractor::extract(std::size_t pos, Poco::Nullable<Poco::Int8>& val)
+{
+	return extractNullable(pos, val);
+}
+
+
+bool Extractor::extract(std::size_t pos, Poco::Nullable<Poco::UInt8>& val)
+{
+	return extractNullable(pos, val);
+}
+
+
+bool Extractor::extract(std::size_t pos, Poco::Nullable<Poco::Int16>& val)
+{
+	return extractNullable(pos, val);
+}
+
+
+bool Extractor::extract(std::size_t pos, Poco::Nullable<Poco::UInt16>& val)
+{
+	return extractNullable(pos, val);
+}
+
+
+bool Extractor::extract(std::size_t pos, Poco::Nullable<Poco::Int32>& val)
+{
+	return extractNullable(pos, val);
+}
+
+
+bool Extractor::extract(std::size_t pos, Poco::Nullable<Poco::UInt32>& val)
+{
+	return extractNullable(pos, val);
+}
+
+
+bool Extractor::extract(std::size_t pos, Poco::Nullable<Poco::Int64>& val)
+{
+	return extractNullable(pos, val);
+}
+
+
+bool Extractor::extract(std::size_t pos, Poco::Nullable<Poco::UInt64>& val)
+{
+	return extractNullable(pos, val);
+}
+
+
+#ifndef POCO_INT64_IS_LONG
+bool Extractor::extract(std::size_t pos, Poco::Nullable<long>& val)
+{
+	return extractNullable(pos, val);
+}
+
+
+bool Extractor::extract(std::size_t pos, Poco::Nullable<unsigned long>& val)
+{
+	return extractNullable(pos, val);
+}
+#endif
+
+bool Extractor::extract(std::size_t pos, Poco::Nullable<bool>& val)
+{
+	return extractNullable(pos, val);
+}
+
+
+bool Extractor::extract(std::size_t pos, Poco::Nullable<float>& val)
+{
+	return extractNullable(pos, val);
+}
+
+
+bool Extractor::extract(std::size_t pos, Poco::Nullable<double>& val)
+{
+	return extractNullable(pos, val);
+}
+
+
+bool Extractor::extract(std::size_t pos, Poco::Nullable<char>& val)
+{
+	return extractNullable(pos, val);
+}
+
+
+bool Extractor::extract(std::size_t pos, Poco::Nullable<std::string>& val)
+{
+	return extractNullable(pos, val);
+}
+
+
+bool Extractor::extract(std::size_t pos, Poco::Nullable<UTF16String>& val)
+{
+	return extractNullable(pos, val);
+}
+
+
+bool Extractor::extract(std::size_t pos, Poco::Nullable<BLOB>& val)
+{
+	return extractNullable(pos, val);
+}
+
+
+bool Extractor::extract(std::size_t pos, Poco::Nullable<CLOB>& val)
+{
+	return extractNullable(pos, val);
+}
+
+
+bool Extractor::extract(std::size_t pos, Poco::Nullable<DateTime>& val)
+{
+	return extractNullable(pos, val);
+}
+
+
+bool Extractor::extract(std::size_t pos, Poco::Nullable<Date>& val)
+{
+	return extractNullable(pos, val);
+}
+
+
+bool Extractor::extract(std::size_t pos, Poco::Nullable<Time>& val)
+{
+	return extractNullable(pos, val);
+}
+
+
+bool Extractor::extract(std::size_t pos, Poco::Nullable<UUID>& val)
+{
+	return extractNullable(pos, val);
+}
+
+
+bool Extractor::extract(std::size_t pos, Poco::Nullable<Any>& val)
+{
+	return extractNullable(pos, val);
+}
+
+
+bool Extractor::extract(std::size_t pos, Poco::Nullable<Poco::Dynamic::Var>& val)
+{
+	return extractNullable(pos, val);
+}
+
+
 bool Extractor::isNull(std::size_t col, std::size_t row)
 {
 	if (Preparator::DE_MANUAL == _dataExtraction)
