@@ -167,7 +167,7 @@ void TypeInfo::fillTypeInfo(const SQLHDBC* pHDBC)
 }
 
 
-DynamicAny TypeInfo::getInfo(SQLSMALLINT type, const std::string& param) const
+Dynamic::Var TypeInfo::getInfo(SQLSMALLINT type, const std::string& param) const
 {
 	TypeInfoVec::const_iterator it = _typeInfo.begin();
 	TypeInfoVec::const_iterator end = _typeInfo.end();
@@ -181,7 +181,7 @@ DynamicAny TypeInfo::getInfo(SQLSMALLINT type, const std::string& param) const
 }
 
 
-bool TypeInfo::tryGetInfo(SQLSMALLINT type, const std::string& param, DynamicAny& result) const
+bool TypeInfo::tryGetInfo(SQLSMALLINT type, const std::string& param, Dynamic::Var& result) const
 {
 	TypeInfoVec::const_iterator it = _typeInfo.begin();
 	TypeInfoVec::const_iterator end = _typeInfo.end();
@@ -198,7 +198,7 @@ bool TypeInfo::tryGetInfo(SQLSMALLINT type, const std::string& param, DynamicAny
 }
 
 
-int TypeInfo::cDataType(int sqlDataType) const
+SQLSMALLINT TypeInfo::cDataType(SQLSMALLINT sqlDataType) const
 {
 	DataTypeMap::const_iterator it = _cDataTypes.find(sqlDataType);
 
@@ -209,7 +209,7 @@ int TypeInfo::cDataType(int sqlDataType) const
 }
 
 
-int TypeInfo::sqlDataType(int cDataType) const
+SQLSMALLINT TypeInfo::sqlDataType(SQLSMALLINT cDataType) const
 {
 	DataTypeMap::const_iterator it = _sqlDataTypes.find(cDataType);
 
