@@ -36,7 +36,6 @@ const std::string SessionHandle::POSTGRESQL_SERIALIZABLE	= "SERIALIZABLE";
 SessionHandle::SessionHandle():
 	_pConnection(0),
 	_inTransaction(false),
-	_isAutoCommit(true),
 	_isAsynchronousCommit(false),
 	_tranactionIsolationLevel(Session::TRANSACTION_READ_COMMITTED)
 {
@@ -83,12 +82,24 @@ void SessionHandle::connect(const std::string& aConnectionString)
 	{
 		throw ConnectionFailedException("Already Connected");
 	}
+	else if (_pConnection)
+	{
+		// free bad connection
+		PQfinish(_pConnection);
+		_pConnection = 0;
+	}
 
 	_pConnection = PQconnectdb(aConnectionString.c_str());
 
 	if (!isConnectedNoLock())
 	{
-		throw ConnectionFailedException(std::string("Connection Error: ") + lastErrorNoLock());
+		std::string msg = std::string("Connection Error: ") + lastErrorNoLock();
+		if (_pConnection)
+		{
+			PQfinish(_pConnection);
+			_pConnection = 0;
+		}
+		throw ConnectionFailedException(msg);
 	}
 
 	_connectionString = aConnectionString;
@@ -137,7 +148,7 @@ void SessionHandle::disconnect()
 {
 	Poco::FastMutex::ScopedLock mutexLocker(_sessionMutex);
 
-	if (isConnectedNoLock())
+	if (_pConnection)
 	{
 		PQfinish(_pConnection);
 
@@ -145,7 +156,6 @@ void SessionHandle::disconnect()
 
 		_connectionString = std::string();
 		_inTransaction= false;
-		_isAutoCommit = true;
 		_isAsynchronousCommit = false;
 		_tranactionIsolationLevel = Session::TRANSACTION_READ_COMMITTED;
 	}
@@ -268,23 +278,13 @@ void SessionHandle::rollback()
 }
 
 
-void SessionHandle::setAutoCommit(bool aShouldAutoCommit)
+void SessionHandle::autoCommit(bool val)
 {
-	if (aShouldAutoCommit == _isAutoCommit)
+	// There is no PostgreSQL API call to switch autocommit (unchained) mode off.
+	if (isTransaction())
 	{
-		return;
+		throw Poco::InvalidAccessException();
 	}
-
-	if (aShouldAutoCommit)
-	{
-		commit();  // end any in process transaction
-	}
-	else
-	{
-		startTransaction();  // start a new transaction
-	}
-
-	_isAutoCommit = aShouldAutoCommit;
 }
 
 
@@ -376,7 +376,7 @@ void SessionHandle::setTransactionIsolation(Poco::UInt32 aTI)
 }
 
 
-Poco::UInt32 SessionHandle::transactionIsolation()
+Poco::UInt32 SessionHandle::transactionIsolation() const
 {
 	return _tranactionIsolationLevel;
 }
@@ -493,6 +493,23 @@ std::string SessionHandle::clientEncoding() const
 }
 
 
+std::string SessionHandle::parameterStatus(const std::string& param) const
+{
+	Poco::FastMutex::ScopedLock mutexLocker(_sessionMutex);
+
+	if (!isConnectedNoLock())
+	{
+		throw NotConnectedException();
+	}
+
+	const char* pValue = PQparameterStatus(_pConnection, param.c_str());
+	if (pValue)
+		return std::string(pValue);
+	else
+		return std::string();
+}
+
+
 int SessionHandle::libpqVersion() const
 {
 	return PQlibVersion();
