@@ -151,18 +151,11 @@ void PostgreSQLTest::testFailedConnect()
 
 	try
 	{
-		std::cout << "Attempting to Connect to [" << dbConnString << "] with invalid credentials: " << std::endl;
 		Session session(PostgreSQL::Connector::KEY, dbConnString);
-		fail ("must fail");
-	}
-	catch (ConnectionFailedException& ex)
-	{
-		std::cout  << ex.displayText() << std::endl;
-	}
-	catch (ConnectionException& ex)
-	{
-		std::cout << ex.displayText() << std::endl;
+		failmsg ("must fail");
 	}
+	catch (ConnectionFailedException& ex) {}
+	catch (ConnectionException& ex) {}
 }
 
 
@@ -171,75 +164,75 @@ void PostgreSQLTest::testPostgreSQLOIDs()
 	if (!_pSession) fail ("Test not available.");
 
 	std::string tableCreateString = "CREATE TABLE Test ("
-		"charcol			char,"
-		"bigintcol          bigint,"
-		"int8col            int8,"
-		"bigserialcol       bigserial,"
-		"serial8col         serial8,"
-		"bit1col			bit(1),"
-		"bit4col			bit(4),"
-		"bit6col			bit(6),"
-		"bit8col			bit(8),"
-		"bit9col			bit(9),"
-		"bitv1col			bit varying(1),"
-		"bitv4col			bit varying(4),"
-		"bitv6col			bit varying(6),"
-		"bitv8col			bit varying(8),"
-		"bitv9col			bit varying(9),"
-		"booleancol			boolean,"
-		"boolcol			bool,"
-		"boxcol				box,"
-		"byteacol			bytea,"
-		"char1col			char(1),"
-		"char4col			char(4),"
-		"char6col			char(6),"
-		"char8col			char(8),"
-		"char9col			char(9),"
-		"char12col			char(12),"
-		"char256col			char(256),"
-		"charv1col			char varying(1),"
-		"charv4col			char varying(4),"
-		"charv6col			char varying(6),"
-		"charv8col			char varying(8),"
-		"charv9col			char varying(9),"
-		"charv12col			char varying(12),"
-		"charv256col		char varying(256),"
-		"cidrcol			cidr,"
-		"circlecol			circle,"
-		"datecol			date,"
-		"doubleprecol		double precision,"
-		"float8col			float8,"
-		"inetcol			inet,"
-		"integercol			integer,"
-		"intcol				int,"
-		"int4col			int4,"
-		"jsoncol			json,"
-//		"jsonbcol			jsonb,"  // requires 9.4
-		"linecol			line,"
-		"lsegcol			lseg,"
-		"macaddrcol			macaddr,"
-		"moneycol			money,"
-		"numericcol			numeric(12,3),"
-		"decimalcol			decimal(12,4),"
-		"pathcol			path,"
-//		"pglencol			pg_lsn,"  // requires 9.4
-		"pointcol			point,"
-		"polygoncol			polygon,"
-		"realcol			real,"
-		"float4col			float4,"
-		"smallintcol		smallint,"
-		"int2col			int2,"
-		"smallserialcol		smallserial,"
-		"serial2col			serial2,"
-		"serialcol			serial,"
-		"serial4col			serial4,"
-		"textcol			text,"
-		"timewtzcol			time(6) without time zone,"
-		"tsquerycol			tsquery,"
-		"tsvectorcol		tsvector,"
-		"txidsnapshotcol	txid_snapshot,"
-		"uuidcol			uuid,"
-		"xmlcol				xml"
+		"charcol         char,"
+		"bigintcol       bigint,"
+		"int8col         int8,"
+		"bigserialcol    bigserial,"
+		"serial8col      serial8,"
+		"bit1col         bit(1),"
+		"bit4col         bit(4),"
+		"bit6col         bit(6),"
+		"bit8col         bit(8),"
+		"bit9col         bit(9),"
+		"bitv1col        bit varying(1),"
+		"bitv4col        bit varying(4),"
+		"bitv6col        bit varying(6),"
+		"bitv8col        bit varying(8),"
+		"bitv9col        bit varying(9),"
+		"booleancol      boolean,"
+		"boolcol         bool,"
+		"boxcol          box,"
+		"byteacol        bytea,"
+		"char1col        char(1),"
+		"char4col        char(4),"
+		"char6col        char(6),"
+		"char8col        char(8),"
+		"char9col        char(9),"
+		"char12col       char(12),"
+		"char256col      char(256),"
+		"charv1col       char varying(1),"
+		"charv4col       char varying(4),"
+		"charv6col       char varying(6),"
+		"charv8col       char varying(8),"
+		"charv9col       char varying(9),"
+		"charv12col      char varying(12),"
+		"charv256col     char varying(256),"
+		"cidrcol         cidr,"
+		"circlecol       circle,"
+		"datecol         date,"
+		"doubleprecol    double precision,"
+		"float8col       float8,"
+		"inetcol         inet,"
+		"integercol      integer,"
+		"intcol          int,"
+		"int4col         int4,"
+		"jsoncol         json,"
+//		"jsonbcol        jsonb,"  // requires 9.4
+		"linecol         line,"
+		"lsegcol         lseg,"
+		"macaddrcol      macaddr,"
+		"moneycol        money,"
+		"numericcol      numeric(12,3),"
+		"decimalcol      decimal(12,4),"
+		"pathcol         path,"
+//		"pglencol        pg_lsn,"  // requires 9.4
+		"pointcol        point,"
+		"polygoncol      polygon,"
+		"realcol         real,"
+		"float4col       float4,"
+		"smallintcol     smallint,"
+		"int2col         int2,"
+		"smallserialcol  smallserial,"
+		"serial2col      serial2,"
+		"serialcol       serial,"
+		"serial4col      serial4,"
+		"textcol         text,"
+		"timewtzcol      time(6) without time zone,"
+		"tsquerycol      tsquery,"
+		"tsvectorcol     tsvector,"
+		"txidsnapshotcol txid_snapshot,"
+		"uuidcol         uuid,"
+		"xmlcol          xml"
 		")";
 
 	Oid OIDArray[] = {
@@ -1322,7 +1315,7 @@ CppUnit::Test* PostgreSQLTest::suite()
 	CppUnit_addTest(pSuite, PostgreSQLTest, testNullableInt);
 	CppUnit_addTest(pSuite, PostgreSQLTest, testNullableString);
 	CppUnit_addTest(pSuite, PostgreSQLTest, testTupleWithNullable);
-        CppUnit_addTest(pSuite, PostgreSQLTest, testSqlState);
+		CppUnit_addTest(pSuite, PostgreSQLTest, testSqlState);
 
 	CppUnit_addTest(pSuite, PostgreSQLTest, testBinarySimpleAccess);
 	CppUnit_addTest(pSuite, PostgreSQLTest, testBinaryComplexType);
