@@ -38,29 +38,29 @@ namespace Data {
 
 
 template <class T>
-class Binding: public AbstractBinding
+class Binding final: public AbstractBinding
 	/// Binding maps a value or multiple values (see Binding specializations for STL containers as
-	/// well as type handlers) to database column(s). Values to be bound can be either mapped 
+	/// well as type handlers) to database column(s). Values to be bound can be either mapped
 	/// directly (by reference) or a copy can be created, depending on the value of the copy argument.
 	/// To pass a reference to a variable, it is recommended to pass it to the intermediate
-	/// utility function use(), which will create the proper binding. In cases when a reference 
+	/// utility function use(), which will create the proper binding. In cases when a reference
 	/// is passed to binding, the storage it refers to must be valid at the statement execution time.
 	/// To pass a copy of a variable, constant or string literal, use utility function bind().
 	/// Variables can be passed as either copies or references (i.e. using either use() or bind()).
-	/// Constants, however, can only be passed as copies. this is best achieved using bind() utility 
+	/// Constants, however, can only be passed as copies. This is best achieved using bind() utility
 	/// function. An attempt to pass a constant by reference shall result in compile-time error.
 {
 public:
-	typedef T                  ValType;
-	typedef SharedPtr<ValType> ValPtr;
-	typedef Binding<ValType>   Type;
-	typedef SharedPtr<Type>    Ptr;
+	using ValType = T;
+	using ValPtr = SharedPtr<ValType>;
+	using Type = Binding<ValType>;
+	using Ptr = SharedPtr<Type>;
 
 	explicit Binding(T& val,
-		const std::string& name = "", 
-		Direction direction = PD_IN): 
+		const std::string& name = "",
+		Direction direction = PD_IN):
 		AbstractBinding(name, direction),
-		_val(val), 
+		_val(val),
 		_bound(false)
 		/// Creates the Binding using the passed reference as bound value.
 		/// If copy is true, a copy of the value referred to is created.
@@ -98,8 +98,7 @@ public:
 	{
 		_bound = false;
 		AbstractBinder::Ptr pBinder = getBinder();
-		poco_assert_dbg (!pBinder.isNull());
-		pBinder->reset();
+		if (pBinder) pBinder->reset();
 	}
 
 private:
@@ -110,25 +109,25 @@ private:
 
 
 template <class T>
-class CopyBinding: public AbstractBinding
+class CopyBinding final: public AbstractBinding
 	/// Binding maps a value or multiple values (see Binding specializations for STL containers as
-	/// well as type handlers) to database column(s). Values to be bound can be either mapped 
+	/// well as type handlers) to database column(s). Values to be bound can be either mapped
 	/// directly (by reference) or a copy can be created, depending on the value of the copy argument.
 	/// To pass a reference to a variable, it is recommended to pass it to the intermediate
-	/// utility function use(), which will create the proper binding. In cases when a reference 
+	/// utility function use(), which will create the proper binding. In cases when a reference
 	/// is passed to binding, the storage it refers to must be valid at the statement execution time.
 	/// To pass a copy of a variable, constant or string literal, use utility function bind().
 	/// Variables can be passed as either copies or references (i.e. using either use() or bind()).
 {
 public:
-	typedef T                    ValType;
-	typedef SharedPtr<ValType>   ValPtr;
-	typedef CopyBinding<ValType> Type;
-	typedef SharedPtr<Type>      Ptr;
+	using ValType = T;
+	using ValPtr = SharedPtr<ValType>;
+	using Type = CopyBinding<ValType>;
+	using Ptr = SharedPtr<Type>;
 
 	explicit CopyBinding(T& val,
-		const std::string& name = "", 
-		Direction direction = PD_IN): 
+		const std::string& name = "",
+		Direction direction = PD_IN):
 		AbstractBinding(name, direction),
 		_pVal(new T(val)),
 		_bound(false)
@@ -168,31 +167,29 @@ public:
 	{
 		_bound = false;
 		AbstractBinder::Ptr pBinder = getBinder();
-		poco_assert_dbg (!pBinder.isNull());
-		pBinder->reset();
+		if (pBinder) pBinder->reset();
 	}
 
 private:
-	//typedef typename TypeWrapper<T>::TYPE ValueType;
 	ValPtr _pVal;
 	bool   _bound;
 };
 
 
 template <>
-class Binding<const char*>: public AbstractBinding
+class Binding<const char*> final: public AbstractBinding
 	/// Binding const char* specialization wraps char pointer into string.
 {
 public:
-	typedef const char*          ValType;
-	typedef SharedPtr<ValType>   ValPtr;
-	typedef Binding<const char*> Type;
-	typedef SharedPtr<Type>      Ptr;
+	using ValType = const char*;
+	using ValPtr = SharedPtr<ValType>;
+	using Type = Binding<const char*>;
+	using Ptr = SharedPtr<Type>;
 
-	explicit Binding(const char* pVal, 
+	explicit Binding(const char* pVal,
 		const std::string& name = "",
-		Direction direction = PD_IN): 
-		AbstractBinding(name, direction), 
+		Direction direction = PD_IN):
+		AbstractBinding(name, direction),
 		_val(pVal ? pVal : throw NullPointerException() ),
 		_bound(false)
 		/// Creates the Binding by copying the passed string.
@@ -230,8 +227,7 @@ public:
 	{
 		_bound = false;
 		AbstractBinder::Ptr pBinder = getBinder();
-		poco_assert_dbg (!pBinder.isNull());
-		pBinder->reset();
+		if (pBinder) pBinder->reset();
 	}
 
 private:
@@ -242,19 +238,19 @@ private:
 
 
 template <>
-class CopyBinding<const char*>: public AbstractBinding
+class CopyBinding<const char*> final: public AbstractBinding
 	/// Binding const char* specialization wraps char pointer into string.
 {
 public:
-	typedef const char*              ValType;
-	typedef SharedPtr<ValType>       ValPtr;
-	typedef CopyBinding<const char*> Type;
-	typedef SharedPtr<Type>          Ptr;
+	using ValType = const char*;
+	using ValPtr = SharedPtr<ValType>;
+	using Type = CopyBinding<const char*>;
+	using Ptr = SharedPtr<Type>;
 
-	explicit CopyBinding(const char* pVal, 
+	explicit CopyBinding(const char* pVal,
 		const std::string& name = "",
-		Direction direction = PD_IN): 
-		AbstractBinding(name, direction), 
+		Direction direction = PD_IN):
+		AbstractBinding(name, direction),
 		_val(pVal ? pVal : throw NullPointerException() ),
 		_bound(false)
 		/// Creates the Binding by copying the passed string.
@@ -292,8 +288,7 @@ public:
 	{
 		_bound = false;
 		AbstractBinder::Ptr pBinder = getBinder();
-		poco_assert_dbg (!pBinder.isNull());
-		pBinder->reset();
+		if (pBinder) pBinder->reset();
 	}
 
 private:
@@ -303,21 +298,21 @@ private:
 
 
 template <class T>
-class Binding<std::vector<T> >: public AbstractBinding
+class Binding<std::vector<T>> final: public AbstractBinding
 	/// Specialization for std::vector.
 {
 public:
-	typedef std::vector<T>                   ValType;
-	typedef SharedPtr<ValType>               ValPtr;
-	typedef SharedPtr<Binding<ValType> >     Ptr;
-	typedef typename ValType::const_iterator Iterator;
+	using ValType = std::vector<T>;
+	using ValPtr = SharedPtr<ValType>;
+	using Ptr = SharedPtr<Binding<ValType>>;
+	using Iterator = typename ValType::const_iterator;
 
-	explicit Binding(std::vector<T>& val, 
-		const std::string& name = "", 
-		Direction direction = PD_IN): 
+	explicit Binding(std::vector<T>& val,
+		const std::string& name = "",
+		Direction direction = PD_IN):
 		AbstractBinding(name, direction),
-		_val(val), 
-		_begin(), 
+		_val(val),
+		_begin(),
 		_end()
 		/// Creates the Binding.
 	{
@@ -350,7 +345,7 @@ public:
 	{
 		poco_assert_dbg(!getBinder().isNull());
 		poco_assert_dbg(canBind());
-		
+
 		TypeHandler<T>::bind(pos, *_begin, getBinder(), getDirection());
 		++_begin;
 	}
@@ -369,22 +364,22 @@ private:
 
 
 template <class T>
-class CopyBinding<std::vector<T> >: public AbstractBinding
+class CopyBinding<std::vector<T>> final: public AbstractBinding
 	/// Specialization for std::vector.
 {
 public:
-	
-	typedef std::vector<T>                   ValType;
-	typedef SharedPtr<ValType>               ValPtr;
-	typedef SharedPtr<CopyBinding<ValType> > Ptr;
-	typedef typename ValType::const_iterator Iterator;
 
-	explicit CopyBinding(std::vector<T>& val, 
-		const std::string& name = "", 
-		Direction direction = PD_IN): 
+	using ValType = std::vector<T>;
+	using ValPtr = SharedPtr<ValType>;
+	using Ptr = SharedPtr<CopyBinding<ValType>>;
+	using Iterator = typename ValType::const_iterator;
+
+	explicit CopyBinding(std::vector<T>& val,
+		const std::string& name = "",
+		Direction direction = PD_IN):
 		AbstractBinding(name, direction),
 		_pVal(new std::vector<T>(val)),
-		_begin(), 
+		_begin(),
 		_end()
 		/// Creates the Binding.
 	{
@@ -417,7 +412,7 @@ public:
 	{
 		poco_assert_dbg(!getBinder().isNull());
 		poco_assert_dbg(canBind());
-		
+
 		TypeHandler<T>::bind(pos, *_begin, getBinder(), getDirection());
 		++_begin;
 	}
@@ -436,33 +431,33 @@ private:
 
 
 template <>
-class Binding<std::vector<bool> >: public AbstractBinding
+class Binding<std::vector<bool>> final: public AbstractBinding
 	/// Specialization for std::vector<bool>.
 	/// This specialization is necessary due to the nature of std::vector<bool>.
-	/// For details, see the standard library implementation of std::vector<bool> 
+	/// For details, see the standard library implementation of std::vector<bool>
 	/// or
 	/// S. Meyers: "Effective STL" (Copyright Addison-Wesley 2001),
 	/// Item 18: "Avoid using vector<bool>."
-	/// 
+	///
 	/// The workaround employed here is using std::deque<bool> as an
-	/// internal replacement container. 
-	/// 
+	/// internal replacement container.
+	///
 	/// IMPORTANT:
 	/// Only IN binding is supported.
 {
 public:
-	typedef std::vector<bool>            ValType;
-	typedef SharedPtr<ValType>           ValPtr;
-	typedef SharedPtr<Binding<ValType> > Ptr;
-	typedef ValType::const_iterator      Iterator;
+	using ValType = std::vector<bool>;
+	using ValPtr = SharedPtr<ValType>;
+	using Ptr = SharedPtr<Binding<ValType>>;
+	using Iterator = ValType::const_iterator;
 
-	explicit Binding(const std::vector<bool>& val, 
-		const std::string& name = "", 
-		Direction direction = PD_IN): 
-		AbstractBinding(name, direction), 
-		_val(val), 
+	explicit Binding(const std::vector<bool>& val,
+		const std::string& name = "",
+		Direction direction = PD_IN):
+		AbstractBinding(name, direction),
+		_val(val),
 		_deq(_val.begin(), _val.end()),
-		_begin(), 
+		_begin(),
 		_end()
 		/// Creates the Binding.
 	{
@@ -500,7 +495,6 @@ public:
 		poco_assert_dbg(canBind());
 		TypeHandler<bool>::bind(pos, *_begin, getBinder(), getDirection());
 		++_begin;
-
 	}
 
 	void reset()
@@ -518,32 +512,32 @@ private:
 
 
 template <>
-class CopyBinding<std::vector<bool> >: public AbstractBinding
+class CopyBinding<std::vector<bool>> final: public AbstractBinding
 	/// Specialization for std::vector<bool>.
 	/// This specialization is necessary due to the nature of std::vector<bool>.
-	/// For details, see the standard library implementation of std::vector<bool> 
+	/// For details, see the standard library implementation of std::vector<bool>
 	/// or
 	/// S. Meyers: "Effective STL" (Copyright Addison-Wesley 2001),
 	/// Item 18: "Avoid using vector<bool>."
-	/// 
+	///
 	/// The workaround employed here is using std::deque<bool> as an
-	/// internal replacement container. 
-	/// 
+	/// internal replacement container.
+	///
 	/// IMPORTANT:
 	/// Only IN binding is supported.
 {
 public:
-	typedef std::vector<bool>                ValType;
-	typedef SharedPtr<ValType>               ValPtr;
-	typedef SharedPtr<CopyBinding<ValType> > Ptr;
-	typedef ValType::const_iterator          Iterator;
+	using ValType = std::vector<bool>;
+	using ValPtr = SharedPtr<ValType>;
+	using Ptr = SharedPtr<CopyBinding<ValType>>;
+	using Iterator = ValType::const_iterator;
 
-	explicit CopyBinding(const std::vector<bool>& val, 
-		const std::string& name = "", 
-		Direction direction = PD_IN): 
-		AbstractBinding(name, direction), 
+	explicit CopyBinding(const std::vector<bool>& val,
+		const std::string& name = "",
+		Direction direction = PD_IN):
+		AbstractBinding(name, direction),
 		_deq(val.begin(), val.end()),
-		_begin(), 
+		_begin(),
 		_end()
 		/// Creates the Binding.
 	{
@@ -598,21 +592,21 @@ private:
 
 
 template <class T>
-class Binding<std::list<T> >: public AbstractBinding
+class Binding<std::list<T>> final: public AbstractBinding
 	/// Specialization for std::list.
 {
 public:
-	typedef std::list<T>                     ValType;
-	typedef SharedPtr<ValType>               ValPtr;
-	typedef SharedPtr<Binding<ValType> >     Ptr;
-	typedef typename ValType::const_iterator Iterator;
+	using ValType = std::list<T>;
+	using ValPtr = SharedPtr<ValType>;
+	using Ptr = SharedPtr<Binding<ValType>>;
+	using Iterator = typename ValType::const_iterator;
 
 	explicit Binding(std::list<T>& val,
 		const std::string& name = "",
-		Direction direction = PD_IN): 
-		AbstractBinding(name, direction), 
-		_val(val), 
-		_begin(), 
+		Direction direction = PD_IN):
+		AbstractBinding(name, direction),
+		_val(val),
+		_begin(),
 		_end()
 		/// Creates the Binding.
 	{
@@ -663,21 +657,21 @@ private:
 
 
 template <class T>
-class CopyBinding<std::list<T> >: public AbstractBinding
+class CopyBinding<std::list<T>> final: public AbstractBinding
 	/// Specialization for std::list.
 {
 public:
-	typedef typename std::list<T>            ValType;
-	typedef SharedPtr<ValType>               ValPtr;
-	typedef SharedPtr<CopyBinding<ValType> > Ptr;
-	typedef typename ValType::const_iterator Iterator;
+	using ValType = typename std::list<T>;
+	using ValPtr = SharedPtr<ValType>;
+	using Ptr = SharedPtr<CopyBinding<ValType>>;
+	using Iterator = typename ValType::const_iterator;
 
 	explicit CopyBinding(ValType& val,
 		const std::string& name = "",
-		Direction direction = PD_IN): 
-		AbstractBinding(name, direction), 
+		Direction direction = PD_IN):
+		AbstractBinding(name, direction),
 		_pVal(new std::list<T>(val)),
-		_begin(), 
+		_begin(),
 		_end()
 		/// Creates the Binding.
 	{
@@ -728,21 +722,21 @@ private:
 
 
 template <class T>
-class Binding<std::deque<T> >: public AbstractBinding
+class Binding<std::deque<T>> final: public AbstractBinding
 	/// Specialization for std::deque.
 {
 public:
-	typedef std::deque<T>                    ValType;
-	typedef SharedPtr<ValType>               ValPtr;
-	typedef SharedPtr<Binding<ValType> >     Ptr;
-	typedef typename ValType::const_iterator Iterator;
+	using ValType = std::deque<T>;
+	using ValPtr = SharedPtr<ValType>;
+	using Ptr = SharedPtr<Binding<ValType>>;
+	using Iterator = typename ValType::const_iterator;
 
 	explicit Binding(std::deque<T>& val,
 		const std::string& name = "",
-		Direction direction = PD_IN): 
-		AbstractBinding(name, direction), 
-		_val(val), 
-		_begin(), 
+		Direction direction = PD_IN):
+		AbstractBinding(name, direction),
+		_val(val),
+		_begin(),
 		_end()
 		/// Creates the Binding.
 	{
@@ -793,21 +787,21 @@ private:
 
 
 template <class T>
-class CopyBinding<std::deque<T> >: public AbstractBinding
+class CopyBinding<std::deque<T>> final: public AbstractBinding
 	/// Specialization for std::deque.
 {
 public:
-	typedef std::deque<T>                    ValType;
-	typedef SharedPtr<ValType>               ValPtr;
-	typedef SharedPtr<CopyBinding<ValType> > Ptr;
-	typedef typename ValType::const_iterator Iterator;
+	using ValType = std::deque<T>;
+	using ValPtr = SharedPtr<ValType>;
+	using Ptr = SharedPtr<CopyBinding<ValType>>;
+	using Iterator = typename ValType::const_iterator;
 
 	explicit CopyBinding(std::deque<T>& val,
 		const std::string& name = "",
-		Direction direction = PD_IN): 
-		AbstractBinding(name, direction), 
+		Direction direction = PD_IN):
+		AbstractBinding(name, direction),
 		_pVal(new std::deque<T>(val)),
-		_begin(), 
+		_begin(),
 		_end()
 		/// Creates the Binding.
 	{
@@ -858,21 +852,21 @@ private:
 
 
 template <class T>
-class Binding<std::set<T> >: public AbstractBinding
+class Binding<std::set<T>> final: public AbstractBinding
 	/// Specialization for std::set.
 {
 public:
-	typedef std::set<T>                      ValType;
-	typedef SharedPtr<ValType>               ValPtr;
-	typedef SharedPtr<Binding<ValType> >     Ptr;
-	typedef typename ValType::const_iterator Iterator;
+	using ValType = std::set<T>;
+	using ValPtr = SharedPtr<ValType>;
+	using Ptr = SharedPtr<Binding<ValType>>;
+	using Iterator = typename ValType::const_iterator;
 
 	explicit Binding(std::set<T>& val,
 		const std::string& name = "",
-		Direction direction = PD_IN): 
-		AbstractBinding(name, direction), 
-		_val(val), 
-		_begin(), 
+		Direction direction = PD_IN):
+		AbstractBinding(name, direction),
+		_val(val),
+		_begin(),
 		_end()
 		/// Creates the Binding.
 	{
@@ -923,21 +917,21 @@ private:
 
 
 template <class T>
-class CopyBinding<std::set<T> >: public AbstractBinding
+class CopyBinding<std::set<T>> final: public AbstractBinding
 	/// Specialization for std::set.
 {
 public:
-	typedef std::set<T>                      ValType;
-	typedef SharedPtr<ValType>               ValPtr;
-	typedef SharedPtr<CopyBinding<ValType> > Ptr;
-	typedef typename ValType::const_iterator Iterator;
+	using ValType = std::set<T>;
+	using ValPtr = SharedPtr<ValType>;
+	using Ptr = SharedPtr<CopyBinding<ValType>>;
+	using Iterator = typename ValType::const_iterator;
 
 	explicit CopyBinding(std::set<T>& val,
 		const std::string& name = "",
-		Direction direction = PD_IN): 
-		AbstractBinding(name, direction), 
+		Direction direction = PD_IN):
+		AbstractBinding(name, direction),
 		_pVal(new std::set<T>(val)),
-		_begin(), 
+		_begin(),
 		_end()
 		/// Creates the Binding.
 	{
@@ -988,21 +982,21 @@ private:
 
 
 template <class T>
-class Binding<std::multiset<T> >: public AbstractBinding
+class Binding<std::multiset<T>> final: public AbstractBinding
 	/// Specialization for std::multiset.
 {
 public:
-	typedef std::multiset<T>                 ValType;
-	typedef SharedPtr<ValType>               ValPtr;
-	typedef SharedPtr<Binding<ValType> >     Ptr;
-	typedef typename ValType::const_iterator Iterator;
+	using ValType = std::multiset<T>;
+	using ValPtr = SharedPtr<ValType>;
+	using Ptr = SharedPtr<Binding<ValType>>;
+	using Iterator = typename ValType::const_iterator;
 
 	explicit Binding(std::multiset<T>& val,
 		const std::string& name = "",
-		Direction direction = PD_IN): 
-		AbstractBinding(name, direction), 
-		_val(val), 
-		_begin(), 
+		Direction direction = PD_IN):
+		AbstractBinding(name, direction),
+		_val(val),
+		_begin(),
 		_end()
 		/// Creates the Binding.
 	{
@@ -1053,21 +1047,21 @@ private:
 
 
 template <class T>
-class CopyBinding<std::multiset<T> >: public AbstractBinding
+class CopyBinding<std::multiset<T>> final: public AbstractBinding
 	/// Specialization for std::multiset.
 {
 public:
-	typedef std::multiset<T>             ValType;
-	typedef SharedPtr<ValType>           ValPtr;
-	typedef SharedPtr<CopyBinding<ValType> > Ptr;
-	typedef typename ValType::const_iterator Iterator;
+	using ValType = std::multiset<T>;
+	using ValPtr = SharedPtr<ValType>;
+	using Ptr = SharedPtr<CopyBinding<ValType>>;
+	using Iterator = typename ValType::const_iterator;
 
 	explicit CopyBinding(std::multiset<T>& val,
 		const std::string& name = "",
-		Direction direction = PD_IN): 
-		AbstractBinding(name, direction), 
+		Direction direction = PD_IN):
+		AbstractBinding(name, direction),
 		_pVal(new std::multiset<T>(val)),
-		_begin(), 
+		_begin(),
 		_end()
 		/// Creates the Binding.
 	{
@@ -1118,21 +1112,21 @@ private:
 
 
 template <class K, class V>
-class Binding<std::map<K, V> >: public AbstractBinding
+class Binding<std::map<K, V>> final: public AbstractBinding
 	/// Specialization for std::map.
 {
 public:
-	typedef std::map<K, V>                   ValType;
-	typedef SharedPtr<ValType>               ValPtr;
-	typedef SharedPtr<Binding<ValType> >     Ptr;
-	typedef typename ValType::const_iterator Iterator;
+	using ValType = std::map<K, V>;
+	using ValPtr = SharedPtr<ValType>;
+	using Ptr = SharedPtr<Binding<ValType>>;
+	using Iterator = typename ValType::const_iterator;
 
 	explicit Binding(std::map<K, V>& val,
 		const std::string& name = "",
-		Direction direction = PD_IN): 
-		AbstractBinding(name, direction), 
-		_val(val), 
-		_begin(), 
+		Direction direction = PD_IN):
+		AbstractBinding(name, direction),
+		_val(val),
+		_begin(),
 		_end()
 		/// Creates the Binding.
 	{
@@ -1183,21 +1177,21 @@ private:
 
 
 template <class K, class V>
-class CopyBinding<std::map<K, V> >: public AbstractBinding
+class CopyBinding<std::map<K, V>> final: public AbstractBinding
 	/// Specialization for std::map.
 {
 public:
-	typedef std::map<K, V>                   ValType;
-	typedef SharedPtr<ValType>               ValPtr;
-	typedef SharedPtr<CopyBinding<ValType> > Ptr;
-	typedef typename ValType::const_iterator Iterator;
+	using ValType = std::map<K, V>;
+	using ValPtr = SharedPtr<ValType>;
+	using Ptr = SharedPtr<CopyBinding<ValType>>;
+	using Iterator = typename ValType::const_iterator;
 
 	explicit CopyBinding(std::map<K, V>& val,
 		const std::string& name = "",
-		Direction direction = PD_IN): 
-		AbstractBinding(name, direction), 
+		Direction direction = PD_IN):
+		AbstractBinding(name, direction),
 		_pVal(new std::map<K, V>(val)),
-		_begin(), 
+		_begin(),
 		_end()
 		/// Creates the Binding.
 	{
@@ -1248,21 +1242,21 @@ private:
 
 
 template <class K, class V>
-class Binding<std::multimap<K, V> >: public AbstractBinding
+class Binding<std::multimap<K, V>> final: public AbstractBinding
 	/// Specialization for std::multimap.
 {
 public:
-	typedef std::multimap<K, V>              ValType;
-	typedef SharedPtr<ValType>               ValPtr;
-	typedef SharedPtr<Binding<ValType> >     Ptr;
-	typedef typename ValType::const_iterator Iterator;
+	using ValType = std::multimap<K, V>;
+	using ValPtr = SharedPtr<ValType>;
+	using Ptr = SharedPtr<Binding<ValType>>;
+	using Iterator = typename ValType::const_iterator;
 
 	explicit Binding(std::multimap<K, V>& val,
 		const std::string& name = "",
-		Direction direction = PD_IN): 
-		AbstractBinding(name, direction), 
-		_val(val), 
-		_begin(), 
+		Direction direction = PD_IN):
+		AbstractBinding(name, direction),
+		_val(val),
+		_begin(),
 		_end()
 		/// Creates the Binding.
 	{
@@ -1313,21 +1307,21 @@ private:
 
 
 template <class K, class V>
-class CopyBinding<std::multimap<K, V> >: public AbstractBinding
+class CopyBinding<std::multimap<K, V>> final: public AbstractBinding
 	/// Specialization for std::multimap.
 {
 public:
-	typedef std::multimap<K, V>              ValType;
-	typedef SharedPtr<ValType>               ValPtr;
-	typedef SharedPtr<CopyBinding<ValType> > Ptr;
-	typedef typename ValType::const_iterator Iterator;
+	using ValType = std::multimap<K, V>;
+	using ValPtr = SharedPtr<ValType>;
+	using Ptr = SharedPtr<CopyBinding<ValType>>;
+	using Iterator = typename ValType::const_iterator;
 
 	explicit CopyBinding(std::multimap<K, V>& val,
 		const std::string& name = "",
-		Direction direction = PD_IN): 
-		AbstractBinding(name, direction), 
+		Direction direction = PD_IN):
+		AbstractBinding(name, direction),
 		_pVal(new std::multimap<K, V>(val)),
-		_begin(), 
+		_begin(),
 		_end()
 		/// Creates the Binding.
 	{
@@ -1380,13 +1374,13 @@ private:
 namespace Keywords {
 
 
-template <typename T> 
+template <typename T>
 inline AbstractBinding::Ptr use(T& t, const std::string& name = "")
 	/// Convenience function for a more compact Binding creation.
 {
 	// If this fails to compile, a const ref was passed to use().
 	// This can be resolved by either (a) using bind (which will copy the value),
-	// or (b) if the const ref is guaranteed to exist when execute is called 
+	// or (b) if the const ref is guaranteed to exist when execute is called
 	// (which can be much later!), by using the "useRef" keyword instead
 	poco_static_assert (!IsConst<T>::VALUE);
 	return new Binding<T>(t, name, AbstractBinding::PD_IN);
@@ -1400,7 +1394,7 @@ inline AbstractBinding::Ptr use(const NullData& t, const std::string& name = "")
 }
 
 
-template <typename T> 
+template <typename T>
 inline AbstractBinding::Ptr useRef(T& t, const std::string& name = "")
 	/// Convenience function for a more compact Binding creation.
 {
@@ -1408,7 +1402,7 @@ inline AbstractBinding::Ptr useRef(T& t, const std::string& name = "")
 }
 
 
-template <typename T> 
+template <typename T>
 inline AbstractBinding::Ptr in(T& t, const std::string& name = "")
 	/// Convenience function for a more compact Binding creation.
 {
@@ -1423,7 +1417,7 @@ inline AbstractBinding::Ptr in(const NullData& t, const std::string& name = "")
 }
 
 
-template <typename T> 
+template <typename T>
 inline AbstractBinding::Ptr out(T& t)
 	/// Convenience function for a more compact Binding creation.
 {
@@ -1432,7 +1426,7 @@ inline AbstractBinding::Ptr out(T& t)
 }
 
 
-template <typename T> 
+template <typename T>
 inline AbstractBinding::Ptr io(T& t)
 	/// Convenience function for a more compact Binding creation.
 {
@@ -1469,7 +1463,7 @@ inline AbstractBindingVec& io(AbstractBindingVec& bv)
 }
 
 
-template <typename T> 
+template <typename T>
 inline AbstractBinding::Ptr bind(T t, const std::string& name)
 	/// Convenience function for a more compact Binding creation.
 	/// This funtion differs from use() in its value copy semantics.
@@ -1478,7 +1472,7 @@ inline AbstractBinding::Ptr bind(T t, const std::string& name)
 }
 
 
-template <typename T> 
+template <typename T>
 inline AbstractBinding::Ptr bind(T t)
 	/// Convenience function for a more compact Binding creation.
 	/// This funtion differs from use() in its value copy semantics.
