@@ -133,6 +133,9 @@ public:
 		/// this execution step. When reset is false, data is appended to the
 		/// bound containers during multiple execute calls.
 
+	void executeDirect(const std::string& query);
+		/// Execute query directly.
+
 	void reset();
 		/// Resets the statement, so that we can reuse all bindings and re-execute again.
 
@@ -199,6 +202,9 @@ protected:
 	virtual void bindImpl() = 0;
 		/// Binds parameters.
 
+	virtual void execDirectImpl(const std::string& query);
+		/// Execute query directly.
+
 	virtual AbstractExtraction::ExtractorPtr extractor() = 0;
 		/// Returns the concrete extractor used by the statement.
 
@@ -253,6 +259,9 @@ protected:
 	SessionImpl& session();
 		/// Rteurns session associated with this statement.
 
+	const SessionImpl& session() const;
+		/// Rteurns session associated with this statement.
+
 	virtual AbstractBinding::BinderPtr binder() = 0;
 		/// Returns the concrete binder used by the statement.
 
@@ -432,7 +441,7 @@ private:
 
 	using CountVec = std::vector<std::size_t>;
 
-	State                    _state;
+	std::atomic<State>       _state;
 	Limit                    _extrLimit;
 	std::size_t              _lowerLimit;
 	std::vector<int>         _columnsExtracted;
@@ -506,6 +515,12 @@ inline SessionImpl& StatementImpl::session()
 }
 
 
+inline const SessionImpl& StatementImpl::session() const
+{
+	return _rSession;
+}
+
+
 inline void StatementImpl::setStorage(Storage storage)
 {
 	_storage = storage;
