@@ -20,6 +20,7 @@
 #include "Poco/Data/Column.h"
 #include "Poco/Data/Date.h"
 #include "Poco/Data/Time.h"
+#include "Poco/Data/SQLChannel.h"
 #include "Poco/Data/SimpleRowFormatter.h"
 #include "Poco/Data/JSONRowFormatter.h"
 #include "Poco/Data/DataException.h"
@@ -27,12 +28,19 @@
 #include "Poco/BinaryReader.h"
 #include "Poco/BinaryWriter.h"
 #include "Poco/DateTime.h"
+#include "Poco/Stopwatch.h"
 #include "Poco/Types.h"
 #include "Poco/Dynamic/Var.h"
 #include "Poco/Data/DynamicLOB.h"
 #include "Poco/Data/DynamicDateTime.h"
 #include "Poco/Latin1Encoding.h"
 #include "Poco/Exception.h"
+#include "Poco/DirectoryIterator.h"
+#include "Poco/Glob.h"
+#include "Poco/File.h"
+#include "Poco/Path.h"
+#include "Poco/Nullable.h"
+#include <string>
 #include <cstring>
 #include <sstream>
 #include <iomanip>
@@ -40,46 +48,10 @@
 
 
 using namespace Poco;
+using Poco::Dynamic::Var;
 using namespace Poco::Data;
 using namespace Poco::Data::Keywords;
-
-
-using Poco::BinaryReader;
-using Poco::BinaryWriter;
-using Poco::UInt32;
-using Poco::Int64;
-using Poco::UInt64;
-using Poco::DateTime;
-using Poco::Latin1Encoding;
-using Poco::Dynamic::Var;
-using Poco::InvalidAccessException;
-using Poco::IllegalStateException;
-using Poco::RangeException;
-using Poco::NotFoundException;
-using Poco::InvalidArgumentException;
-using Poco::NotImplementedException;
-using Poco::Data::Session;
-using Poco::Data::SessionFactory;
-using Poco::Data::Statement;
-using Poco::Data::NotSupportedException;
-using Poco::Data::CLOB;
-using Poco::Data::CLOBInputStream;
-using Poco::Data::CLOBOutputStream;
-using Poco::Data::MetaColumn;
-using Poco::Data::Column;
-using Poco::Data::Row;
-using Poco::Data::RowFormatter;
-using Poco::Data::SimpleRowFormatter;
-using Poco::Data::JSONRowFormatter;
-using Poco::Data::Date;
-using Poco::Data::Time;
-using Poco::Data::AbstractExtractor;
-using Poco::Data::AbstractExtraction;
-using Poco::Data::AbstractExtractionVec;
-using Poco::Data::AbstractExtractionVecVec;
-using Poco::Data::AbstractBinding;
-using Poco::Data::AbstractBindingVec;
-using Poco::Data::NotConnectedException;
+using namespace std::string_literals;
 
 
 DataTest::DataTest(const std::string& name): CppUnit::TestCase(name)
@@ -101,6 +73,7 @@ void DataTest::testSession()
 	assertTrue (sess.connector() == sess.impl()->connectorName());
 	assertTrue ("cs" == sess.impl()->connectionString());
 	assertTrue ("test:///cs" == sess.uri());
+	assertTrue ("Test" == sess.dbmsName());
 
 	assertTrue (sess.getLoginTimeout() == Session::LOGIN_TIMEOUT_DEFAULT);
 	sess.setLoginTimeout(123);
@@ -206,11 +179,11 @@ void DataTest::testFeatures()
 	assertTrue (!sess.getFeature("forceEmptyString"));
 
 	assertTrue (sess.hasFeature("sqlParse"));
-	assertTrue (sess.getFeature("sqlParse"));
-	sess.setFeature("sqlParse", false);
-	assertTrue (!sess.getFeature("sqlParse"));
+	assertFalse (sess.getFeature("sqlParse"));
 	sess.setFeature("sqlParse", true);
 	assertTrue (sess.getFeature("sqlParse"));
+	sess.setFeature("sqlParse", false);
+	assertFalse (sess.getFeature("sqlParse"));
 
 	assertTrue (sess.hasFeature("autoCommit"));
 	assertTrue (sess.getFeature("autoCommit"));
@@ -383,7 +356,7 @@ void DataTest::testCLOB()
 	blobChrStr = CLOB(sss);
 	assertTrue (blobChrStr == blobNumStr);
 
-    std::string xyz = "xyz";
+	std::string xyz = "xyz";
 	vLOB = xyz;
 	blobChrStr = sss = vLOB.convert<std::string>();
 	assertTrue (0 == std::strncmp(xyz.c_str(), blobChrStr.rawContent(), blobChrStr.size()));
@@ -1192,7 +1165,6 @@ void DataTest::testRowSort()
 
 	testRowStrictWeak(row10, row9, row8);
 
-
 	Row row11;
 	row11.append("0", 2.5);
 	row11.append("1", 2.5);
@@ -1498,6 +1470,10 @@ void DataTest::testSQLParse()
 	sess.setFeature("autoCommit", false);
 	assertTrue (!sess.getFeature("autoCommit"));
 
+	assertFalse (sess.getFeature("sqlParse"));
+	sess.setFeature("sqlParse", true);
+	assertTrue (sess.getFeature("sqlParse"));
+
 	Statement stmt = (sess << "SELECT %s%c%s,%d,%u,%f,%s FROM Person WHERE Name LIKE 'Simp%%'",
 		"'",'a',"'",-1, 1u, 1.5, "42", now);
 
@@ -1566,6 +1542,79 @@ void DataTest::testSQLParse()
 }
 
 
+void DataTest::testSQLChannel()
+{
+	const std::string dir = Path::tempHome();
+	AutoPtr<SQLChannel> pChannel = new SQLChannel();
+	pChannel->setProperty("directory", dir);
+	Stopwatch sw; sw.start();
+	while (!pChannel->isRunning())
+	{
+		Thread::sleep(10);
+		if (sw.elapsedSeconds() > 3)
+			fail("SQLChannel timed out");
+	}
+
+	Glob g("*.log.sql");
+	if (File(dir).exists())
+	{
+		{
+			DirectoryIterator it(dir);
+			const DirectoryIterator end;
+			while (it != end)
+			{
+				if (g.match(it->path()))
+				{
+					File(it->path()).remove();
+				}
+				++it;
+			}
+		}
+	}
+
+	constexpr int mcount{10};
+	constexpr int batch{3};
+	pChannel->setProperty("minBatch", std::to_string(batch));
+	constexpr int flush{1};
+	pChannel->setProperty("flush", std::to_string(flush));
+	assertEqual(flush, NumberParser::parse(pChannel->getProperty("flush")));
+	for (int i = 0; i < mcount; i++)
+	{
+		Message msgInfA("InformationSource", Poco::format("%d Informational sync message", i), Message::PRIO_INFORMATION);
+		pChannel->log(msgInfA);
+	}
+	Thread::sleep(2000*flush); // give it time to flush
+	auto logged = pChannel->logged();
+	assertEqual(mcount, logged);
+	pChannel.reset();
+
+	int count = 0;
+	DirectoryIterator it(dir);
+	const DirectoryIterator end;
+	while (it != end)
+	{
+		if (g.match(it->path()))
+		{
+			++count;
+			File(it->path()).remove();
+		}
+		++it;
+	}
+	assertEqual(count, (mcount / batch) + (mcount % batch));
+}
+
+
+void DataTest::testNullableExtract()
+{
+	Poco::Data::Test::Extractor ext;
+	Poco::Nullable<Poco::Int32> ni;
+	assertTrue (ni.isNull());
+	assertTrue (ext.extract(0, ni));
+	assertFalse (ni.isNull());
+	assertEqual (ni.value(), 1);
+}
+
+
 void DataTest::setUp()
 {
 }
@@ -1599,6 +1648,8 @@ CppUnit::Test* DataTest::suite()
 	CppUnit_addTest(pSuite, DataTest, testExternalBindingAndExtraction);
 	CppUnit_addTest(pSuite, DataTest, testTranscode);
 	CppUnit_addTest(pSuite, DataTest, testSQLParse);
+	CppUnit_addTest(pSuite, DataTest, testSQLChannel);
+	CppUnit_addTest(pSuite, DataTest, testNullableExtract);
 
 	return pSuite;
 }
