@@ -1,9 +1,9 @@
 //
-// ISO8859_14Encoding.cpp
+// ISO8859_10Encoding.cpp
 //
 // Library: Encodings
 // Package: Encodings
-// Module:  ISO8859_14Encoding
+// Module:  ISO8859_10Encoding
 //
 // Copyright (c) 2018, Applied Informatics Software Engineering GmbH.
 // and Contributors.
@@ -12,22 +12,22 @@
 //
 
 
-#include "Poco/ISO8859_14Encoding.h"
+#include "Poco/ISO8859_10Encoding.h"
 
 
 namespace Poco {
 
 
-const char* ISO8859_14Encoding::_names[] =
+const char* ISO8859_10Encoding::_names[] =
 {
-	"ISO-8859-14",
-	"Latin8",
-	"Latin-8",
+	"ISO-8859-10",
+	"Latin6",
+	"Latin-6",
 	NULL
 };
 
 
-const TextEncoding::CharacterMap ISO8859_14Encoding::_charMap =
+const TextEncoding::CharacterMap ISO8859_10Encoding::_charMap =
 {
 	0x0000, 0x0001, 0x0002, 0x0003, 0x0004, 0x0005, 0x0006, 0x0007, 0x0008, 0x0009, 0x000A, 0x000B, 0x000C, 0x000D, 0x000E, 0x000F,
 	0x0010, 0x0011, 0x0012, 0x0013, 0x0014, 0x0015, 0x0016, 0x0017, 0x0018, 0x0019, 0x001A, 0x001B, 0x001C, 0x001D, 0x001E, 0x001F,
@@ -39,21 +39,21 @@ const TextEncoding::CharacterMap ISO8859_14Encoding::_charMap =
 	0x0070, 0x0071, 0x0072, 0x0073, 0x0074, 0x0075, 0x0076, 0x0077, 0x0078, 0x0079, 0x007A, 0x007B, 0x007C, 0x007D, 0x007E, 0x007F,
 	0x0080, 0x0081, 0x0082, 0x0083, 0x0084, 0x0085, 0x0086, 0x0087, 0x0088, 0x0089, 0x008A, 0x008B, 0x008C, 0x008D, 0x008E, 0x008F,
 	0x0090, 0x0091, 0x0092, 0x0093, 0x0094, 0x0095, 0x0096, 0x0097, 0x0098, 0x0099, 0x009A, 0x009B, 0x009C, 0x009D, 0x009E, 0x009F,
-	0x00A0, 0x1E02, 0x1E03, 0x00A3, 0x010A, 0x010B, 0x1E0A, 0x00A7, 0x1E80, 0x00A9, 0x1E82, 0x1E0B, 0x1EF2, 0x00AD, 0x00AE, 0x0178,
-	0x1E1E, 0x1E1F, 0x0120, 0x0121, 0x1E40, 0x1E41, 0x00B6, 0x1E56, 0x1E81, 0x1E57, 0x1E83, 0x1E60, 0x1EF3, 0x1E84, 0x1E85, 0x1E61,
-	0x00C0, 0x00C1, 0x00C2, 0x00C3, 0x00C4, 0x00C5, 0x00C6, 0x00C7, 0x00C8, 0x00C9, 0x00CA, 0x00CB, 0x00CC, 0x00CD, 0x00CE, 0x00CF,
-	0x0174, 0x00D1, 0x00D2, 0x00D3, 0x00D4, 0x00D5, 0x00D6, 0x1E6A, 0x00D8, 0x00D9, 0x00DA, 0x00DB, 0x00DC, 0x00DD, 0x0176, 0x00DF,
-	0x00E0, 0x00E1, 0x00E2, 0x00E3, 0x00E4, 0x00E5, 0x00E6, 0x00E7, 0x00E8, 0x00E9, 0x00EA, 0x00EB, 0x00EC, 0x00ED, 0x00EE, 0x00EF,
-	0x0175, 0x00F1, 0x00F2, 0x00F3, 0x00F4, 0x00F5, 0x00F6, 0x1E6B, 0x00F8, 0x00F9, 0x00FA, 0x00FB, 0x00FC, 0x00FD, 0x0177, 0x00FF,
+	0x00A0, 0x0104, 0x0112, 0x0122, 0x012A, 0x0128, 0x0136, 0x00A7, 0x013B, 0x0110, 0x0160, 0x0166, 0x017D, 0x00AD, 0x016A, 0x014A,
+	0x00B0, 0x0105, 0x0113, 0x0123, 0x012B, 0x0129, 0x0137, 0x00B7, 0x013C, 0x0111, 0x0161, 0x0167, 0x017E, 0x2015, 0x016B, 0x014B,
+	0x0100, 0x00C1, 0x00C2, 0x00C3, 0x00C4, 0x00C5, 0x00C6, 0x012E, 0x010C, 0x00C9, 0x0118, 0x00CB, 0x0116, 0x00CD, 0x00CE, 0x00CF,
+	0x00D0, 0x0145, 0x014C, 0x00D3, 0x00D4, 0x00D5, 0x00D6, 0x0168, 0x00D8, 0x0172, 0x00DA, 0x00DB, 0x00DC, 0x00DD, 0x00DE, 0x00DF,
+	0x0101, 0x00E1, 0x00E2, 0x00E3, 0x00E4, 0x00E5, 0x00E6, 0x012F, 0x010D, 0x00E9, 0x0119, 0x00EB, 0x0117, 0x00ED, 0x00EE, 0x00EF,
+	0x00F0, 0x0146, 0x014D, 0x00F3, 0x00F4, 0x00F5, 0x00F6, 0x0169, 0x00F8, 0x0173, 0x00FA, 0x00FB, 0x00FC, 0x00FD, 0x00FE, 0x0138,
 };
 
 
-const DoubleByteEncoding::Mapping ISO8859_14Encoding::_mappingTable[] = {
+const DoubleByteEncoding::Mapping ISO8859_10Encoding::_mappingTable[] = {
 	{ 0x0000, 0x0000 } // dummy entry
 };
 
 
-const DoubleByteEncoding::Mapping ISO8859_14Encoding::_reverseMappingTable[] = {
+const DoubleByteEncoding::Mapping ISO8859_10Encoding::_reverseMappingTable[] = {
 	{ 0x0000, 0x0000 }, { 0x0001, 0x0001 }, { 0x0002, 0x0002 }, { 0x0003, 0x0003 }, { 0x0004, 0x0004 }, { 0x0005, 0x0005 }, { 0x0006, 0x0006 }, { 0x0007, 0x0007 },
 	{ 0x0008, 0x0008 }, { 0x0009, 0x0009 }, { 0x000A, 0x000A }, { 0x000B, 0x000B }, { 0x000C, 0x000C }, { 0x000D, 0x000D }, { 0x000E, 0x000E }, { 0x000F, 0x000F },
 	{ 0x0010, 0x0010 }, { 0x0011, 0x0011 }, { 0x0012, 0x0012 }, { 0x0013, 0x0013 }, { 0x0014, 0x0014 }, { 0x0015, 0x0015 }, { 0x0016, 0x0016 }, { 0x0017, 0x0017 },
@@ -74,28 +74,28 @@ const DoubleByteEncoding::Mapping ISO8859_14Encoding::_reverseMappingTable[] = {
 	{ 0x0088, 0x0088 }, { 0x0089, 0x0089 }, { 0x008A, 0x008A }, { 0x008B, 0x008B }, { 0x008C, 0x008C }, { 0x008D, 0x008D }, { 0x008E, 0x008E }, { 0x008F, 0x008F },
 	{ 0x0090, 0x0090 }, { 0x0091, 0x0091 }, { 0x0092, 0x0092 }, { 0x0093, 0x0093 }, { 0x0094, 0x0094 }, { 0x0095, 0x0095 }, { 0x0096, 0x0096 }, { 0x0097, 0x0097 },
 	{ 0x0098, 0x0098 }, { 0x0099, 0x0099 }, { 0x009A, 0x009A }, { 0x009B, 0x009B }, { 0x009C, 0x009C }, { 0x009D, 0x009D }, { 0x009E, 0x009E }, { 0x009F, 0x009F },
-	{ 0x00A0, 0x00A0 }, { 0x00A3, 0x00A3 }, { 0x00A7, 0x00A7 }, { 0x00A9, 0x00A9 }, { 0x00AD, 0x00AD }, { 0x00AE, 0x00AE }, { 0x00B6, 0x00B6 }, { 0x00C0, 0x00C0 },
-	{ 0x00C1, 0x00C1 }, { 0x00C2, 0x00C2 }, { 0x00C3, 0x00C3 }, { 0x00C4, 0x00C4 }, { 0x00C5, 0x00C5 }, { 0x00C6, 0x00C6 }, { 0x00C7, 0x00C7 }, { 0x00C8, 0x00C8 },
-	{ 0x00C9, 0x00C9 }, { 0x00CA, 0x00CA }, { 0x00CB, 0x00CB }, { 0x00CC, 0x00CC }, { 0x00CD, 0x00CD }, { 0x00CE, 0x00CE }, { 0x00CF, 0x00CF }, { 0x00D1, 0x00D1 },
-	{ 0x00D2, 0x00D2 }, { 0x00D3, 0x00D3 }, { 0x00D4, 0x00D4 }, { 0x00D5, 0x00D5 }, { 0x00D6, 0x00D6 }, { 0x00D8, 0x00D8 }, { 0x00D9, 0x00D9 }, { 0x00DA, 0x00DA },
-	{ 0x00DB, 0x00DB }, { 0x00DC, 0x00DC }, { 0x00DD, 0x00DD }, { 0x00DF, 0x00DF }, { 0x00E0, 0x00E0 }, { 0x00E1, 0x00E1 }, { 0x00E2, 0x00E2 }, { 0x00E3, 0x00E3 },
-	{ 0x00E4, 0x00E4 }, { 0x00E5, 0x00E5 }, { 0x00E6, 0x00E6 }, { 0x00E7, 0x00E7 }, { 0x00E8, 0x00E8 }, { 0x00E9, 0x00E9 }, { 0x00EA, 0x00EA }, { 0x00EB, 0x00EB },
-	{ 0x00EC, 0x00EC }, { 0x00ED, 0x00ED }, { 0x00EE, 0x00EE }, { 0x00EF, 0x00EF }, { 0x00F1, 0x00F1 }, { 0x00F2, 0x00F2 }, { 0x00F3, 0x00F3 }, { 0x00F4, 0x00F4 },
-	{ 0x00F5, 0x00F5 }, { 0x00F6, 0x00F6 }, { 0x00F8, 0x00F8 }, { 0x00F9, 0x00F9 }, { 0x00FA, 0x00FA }, { 0x00FB, 0x00FB }, { 0x00FC, 0x00FC }, { 0x00FD, 0x00FD },
-	{ 0x00FF, 0x00FF }, { 0x010A, 0x00A4 }, { 0x010B, 0x00A5 }, { 0x0120, 0x00B2 }, { 0x0121, 0x00B3 }, { 0x0174, 0x00D0 }, { 0x0175, 0x00F0 }, { 0x0176, 0x00DE },
-	{ 0x0177, 0x00FE }, { 0x0178, 0x00AF }, { 0x1E02, 0x00A1 }, { 0x1E03, 0x00A2 }, { 0x1E0A, 0x00A6 }, { 0x1E0B, 0x00AB }, { 0x1E1E, 0x00B0 }, { 0x1E1F, 0x00B1 },
-	{ 0x1E40, 0x00B4 }, { 0x1E41, 0x00B5 }, { 0x1E56, 0x00B7 }, { 0x1E57, 0x00B9 }, { 0x1E60, 0x00BB }, { 0x1E61, 0x00BF }, { 0x1E6A, 0x00D7 }, { 0x1E6B, 0x00F7 },
-	{ 0x1E80, 0x00A8 }, { 0x1E81, 0x00B8 }, { 0x1E82, 0x00AA }, { 0x1E83, 0x00BA }, { 0x1E84, 0x00BD }, { 0x1E85, 0x00BE }, { 0x1EF2, 0x00AC }, { 0x1EF3, 0x00BC },
+	{ 0x00A0, 0x00A0 }, { 0x00A7, 0x00A7 }, { 0x00AD, 0x00AD }, { 0x00B0, 0x00B0 }, { 0x00B7, 0x00B7 }, { 0x00C1, 0x00C1 }, { 0x00C2, 0x00C2 }, { 0x00C3, 0x00C3 },
+	{ 0x00C4, 0x00C4 }, { 0x00C5, 0x00C5 }, { 0x00C6, 0x00C6 }, { 0x00C9, 0x00C9 }, { 0x00CB, 0x00CB }, { 0x00CD, 0x00CD }, { 0x00CE, 0x00CE }, { 0x00CF, 0x00CF },
+	{ 0x00D0, 0x00D0 }, { 0x00D3, 0x00D3 }, { 0x00D4, 0x00D4 }, { 0x00D5, 0x00D5 }, { 0x00D6, 0x00D6 }, { 0x00D8, 0x00D8 }, { 0x00DA, 0x00DA }, { 0x00DB, 0x00DB },
+	{ 0x00DC, 0x00DC }, { 0x00DD, 0x00DD }, { 0x00DE, 0x00DE }, { 0x00DF, 0x00DF }, { 0x00E1, 0x00E1 }, { 0x00E2, 0x00E2 }, { 0x00E3, 0x00E3 }, { 0x00E4, 0x00E4 },
+	{ 0x00E5, 0x00E5 }, { 0x00E6, 0x00E6 }, { 0x00E9, 0x00E9 }, { 0x00EB, 0x00EB }, { 0x00ED, 0x00ED }, { 0x00EE, 0x00EE }, { 0x00EF, 0x00EF }, { 0x00F0, 0x00F0 },
+	{ 0x00F3, 0x00F3 }, { 0x00F4, 0x00F4 }, { 0x00F5, 0x00F5 }, { 0x00F6, 0x00F6 }, { 0x00F8, 0x00F8 }, { 0x00FA, 0x00FA }, { 0x00FB, 0x00FB }, { 0x00FC, 0x00FC },
+	{ 0x00FD, 0x00FD }, { 0x00FE, 0x00FE }, { 0x0100, 0x00C0 }, { 0x0101, 0x00E0 }, { 0x0104, 0x00A1 }, { 0x0105, 0x00B1 }, { 0x010C, 0x00C8 }, { 0x010D, 0x00E8 },
+	{ 0x0110, 0x00A9 }, { 0x0111, 0x00B9 }, { 0x0112, 0x00A2 }, { 0x0113, 0x00B2 }, { 0x0116, 0x00CC }, { 0x0117, 0x00EC }, { 0x0118, 0x00CA }, { 0x0119, 0x00EA },
+	{ 0x0122, 0x00A3 }, { 0x0123, 0x00B3 }, { 0x0128, 0x00A5 }, { 0x0129, 0x00B5 }, { 0x012A, 0x00A4 }, { 0x012B, 0x00B4 }, { 0x012E, 0x00C7 }, { 0x012F, 0x00E7 },
+	{ 0x0136, 0x00A6 }, { 0x0137, 0x00B6 }, { 0x0138, 0x00FF }, { 0x013B, 0x00A8 }, { 0x013C, 0x00B8 }, { 0x0145, 0x00D1 }, { 0x0146, 0x00F1 }, { 0x014A, 0x00AF },
+	{ 0x014B, 0x00BF }, { 0x014C, 0x00D2 }, { 0x014D, 0x00F2 }, { 0x0160, 0x00AA }, { 0x0161, 0x00BA }, { 0x0166, 0x00AB }, { 0x0167, 0x00BB }, { 0x0168, 0x00D7 },
+	{ 0x0169, 0x00F7 }, { 0x016A, 0x00AE }, { 0x016B, 0x00BE }, { 0x0172, 0x00D9 }, { 0x0173, 0x00F9 }, { 0x017D, 0x00AC }, { 0x017E, 0x00BC }, { 0x2015, 0x00BD },
 };
 
 
-ISO8859_14Encoding::ISO8859_14Encoding():
+ISO8859_10Encoding::ISO8859_10Encoding():
 	DoubleByteEncoding(_names, _charMap, _mappingTable, sizeof(_mappingTable)/sizeof(Mapping), _reverseMappingTable, sizeof(_reverseMappingTable)/sizeof(Mapping))
 {
 }
 
 
-ISO8859_14Encoding::~ISO8859_14Encoding()
+ISO8859_10Encoding::~ISO8859_10Encoding()
 {
 }
 
