@@ -210,7 +210,7 @@ public:
 
 		if (pHolder && pHolder->type() == typeid(T))
 		{
-			VarHolderImpl<T>* pHolderImpl = static_cast<VarHolderImpl<T>*>(pHolder);
+			auto* pHolderImpl = static_cast<VarHolderImpl<T>*>(pHolder);
 			return pHolderImpl->value();
 		}
 		else if (!pHolder)
@@ -475,7 +475,12 @@ public:
 	const std::type_info& type() const;
 		/// Returns the type information of the stored content.
 
-	//@ deprecated
+	std::string typeName(bool demangle = true) const;
+		/// Returns the type name of the stored content.
+		/// If demangling is available and emangle is true,
+		/// the returnsed string will be demangled.
+
+	POCO_DEPRECATED("Use clear() instead")
 	void empty();
 		/// Empties Var.
 		/// This function is deprecated and will be removed.
@@ -521,23 +526,8 @@ public:
 		/// This function returns 0 when Var is empty, 1 for POD or the size (i.e. length)
 		/// for held container.
 
-	std::string toString() const
+	std::string toString() const;
 		/// Returns the stored value as string.
-	{
-		VarHolder* pHolder = content();
-
-		if (!pHolder)
-				throw InvalidAccessException("Can not convert empty value.");
-
-		if (typeid(std::string) == pHolder->type())
-			return extract<std::string>();
-		else
-		{
-			std::string result;
-			pHolder->convert(result);
-			return result;
-		}
-	}
 
 	static Var parse(const std::string& val);
 		/// Parses the string which must be in JSON format
@@ -617,17 +607,8 @@ private:
 		_placeholder.assign<VarHolderImpl<ValueType>, ValueType>(value);
 	}
 
-	void construct(const char* value)
-	{
-		std::string val(value);
-		_placeholder.assign<VarHolderImpl<std::string>, std::string>(val);
-	}
-
-	void construct(const Var& other)
-	{
-		if (!other.isEmpty())
-			other.content()->clone(&_placeholder);
-	}
+	void construct(const char* value);
+	void construct(const Var& other);
 
 	Placeholder<VarHolder> _placeholder;
 };
@@ -642,6 +623,20 @@ private:
 /// Var members
 ///
 
+inline void Var::construct(const char* value)
+{
+	std::string val(value);
+	_placeholder.assign<VarHolderImpl<std::string>, std::string>(val);
+}
+
+
+inline void Var::construct(const Var& other)
+{
+	if (!other.isEmpty())
+		other.content()->clone(&_placeholder);
+}
+
+
 inline void Var::swap(Var& other)
 {
 	if (this == &other) return;
@@ -674,6 +669,13 @@ inline const std::type_info& Var::type() const
 }
 
 
+inline std::string Var::typeName(bool demangle) const
+{
+	VarHolder* pHolder = content();
+	return pHolder ? demangle ? Poco::demangle(pHolder->type().name()) : pHolder->type().name() : std::string();
+}
+
+
 inline Var::ConstIterator Var::begin() const
 {
 	if (size() == 0) return ConstIterator(const_cast<Var*>(this), true);
@@ -731,7 +733,7 @@ inline bool Var::operator ! () const
 
 inline bool Var::isEmpty() const
 {
-	return 0 == content();
+	return nullptr == content();
 }
 
 
@@ -2286,8 +2288,7 @@ inline bool operator >= (const unsigned long& other, const Var& da)
 } // namespace Dynamic
 
 
-//@ deprecated
-typedef Dynamic::Var DynamicAny;
+using DynamicAny POCO_DEPRECATED("") = Dynamic::Var;
 
 
 } // namespace Poco
