@@ -47,19 +47,25 @@ class Foundation_API FileIOS: public virtual std::ios
 	/// On Windows platforms, UTF-8 encoded Unicode paths are correctly handled.
 {
 public:
-	FileIOS(std::ios::openmode defaultMode);
+
+	using NativeHandle = FileStreamBuf::NativeHandle;
+
+	FileIOS();
 		/// Creates the basic stream.
-		
-	~FileIOS();
+
+	~FileIOS() override;
 		/// Destroys the stream.
 
-	void open(const std::string& path, std::ios::openmode mode);
+	virtual void open(const std::string& path, std::ios::openmode mode);
 		/// Opens the file specified by path, using the given mode.
 		///
 		/// Throws a FileException (or a similar exception) if the file 
 		/// does not exist or is not accessible for other reasons and
 		/// a new file cannot be created.
 
+	void openHandle(NativeHandle handle, std::ios::openmode mode);
+		/// Takes ownership of the handle.
+
 	void close();
 		/// Closes the file stream.
 		///
@@ -70,9 +76,17 @@ public:
 	FileStreamBuf* rdbuf();
 		/// Returns a pointer to the underlying streambuf.
 
+	NativeHandle nativeHandle() const;
+		/// Returns native file descriptor handle
+
+	UInt64 size() const;
+		/// Returns file size
+
+	void flushToDisk();
+		/// Forces buffered data to be written to the disk
+
 protected:
 	FileStreamBuf _buf;
-	std::ios::openmode _defaultMode;
 };
 
 
@@ -90,7 +104,7 @@ class Foundation_API FileInputStream: public FileIOS, public std::istream
 public:
 	FileInputStream();
 		/// Creates an unopened FileInputStream.
-	
+
 	FileInputStream(const std::string& path, std::ios::openmode mode = std::ios::in);
 		/// Creates the FileInputStream for the file given by path, using
 		/// the given mode.
@@ -98,11 +112,19 @@ public:
 		/// The std::ios::in flag is always set, regardless of the actual
 		/// value specified for mode.
 		///
-		/// Throws a FileNotFoundException (or a similar exception) if the file 
+		/// Throws a FileNotFoundException (or a similar exception) if the file
 		/// does not exist or is not accessible for other reasons.
 
-	~FileInputStream();
+	~FileInputStream() override;
 		/// Destroys the stream.
+
+	void open(const std::string& path, std::ios::openmode mode = std::ios::in) override;
+		/// Opens the file specified by path, using the given mode, which
+		/// will always include std::ios::in (even if not specified).
+		///
+		/// Throws a FileException (or a similar exception) if the file
+		/// does not exist or is not accessible for other reasons and
+		/// a new file cannot be created.
 };
 
 
@@ -120,20 +142,36 @@ class Foundation_API FileOutputStream: public FileIOS, public std::ostream
 public:
 	FileOutputStream();
 		/// Creats an unopened FileOutputStream.
-		
+
 	FileOutputStream(const std::string& path, std::ios::openmode mode = std::ios::out | std::ios::trunc);
 		/// Creates the FileOutputStream for the file given by path, using
 		/// the given mode.
 		///
-		/// The std::ios::out is always set, regardless of the actual 
+		/// The std::ios::out is always set, regardless of the actual
 		/// value specified for mode.
 		///
-		/// Throws a FileException (or a similar exception) if the file 
+		/// Throws a FileException (or a similar exception) if the file
 		/// does not exist or is not accessible for other reasons and
 		/// a new file cannot be created.
+		///
+		/// NOTE: The default mode std::ios::out | std::ios::trunc is different from the default
+		/// for std::ofstream, which is std::ios::out only. This is for backwards compatibility
+		/// with earlier POCO versions.
 
-	~FileOutputStream();
+	~FileOutputStream() override;
 		/// Destroys the FileOutputStream.
+
+	void open(const std::string& path, std::ios::openmode mode = std::ios::out | std::ios::trunc) override;
+		/// Opens the file specified by path, using the given mode, which
+		/// always includes std::ios::out, even if not specified.
+		///
+		/// Throws a FileException (or a similar exception) if the file
+		/// does not exist or is not accessible for other reasons and
+		/// a new file cannot be created.
+		///
+		/// NOTE: The default mode std::ios::out | std::ios::trunc is different from the default
+		/// for std::ostream, which is std::ios::out only. This is for backwards compatibility
+		/// with earlier POCO versions.
 };
 
 
@@ -147,7 +185,7 @@ class Foundation_API FileStream: public FileIOS, public std::iostream
 	/// Use an InputLineEndingConverter or OutputLineEndingConverter
 	/// if you require CR-LF translation.
 	///
-	/// A seek (seekg() or seekp()) operation will always set the 
+	/// A seek (seekg() or seekp()) operation will always set the
 	/// read position and the write position simultaneously to the
 	/// same value.
 	///
@@ -156,13 +194,24 @@ class Foundation_API FileStream: public FileIOS, public std::iostream
 public:
 	FileStream();
 		/// Creats an unopened FileStream.
-	
+
 	FileStream(const std::string& path, std::ios::openmode mode = std::ios::out | std::ios::in);
 		/// Creates the FileStream for the file given by path, using
 		/// the given mode.
+		///
+		/// NOTE: The default mode std::ios::in | std::ios::out is different from the default
+		/// for std::fstream, which is std::ios::out only. This is for backwards compatibility
+		/// with earlier POCO versions.
 
-	~FileStream();
+	~FileStream() override;
 		/// Destroys the FileOutputStream.
+
+	void open(const std::string& path, std::ios::openmode mode = std::ios::out | std::ios::in) override;
+		/// Opens the file specified by path, using the given mode.
+		///
+		/// Throws a FileException (or a similar exception) if the file
+		/// does not exist or is not accessible for other reasons and
+		/// a new file cannot be created.
 };
 
 
