@@ -19,6 +19,7 @@
 
 
 #include "Poco/Foundation.h"
+#include "Poco/Timestamp.h"
 
 
 namespace Poco {
@@ -32,7 +33,7 @@ protected:
 		OPT_FAIL_ON_OVERWRITE_IMPL = 0x01
 	};
 
-	typedef UInt64 FileSizeImpl;
+	using FileSizeImpl = UInt64;
 
 	FileImpl();
 	FileImpl(const std::string& path);
@@ -40,10 +41,11 @@ protected:
 	void swapImpl(FileImpl& file);
 	void setPathImpl(const std::string& path);
 	const std::string& getPathImpl() const;
+	std::string getExecutablePathImpl() const;
 	bool existsImpl() const;
 	bool canReadImpl() const;
 	bool canWriteImpl() const;
-	bool canExecuteImpl() const;
+	bool canExecuteImpl(const std::string& absolutePath) const;
 	bool isFileImpl() const;
 	bool isDirectoryImpl() const;
 	bool isLinkImpl() const;
