@@ -26,16 +26,16 @@ namespace Poco {
 
 
 template <
-	class TKey, 
+	class TKey,
 	class TValue,
-	class TMutex = FastMutex, 
+	class TMutex = FastMutex,
 	class TEventMutex = FastMutex
-> 
+>
 class LRUCache: public AbstractCache<TKey, TValue, LRUStrategy<TKey, TValue>, TMutex, TEventMutex>
 	/// An LRUCache implements Least Recently Used caching. The default size for a cache is 1024 entries.
 {
 public:
-	LRUCache(long size = 1024):
+	LRUCache(std::size_t size = 1024):
 		AbstractCache<TKey, TValue, LRUStrategy<TKey, TValue>, TMutex, TEventMutex>(LRUStrategy<TKey, TValue>(size))
 	{
 	}
