@@ -22,39 +22,29 @@
 #include "Poco/Exception.h"
 #include "Poco/ScopedLock.h"
 #include "Poco/Timestamp.h"
+#include <atomic>
 
-#if __cplusplus >= 201103L
-	#ifndef POCO_HAVE_STD_ATOMICS
-		#define POCO_HAVE_STD_ATOMICS
-	#endif
-#endif
-
-#ifdef POCO_HAVE_STD_ATOMICS
-	#include <atomic>
-#endif
-
-
-#if defined(POCO_OS_FAMILY_WINDOWS)
-#if defined(_WIN32_WCE)
-#include "Poco/Mutex_WINCE.h"
+#ifdef POCO_ENABLE_STD_MUTEX
+#include "Poco/Mutex_STD.h"
 #else
+#if defined(POCO_OS_FAMILY_WINDOWS)
 #include "Poco/Mutex_WIN32.h"
-#endif
 #elif defined(POCO_VXWORKS)
 #include "Poco/Mutex_VX.h"
 #else
 #include "Poco/Mutex_POSIX.h"
 #endif
+#endif
 
 
 namespace Poco {
 
 
 class Foundation_API Mutex: private MutexImpl
-	/// A Mutex (mutual exclusion) is a synchronization 
+	/// A Mutex (mutual exclusion) is a synchronization
 	/// mechanism used to control access to a shared resource
 	/// in a concurrent (multithreaded) scenario.
-	/// Mutexes are recursive, that is, the same mutex can be 
+	/// Mutexes are recursive, that is, the same mutex can be
 	/// locked multiple times by the same thread (but, of course,
 	/// not by other threads).
 	/// Using the ScopedLock class is the preferred way to automatically
@@ -62,23 +52,24 @@ class Foundation_API Mutex: private MutexImpl
 {
 public:
 	using ScopedLock = Poco::ScopedLock<Mutex>;
-	
+	using ScopedLockWithUnlock = Poco::ScopedLockWithUnlock<Mutex>;
+
 	Mutex();
 		/// creates the Mutex.
-		
+
 	~Mutex();
 		/// destroys the Mutex.
 
 	void lock();
 		/// Locks the mutex. Blocks if the mutex
 		/// is held by another thread.
-		
+
 	void lock(long milliseconds);
 		/// Locks the mutex. Blocks up to the given number of milliseconds
 		/// if the mutex is held by another thread. Throws a TimeoutException
 		/// if the mutex can not be locked within the given timeout.
 		///
-		/// Performance Note: On most platforms (including Windows), this member function is 
+		/// Performance Note: On most platforms (including Windows), this member function is
 		/// implemented using a loop calling (the equivalent of) tryLock() and Thread::sleep().
 		/// On POSIX platforms that support pthread_mutex_timedlock(), this is used.
 
@@ -92,14 +83,14 @@ public:
 		/// if the mutex is held by another thread.
 		/// Returns true if the mutex was successfully locked.
 		///
-		/// Performance Note: On most platforms (including Windows), this member function is 
+		/// Performance Note: On most platforms (including Windows), this member function is
 		/// implemented using a loop calling (the equivalent of) tryLock() and Thread::sleep().
 		/// On POSIX platforms that support pthread_mutex_timedlock(), this is used.
 
 	void unlock();
 		/// Unlocks the mutex so that it can be acquired by
 		/// other threads.
-	
+
 private:
 	Mutex(const Mutex&);
 	Mutex& operator = (const Mutex&);
@@ -117,10 +108,11 @@ class Foundation_API FastMutex: private FastMutexImpl
 {
 public:
 	using ScopedLock = Poco::ScopedLock<FastMutex>;
+	using ScopedLockWithUnlock = Poco::ScopedLockWithUnlock<FastMutex>;
 
 	FastMutex();
 		/// creates the Mutex.
-		
+
 	~FastMutex();
 		/// destroys the Mutex.
 
@@ -133,7 +125,7 @@ public:
 		/// if the mutex is held by another thread. Throws a TimeoutException
 		/// if the mutex can not be locked within the given timeout.
 		///
-		/// Performance Note: On most platforms (including Windows), this member function is 
+		/// Performance Note: On most platforms (including Windows), this member function is
 		/// implemented using a loop calling (the equivalent of) tryLock() and Thread::sleep().
 		/// On POSIX platforms that support pthread_mutex_timedlock(), this is used.
 
@@ -147,35 +139,35 @@ public:
 		/// if the mutex is held by another thread.
 		/// Returns true if the mutex was successfully locked.
 		///
-		/// Performance Note: On most platforms (including Windows), this member function is 
+		/// Performance Note: On most platforms (including Windows), this member function is
 		/// implemented using a loop calling (the equivalent of) tryLock() and Thread::sleep().
 		/// On POSIX platforms that support pthread_mutex_timedlock(), this is used.
 
 	void unlock();
 		/// Unlocks the mutex so that it can be acquired by
 		/// other threads.
-	
+
 private:
 	FastMutex(const FastMutex&);
 	FastMutex& operator = (const FastMutex&);
 };
 
 
-#ifdef POCO_HAVE_STD_ATOMICS
-
 class Foundation_API SpinlockMutex
 	/// A SpinlockMutex, implemented in terms of std::atomic_flag, as
 	/// busy-wait mutual exclusion.
 	///
 	/// While in some cases (eg. locking small blocks of code)
 	/// busy-waiting may be an optimal solution, in many scenarios
-	/// spinlock may not be the right choice - it is up to the user to
-	/// choose the proper mutex type for their particular case.
+	/// spinlock may not be the right choice (especially on single-core
+	/// systems) - it is up to the user to choose the proper mutex type
+	/// for their particular case.
 	///
 	/// Works with the ScopedLock class.
 {
 public:
 	using ScopedLock = Poco::ScopedLock<SpinlockMutex>;
+	using ScopedLockWithUnlock = Poco::ScopedLockWithUnlock<SpinlockMutex>;
 
 	SpinlockMutex();
 		/// Creates the SpinlockMutex.
@@ -210,8 +202,6 @@ private:
 	std::atomic_flag _flag = ATOMIC_FLAG_INIT;
 };
 
-#endif // POCO_HAVE_STD_ATOMICS
-
 
 class Foundation_API NullMutex
 	/// A NullMutex is an empty mutex implementation
@@ -222,12 +212,13 @@ class Foundation_API NullMutex
 {
 public:
 	using ScopedLock = Poco::ScopedLock<NullMutex>;
-	
+	using ScopedLockWithUnlock = Poco::ScopedLockWithUnlock<NullMutex>;
+
 	NullMutex()
 		/// Creates the NullMutex.
 	{
 	}
-		
+
 	~NullMutex()
 		/// Destroys the NullMutex.
 	{
@@ -237,7 +228,7 @@ public:
 		/// Does nothing.
 	{
 	}
-		
+
 	void lock(long)
 		/// Does nothing.
 	{
@@ -336,8 +327,6 @@ inline void FastMutex::unlock()
 }
 
 
-#ifdef POCO_HAVE_STD_ATOMICS
-
 //
 // SpinlockMutex
 //
@@ -382,8 +371,6 @@ inline void SpinlockMutex::unlock()
 	_flag.clear(std::memory_order_release);
 }
 
-#endif // POCO_HAVE_STD_ATOMICS
-
 
 } // namespace Poco
 
