@@ -29,7 +29,7 @@
 namespace Poco {
 
 
-template <class Head, class Tail> 
+template <class Head, class Tail>
 struct TypeList;
 
 
@@ -57,7 +57,7 @@ struct NullTypeList
 };
 
 
-template <class Head, class Tail> 
+template <class Head, class Tail>
 struct TypeList
 	/// Compile Time List of Types
 {
@@ -110,7 +110,7 @@ struct TypeList
 			return tail < tl.tail;
 		return false;
 	}
-	
+
 	HeadType head;
 	TailType tail;
 };
@@ -183,7 +183,7 @@ struct TypeListType<>
 };
 
 
-template <int n> 
+template <int n>
 struct Getter
 {
 	template <class Ret, class Head, class Tail>
@@ -200,7 +200,7 @@ struct Getter
 };
 
 
-template <> 
+template <>
 struct Getter<0>
 {
 	template <class Ret, class Head, class Tail>
@@ -217,20 +217,20 @@ struct Getter<0>
 };
 
 
-template <int N, class Head> 
+template <int N, class Head>
 struct TypeGetter;
 
 
-template <int N, class Head, class Tail> 
-struct TypeGetter<N, TypeList<Head, Tail> >
+template <int N, class Head, class Tail>
+struct TypeGetter<N, TypeList<Head, Tail>>
 {
 	typedef typename TypeGetter<N-1, Tail>::HeadType HeadType;
 	typedef typename TypeWrapper<HeadType>::CONSTTYPE ConstHeadType;
 };
 
 
-template <class Head, class Tail> 
-struct TypeGetter<0, TypeList<Head, Tail> >
+template <class Head, class Tail>
+struct TypeGetter<0, TypeList<Head, Tail>>
 {
 	typedef typename TypeList<Head, Tail>::HeadType HeadType;
 	typedef typename TypeWrapper<HeadType>::CONSTTYPE ConstHeadType;
@@ -248,7 +248,7 @@ struct TypeLocator;
 	///
 	/// if (2 == TypeLoc.value) ...
 	///
-	
+
 
 template <class T>
 struct TypeLocator<NullTypeList, T>
@@ -274,7 +274,7 @@ public:
 };
 
 
-template <class Head, class T> 
+template <class Head, class T>
 struct TypeAppender;
 	/// TypeAppender appends T (type or a TypeList) to Head.
 	///
@@ -305,7 +305,7 @@ struct TypeAppender<NullTypeList, T>
 
 
 template <class Head, class Tail>
-struct TypeAppender<NullTypeList, TypeList<Head, Tail> >
+struct TypeAppender<NullTypeList, TypeList<Head, Tail>>
 {
 	typedef TypeList<Head, Tail> HeadType;
 };
@@ -318,9 +318,9 @@ struct TypeAppender<TypeList<Head, Tail>, T>
 };
 
 
-template <class Head, class T> 
+template <class Head, class T>
 struct TypeOneEraser;
-	/// TypeOneEraser erases the first occurence of the type T in Head.
+	/// TypeOneEraser erases the first occurrence of the type T in Head.
 	/// Usage:
 	///
 	/// typedef TypeListType<char, int, float>::HeadType Type3;
@@ -350,9 +350,9 @@ struct TypeOneEraser<TypeList<Head, Tail>, T>
 };
 
 
-template <class Head, class T> 
+template <class Head, class T>
 struct TypeAllEraser;
-	/// TypeAllEraser erases all the occurences of the type T in Head.
+	/// TypeAllEraser erases all the occurrences of the type T in Head.
 	/// Usage:
 	///
 	/// typedef TypeListType<char, int, float, int>::HeadType Type4;
@@ -382,9 +382,9 @@ struct TypeAllEraser<TypeList<Head, Tail>, T>
 };
 
 
-template <class Head> 
+template <class Head>
 struct TypeDuplicateEraser;
-	/// TypeDuplicateEraser erases all but the first occurence of the type T in Head.
+	/// TypeDuplicateEraser erases all but the first occurrence of the type T in Head.
 	/// Usage:
 	///
 	/// typedef TypeListType<char, int, float, int>::HeadType Type4;
@@ -393,7 +393,7 @@ struct TypeDuplicateEraser;
 	///
 
 
-template <> 
+template <>
 struct TypeDuplicateEraser<NullTypeList>
 {
 	typedef NullTypeList HeadType;
@@ -401,7 +401,7 @@ struct TypeDuplicateEraser<NullTypeList>
 
 
 template <class Head, class Tail>
-struct TypeDuplicateEraser<TypeList<Head, Tail> >
+struct TypeDuplicateEraser<TypeList<Head, Tail>>
 {
 private:
 	typedef typename TypeDuplicateEraser<Tail>::HeadType L1;
@@ -413,7 +413,7 @@ public:
 
 template <class Head, class T, class R>
 struct TypeOneReplacer;
-	/// TypeOneReplacer replaces the first occurence 
+	/// TypeOneReplacer replaces the first occurrence
 	/// of the type T in Head with type R.
 	/// Usage:
 	///
@@ -446,7 +446,7 @@ struct TypeOneReplacer<TypeList<Head, Tail>, T, R>
 
 template <class Head, class T, class R>
 struct TypeAllReplacer;
-	/// TypeAllReplacer replaces all the occurences 
+	/// TypeAllReplacer replaces all the occurrences
 	/// of the type T in Head with type R.
 	/// Usage:
 	///
