@@ -22,6 +22,11 @@
 #include <cstdint>
 #include <type_traits>
 
+#if defined(POCO_HAVE_CXXABI_H)
+	#include <typeinfo>
+	#include <cxxabi.h>
+	#include <cstdlib>
+#endif
 
 namespace Poco {
 
@@ -37,7 +42,6 @@ using UInt64  = std::uint64_t;
 using IntPtr  = std::intptr_t;
 using UIntPtr = std::uintptr_t;
 
-
 #if defined(_MSC_VER)
 	#if defined(_WIN64)
 		#define POCO_PTR_IS_64_BIT 1
@@ -73,6 +77,47 @@ using UIntPtr = std::uintptr_t;
 #endif
 
 
+inline std::string Foundation_API demangle(const char* typeName)
+{
+	std::string result(typeName);
+#ifdef POCO_HAVE_CXXABI_H
+	int status;
+	char* demangled = abi::__cxa_demangle(typeName, nullptr, nullptr, &status);
+	if (demangled)
+	{
+		if (status == 0) result = demangled;
+		else
+		{
+			switch (status)
+			{
+				case -1: result = "[ERRMEM]";  break;
+				case -2: result = "[ERRNAME]"; break;
+				case -3: result = "[ERRARG]";  break;
+				default: result = "[ERRUNK]";
+			}
+		}
+
+		std::free(demangled);
+	}
+#endif
+	return result;
+}
+
+
+template <typename T>
+std::string demangle()
+{
+	return demangle(typeid(T).name());
+}
+
+
+template <typename T>
+std::string demangle(const T& t)
+{
+	return demangle(typeid(std::remove_const_t<std::remove_reference_t<decltype(t)>>).name());
+}
+
+
 } // namespace Poco
 
 
