@@ -163,15 +163,14 @@ private:
 //
 // We provide an instantiation for char.
 //
-// Visual C++ needs a workaround - explicitly importing the template
-// instantiation - to avoid duplicate symbols due to multiple
-// instantiations in different libraries.
-//
-#if defined(_MSC_VER) && defined(POCO_DLL) && !defined(Foundation_EXPORTS)
-template class Foundation_API BasicUnbufferedStreamBuf<char, std::char_traits<char>>;
-#endif
-typedef BasicUnbufferedStreamBuf<char, std::char_traits<char>> UnbufferedStreamBuf;
 
+#if defined(POCO_OS_FAMILY_WINDOWS)
+extern template class BasicUnbufferedStreamBuf<char, std::char_traits<char>>;
+#else
+extern template class Foundation_API BasicUnbufferedStreamBuf<char, std::char_traits<char>>;
+#endif
+
+using UnbufferedStreamBuf = BasicUnbufferedStreamBuf<char, std::char_traits<char>>;
 
 } // namespace Poco
 
