@@ -33,6 +33,10 @@ int main(int argc, char** argv)
 	{
 		if (arg == "-random")
 			uuid = UUIDGenerator::defaultGenerator().createRandom();
+		else if (arg == "-v6")
+			uuid = UUIDGenerator::defaultGenerator().createV6();
+		else if (arg == "-v7")
+			uuid = UUIDGenerator::defaultGenerator().createV7();
 		else if (arg.empty())
 			uuid = UUIDGenerator::defaultGenerator().create();
 		else
