@@ -170,21 +170,21 @@ BinaryReader& BinaryReader::operator >> (double& value)
 }
 
 
-#if defined(POCO_HAVE_INT64) && !defined(POCO_LONG_IS_64_BIT)
+#if defined(POCO_HAVE_INT64)
 
 
-BinaryReader& BinaryReader::operator >> (Int64& value)
+BinaryReader& BinaryReader::operator >> (long long& value)
 {
 	_istr.read((char*) &value, sizeof(value));
-	if (_flipBytes) value = ByteOrder::flipBytes(value);
+	if (_flipBytes) value = ByteOrder::flipBytes(static_cast<Poco::Int64>(value));
 	return *this;
 }
 
 
-BinaryReader& BinaryReader::operator >> (UInt64& value)
+BinaryReader& BinaryReader::operator >> (unsigned long long& value)
 {
 	_istr.read((char*) &value, sizeof(value));
-	if (_flipBytes) value = ByteOrder::flipBytes(value);
+	if (_flipBytes) value = ByteOrder::flipBytes(static_cast<Poco::UInt64>(value));
 	return *this;
 }
 
@@ -276,6 +276,31 @@ void BinaryReader::readRaw(char* buffer, std::streamsize length)
 }
 
 
+void BinaryReader::readCString(std::string& value)
+{
+	value.clear();
+	if (!_istr.good())
+	{
+		return;
+	}
+	value.reserve(256);
+	while (true)
+	{
+		char c;
+		_istr.get(c);
+		if (!_istr.good())
+		{
+			break;
+		}
+		if (c == '\0')
+		{
+			break;
+		}
+		value += c;
+	}
+}
+
+
 void BinaryReader::readBOM()
 {
 	UInt16 bom;
