@@ -21,8 +21,8 @@ namespace Poco {
 //
 // TraverseBase
 //
-TraverseBase::TraverseBase(DepthFun depthDeterminer, UInt16 maxDepth)
-	: _depthDeterminer(depthDeterminer), _maxDepth(maxDepth)
+TraverseBase::TraverseBase(DepthFun depthDeterminer, UInt16 maxDepth):
+	_depthDeterminer(depthDeterminer), _maxDepth(maxDepth)
 {
 }
 
@@ -49,8 +49,8 @@ bool TraverseBase::isDirectory(Poco::File& file)
 //
 // ChildrenFirstTraverse
 //
-ChildrenFirstTraverse::ChildrenFirstTraverse(DepthFun depthDeterminer, UInt16 maxDepth)
-	: TraverseBase(depthDeterminer, maxDepth)
+ChildrenFirstTraverse::ChildrenFirstTraverse(DepthFun depthDeterminer, UInt16 maxDepth):
+	TraverseBase(depthDeterminer, maxDepth)
 {
 }
 
@@ -61,10 +61,6 @@ const std::string ChildrenFirstTraverse::next(Stack* itStack, bool* isFinished)
 	poco_check_ptr(isFinished);
 	poco_assert(!(*isFinished));
 
-	std::stack<DirectoryIterator> it;
-
-	//_depthDeterminer(it);
-
 	// go deeper into not empty directory
 	// (if depth limit allows)
 	bool isDepthLimitReached = isFiniteDepth() && _depthDeterminer(*itStack) >= _maxDepth;
@@ -106,8 +102,8 @@ const std::string ChildrenFirstTraverse::next(Stack* itStack, bool* isFinished)
 //
 // SiblingsFirstTraverse
 //
-SiblingsFirstTraverse::SiblingsFirstTraverse(DepthFun depthDeterminer, UInt16 maxDepth)
-	: TraverseBase(depthDeterminer, maxDepth)
+SiblingsFirstTraverse::SiblingsFirstTraverse(DepthFun depthDeterminer, UInt16 maxDepth):
+	TraverseBase(depthDeterminer, maxDepth)
 {
 	_dirsStack.push(std::queue<std::string>());
 }
