@@ -13,7 +13,6 @@
 
 
 #include "Poco/ErrorHandler.h"
-#include "Poco/SingletonHolder.h"
 
 
 namespace Poco {
@@ -103,11 +102,8 @@ ErrorHandler* ErrorHandler::set(ErrorHandler* pHandler)
 
 ErrorHandler* ErrorHandler::defaultHandler()
 {
-	// NOTE: Since this is called to initialize the static _pHandler
-	// variable, sh has to be a local static, otherwise we run
-	// into static initialization order issues.
-	static SingletonHolder<ErrorHandler> sh;
-	return sh.get();
+	static ErrorHandler eh;
+	return &eh;
 }
 
 
