@@ -14,6 +14,11 @@
 
 #include "Poco/Exception.h"
 #include <typeinfo>
+#ifdef POCO_ENABLE_TRACE
+#include <sstream>
+#include "cpptrace/cpptrace.hpp"
+#include "Poco/Trace/Trace.h"
+#endif
 
 
 namespace Poco {
@@ -21,11 +26,23 @@ namespace Poco {
 
 Exception::Exception(int code): _pNested(0), _code(code)
 {
+#ifdef POCO_ENABLE_TRACE
+	std::ostringstream ostr;
+	ostr << '\n';
+	cpptrace::generate_trace(0,100).print(ostr);
+	_msg = ostr.str();
+#endif
 }
 
 
 Exception::Exception(const std::string& msg, int code): _msg(msg), _pNested(0), _code(code)
 {
+#ifdef POCO_ENABLE_TRACE
+	std::ostringstream ostr;
+	ostr << '\n';
+	cpptrace::generate_trace(0,100).print(ostr);
+	_msg += ostr.str();
+#endif
 }
 
 
@@ -36,11 +53,23 @@ Exception::Exception(const std::string& msg, const std::string& arg, int code):
 		_msg.append(": ");
 		_msg.append(arg);
 	}
+#ifdef POCO_ENABLE_TRACE
+	std::ostringstream ostr;
+	ostr << '\n';
+	cpptrace::generate_trace(0,100).print(ostr);
+	_msg += ostr.str();
+#endif
 }
 
 
 Exception::Exception(const std::string& msg, const Exception& nested, int code): _msg(msg), _pNested(nested.clone()), _code(code)
 {
+#ifdef POCO_ENABLE_TRACE
+	std::ostringstream ostr;
+	ostr << '\n';
+	cpptrace::generate_trace(0,100).print(ostr);
+	_msg += ostr.str();
+#endif
 }
 
 
@@ -151,6 +180,7 @@ POCO_IMPLEMENT_EXCEPTION(PropertyNotSupportedException, RuntimeException, "Prope
 POCO_IMPLEMENT_EXCEPTION(PoolOverflowException, RuntimeException, "Pool overflow")
 POCO_IMPLEMENT_EXCEPTION(NoPermissionException, RuntimeException, "No permission")
 POCO_IMPLEMENT_EXCEPTION(OutOfMemoryException, RuntimeException, "Out of memory")
+POCO_IMPLEMENT_EXCEPTION(ResourceLimitException, RuntimeException, "Resource limit")
 POCO_IMPLEMENT_EXCEPTION(DataException, RuntimeException, "Data error")
 
 POCO_IMPLEMENT_EXCEPTION(DataFormatException, DataException, "Bad data format")
@@ -169,6 +199,7 @@ POCO_IMPLEMENT_EXCEPTION(CreateFileException, FileException, "Cannot create file
 POCO_IMPLEMENT_EXCEPTION(OpenFileException, FileException, "Cannot open file")
 POCO_IMPLEMENT_EXCEPTION(WriteFileException, FileException, "Cannot write file")
 POCO_IMPLEMENT_EXCEPTION(ReadFileException, FileException, "Cannot read file")
+POCO_IMPLEMENT_EXCEPTION(ExecuteFileException, FileException, "Cannot execute file")
 POCO_IMPLEMENT_EXCEPTION(FileNotReadyException, FileException, "File not ready")
 POCO_IMPLEMENT_EXCEPTION(DirectoryNotEmptyException, FileException, "Directory not empty")
 POCO_IMPLEMENT_EXCEPTION(UnknownURISchemeException, RuntimeException, "Unknown URI scheme")
