@@ -15,6 +15,12 @@
 #include "Poco/InflatingStream.h"
 #include "Poco/Exception.h"
 #include <cstring>
+#include <memory>
+#if defined(POCO_UNBUNDLED)
+#include <zlib.h>
+#else
+#include "zlib.h"
+#endif
 
 
 namespace Poco {
@@ -27,29 +33,17 @@ InflatingStreamBuf::InflatingStreamBuf(std::istream& istr, StreamType type):
 	_eof(false),
 	_check(type != STREAM_ZIP)
 {
-	_zstr.next_in   = 0;
-	_zstr.avail_in  = 0;
-	_zstr.total_in  = 0;
-	_zstr.next_out  = 0;
-	_zstr.avail_out = 0;
-	_zstr.total_out = 0;
-	_zstr.msg       = 0;
-	_zstr.state     = 0;
-	_zstr.zalloc    = Z_NULL;
-	_zstr.zfree     = Z_NULL;
-	_zstr.opaque    = Z_NULL;
-	_zstr.data_type = 0;
-	_zstr.adler     = 0;
-	_zstr.reserved  = 0;
+	std::unique_ptr<char[]> buffer(new char[INFLATE_BUFFER_SIZE]);
 
-	_buffer = new char[INFLATE_BUFFER_SIZE];
-
-	int rc = inflateInit2(&_zstr, 15 + (type == STREAM_GZIP ? 16 : 0));
+	std::unique_ptr<z_stream> pZstr = std::make_unique<z_stream>(z_stream{});
+	int rc = inflateInit2(pZstr.get(), 15 + (type == STREAM_GZIP ? 16 : 0));
 	if (rc != Z_OK)
 	{
-		delete [] _buffer;
 		throw IOException(zError(rc));
 	}
+
+	_pZstr = pZstr.release();
+	_buffer = buffer.release();
 }
 
 
@@ -60,22 +54,17 @@ InflatingStreamBuf::InflatingStreamBuf(std::istream& istr, int windowBits):
 	_eof(false),
 	_check(false)
 {
-	_zstr.zalloc    = Z_NULL;
-	_zstr.zfree     = Z_NULL;
-	_zstr.opaque    = Z_NULL;
-	_zstr.next_in   = 0;
-	_zstr.avail_in  = 0;
-	_zstr.next_out  = 0;
-	_zstr.avail_out = 0;
+	std::unique_ptr<char[]> buffer(new char[INFLATE_BUFFER_SIZE]);
 
-	_buffer = new char[INFLATE_BUFFER_SIZE];
-
-	int rc = inflateInit2(&_zstr, windowBits);
+	std::unique_ptr<z_stream> pZstr = std::make_unique<z_stream>(z_stream{});
+	int rc = inflateInit2(pZstr.get(), windowBits);
 	if (rc != Z_OK)
 	{
-		delete [] _buffer;
 		throw IOException(zError(rc));
 	}
+
+	_pZstr = pZstr.release();
+	_buffer = buffer.release();
 }
 
 
@@ -86,22 +75,17 @@ InflatingStreamBuf::InflatingStreamBuf(std::ostream& ostr, StreamType type):
 	_eof(false),
 	_check(type != STREAM_ZIP)
 {
-	_zstr.zalloc    = Z_NULL;
-	_zstr.zfree     = Z_NULL;
-	_zstr.opaque    = Z_NULL;
-	_zstr.next_in   = 0;
-	_zstr.avail_in  = 0;
-	_zstr.next_out  = 0;
-	_zstr.avail_out = 0;
+	std::unique_ptr<char[]> buffer(new char[INFLATE_BUFFER_SIZE]);
 
-	_buffer = new char[INFLATE_BUFFER_SIZE];
-
-	int rc = inflateInit2(&_zstr, 15 + (type == STREAM_GZIP ? 16 : 0));
+	std::unique_ptr<z_stream> pZstr = std::make_unique<z_stream>(z_stream{});
+	int rc = inflateInit2(pZstr.get(), 15 + (type == STREAM_GZIP ? 16 : 0));
 	if (rc != Z_OK)
 	{
-		delete [] _buffer;
 		throw IOException(zError(rc));
 	}
+
+	_pZstr = pZstr.release();
+	_buffer = buffer.release();
 }
 
 
@@ -112,22 +96,17 @@ InflatingStreamBuf::InflatingStreamBuf(std::ostream& ostr, int windowBits):
 	_eof(false),
 	_check(false)
 {
-	_zstr.zalloc    = Z_NULL;
-	_zstr.zfree     = Z_NULL;
-	_zstr.opaque    = Z_NULL;
-	_zstr.next_in   = 0;
-	_zstr.avail_in  = 0;
-	_zstr.next_out  = 0;
-	_zstr.avail_out = 0;
+	std::unique_ptr<char[]> buffer(new char[INFLATE_BUFFER_SIZE]);
 
-	_buffer = new char[INFLATE_BUFFER_SIZE];
-
-	int rc = inflateInit2(&_zstr, windowBits);
+	std::unique_ptr<z_stream> pZstr = std::make_unique<z_stream>(z_stream{});
+	int rc = inflateInit2(pZstr.get(), windowBits);
 	if (rc != Z_OK)
 	{
-		delete [] _buffer;
 		throw IOException(zError(rc));
 	}
+
+	_pZstr = pZstr.release();
+	_buffer = buffer.release();
 }
 
 
@@ -141,7 +120,8 @@ InflatingStreamBuf::~InflatingStreamBuf()
 	{
 	}
 	delete [] _buffer;
-	inflateEnd(&_zstr);
+	inflateEnd(_pZstr);
+	delete _pZstr;
 }
 
 
@@ -156,7 +136,7 @@ int InflatingStreamBuf::close()
 
 void InflatingStreamBuf::reset()
 {
-	int rc = inflateReset(&_zstr);
+	int rc = inflateReset(_pZstr);
 	if (rc == Z_OK)
 		_eof = false;
 	else
@@ -168,7 +148,7 @@ int InflatingStreamBuf::readFromDevice(char* buffer, std::streamsize length)
 {
 	if (_eof || !_pIstr) return 0;
 
-	if (_zstr.avail_in == 0)
+	if (_pZstr->avail_in == 0)
 	{
 		int n = 0;
 		if (_pIstr->good())
@@ -176,17 +156,17 @@ int InflatingStreamBuf::readFromDevice(char* buffer, std::streamsize length)
 			_pIstr->read(_buffer, INFLATE_BUFFER_SIZE);
 			n = static_cast<int>(_pIstr->gcount());
 		}
-		_zstr.next_in   = (unsigned char*) _buffer;
-		_zstr.avail_in  = n;
+		_pZstr->next_in   = (unsigned char*) _buffer;
+		_pZstr->avail_in  = n;
 	}
-	_zstr.next_out  = (unsigned char*) buffer;
-	_zstr.avail_out = static_cast<unsigned>(length);
+	_pZstr->next_out  = (unsigned char*) buffer;
+	_pZstr->avail_out = static_cast<unsigned>(length);
 	for (;;)
 	{
-		int rc = inflate(&_zstr, Z_NO_FLUSH);
+		int rc = inflate(_pZstr, Z_NO_FLUSH);
 		if (rc == Z_DATA_ERROR && !_check)
 		{
-			if (_zstr.avail_in == 0)
+			if (_pZstr->avail_in == 0)
 			{
 				if (_pIstr->good())
 					rc = Z_OK;
@@ -197,12 +177,12 @@ int InflatingStreamBuf::readFromDevice(char* buffer, std::streamsize length)
 		if (rc == Z_STREAM_END)
 		{
 			_eof = true;
-			return static_cast<int>(length) - _zstr.avail_out;
+			return static_cast<int>(length) - _pZstr->avail_out;
 		}
 		if (rc != Z_OK) throw IOException(zError(rc));
-		if (_zstr.avail_out == 0)
+		if (_pZstr->avail_out == 0)
 			return static_cast<int>(length);
-		if (_zstr.avail_in == 0)
+		if (_pZstr->avail_in == 0)
 		{
 			int n = 0;
 			if (_pIstr->good())
@@ -212,10 +192,10 @@ int InflatingStreamBuf::readFromDevice(char* buffer, std::streamsize length)
 			}
 			if (n > 0)
 			{
-				_zstr.next_in  = (unsigned char*) _buffer;
-				_zstr.avail_in = n;
+				_pZstr->next_in  = (unsigned char*) _buffer;
+				_pZstr->avail_in = n;
 			}
-			else return static_cast<int>(length) - _zstr.avail_out;
+			else return static_cast<int>(length) - _pZstr->avail_out;
 		}
 	}
 }
@@ -225,33 +205,33 @@ int InflatingStreamBuf::writeToDevice(const char* buffer, std::streamsize length
 {
 	if (length == 0 || !_pOstr) return 0;
 
-	_zstr.next_in   = (unsigned char*) buffer;
-	_zstr.avail_in  = static_cast<unsigned>(length);
-	_zstr.next_out  = (unsigned char*) _buffer;
-	_zstr.avail_out = INFLATE_BUFFER_SIZE;
+	_pZstr->next_in   = (unsigned char*) buffer;
+	_pZstr->avail_in  = static_cast<unsigned>(length);
+	_pZstr->next_out  = (unsigned char*) _buffer;
+	_pZstr->avail_out = INFLATE_BUFFER_SIZE;
 	for (;;)
 	{
-		int rc = inflate(&_zstr, Z_NO_FLUSH);
+		int rc = inflate(_pZstr, Z_NO_FLUSH);
 		if (rc == Z_STREAM_END)
 		{
-			_pOstr->write(_buffer, INFLATE_BUFFER_SIZE - _zstr.avail_out);
+			_pOstr->write(_buffer, INFLATE_BUFFER_SIZE - _pZstr->avail_out);
 			if (!_pOstr->good()) throw IOException("Failed writing inflated data to output stream");
 			break;
 		}
 		if (rc != Z_OK) throw IOException(zError(rc));
-		if (_zstr.avail_out == 0)
+		if (_pZstr->avail_out == 0)
 		{
 			_pOstr->write(_buffer, INFLATE_BUFFER_SIZE);
 			if (!_pOstr->good()) throw IOException("Failed writing inflated data to output stream");
-			_zstr.next_out  = (unsigned char*) _buffer;
-			_zstr.avail_out = INFLATE_BUFFER_SIZE;
+			_pZstr->next_out  = (unsigned char*) _buffer;
+			_pZstr->avail_out = INFLATE_BUFFER_SIZE;
 		}
-		if (_zstr.avail_in == 0)
+		if (_pZstr->avail_in == 0)
 		{
-			_pOstr->write(_buffer, INFLATE_BUFFER_SIZE - _zstr.avail_out);
+			_pOstr->write(_buffer, INFLATE_BUFFER_SIZE - _pZstr->avail_out);
 			if (!_pOstr->good()) throw IOException("Failed writing inflated data to output stream");
-			_zstr.next_out  = (unsigned char*) _buffer;
-			_zstr.avail_out = INFLATE_BUFFER_SIZE;
+			_pZstr->next_out  = (unsigned char*) _buffer;
+			_pZstr->avail_out = INFLATE_BUFFER_SIZE;
 			break;
 		}
 	}
