@@ -19,7 +19,8 @@
 namespace Poco {
 
 
-Notification::Notification()
+Notification::Notification(const std::string& name):
+	_pName(name.empty() ? nullptr : new std::string(name))
 {
 }
 
@@ -31,7 +32,7 @@ Notification::~Notification()
 
 std::string Notification::name() const
 {
-	return typeid(*this).name();
+	return _pName ? *_pName : typeid(*this).name();
 }
 
 
