@@ -83,20 +83,20 @@ void NumberFormatter::append0(std::string& str, int value, int width)
 }
 
 
-void NumberFormatter::appendHex(std::string& str, int value)
+void NumberFormatter::appendHex(std::string& str, int value, bool lowercase)
 {
 	char result[NF_MAX_INT_STRING_LEN];
 	std::size_t sz = NF_MAX_INT_STRING_LEN;
-	uIntToStr(static_cast<unsigned int>(value), 0x10, result, sz);
+	intToStr(static_cast<unsigned int>(value), 0x10, result, sz, false, -1, ' ', 0, lowercase);
 	str.append(result, sz);
 }
 
 
-void NumberFormatter::appendHex(std::string& str, int value, int width)
+void NumberFormatter::appendHex(std::string& str, int value, int width, bool lowercase)
 {
 	char result[NF_MAX_INT_STRING_LEN];
 	std::size_t sz = NF_MAX_INT_STRING_LEN;
-	uIntToStr(static_cast<unsigned int>(value), 0x10, result, sz, false, width, '0');
+	intToStr(static_cast<unsigned int>(value), 0x10, result, sz, false, width, '0', 0, lowercase);
 	str.append(result, sz);
 }
 
@@ -105,7 +105,7 @@ void NumberFormatter::append(std::string& str, unsigned value)
 {
 	char result[NF_MAX_INT_STRING_LEN];
 	std::size_t sz = NF_MAX_INT_STRING_LEN;
-	uIntToStr(value, 10, result, sz);
+	intToStr(value, 10, result, sz);
 	str.append(result, sz);
 }
 
@@ -114,7 +114,7 @@ void NumberFormatter::append(std::string& str, unsigned value, int width)
 {
 	char result[NF_MAX_INT_STRING_LEN];
 	std::size_t sz = NF_MAX_INT_STRING_LEN;
-	uIntToStr(value, 10, result, sz, false, width);
+	intToStr(value, 10, result, sz, false, width);
 	str.append(result, sz);
 }
 
@@ -123,25 +123,25 @@ void NumberFormatter::append0(std::string& str, unsigned int value, int width)
 {
 	char result[NF_MAX_INT_STRING_LEN];
 	std::size_t sz = NF_MAX_INT_STRING_LEN;
-	uIntToStr(value, 10, result, sz, false, width, '0');
+	intToStr(value, 10, result, sz, false, width, '0');
 	str.append(result, sz);
 }
 
 
-void NumberFormatter::appendHex(std::string& str, unsigned value)
+void NumberFormatter::appendHex(std::string& str, unsigned value, bool lowercase)
 {
 	char result[NF_MAX_INT_STRING_LEN];
 	std::size_t sz = NF_MAX_INT_STRING_LEN;
-	uIntToStr(value, 0x10, result, sz);
+	intToStr(value, 0x10, result, sz, false, -1, ' ', 0, lowercase);
 	str.append(result, sz);
 }
 
 
-void NumberFormatter::appendHex(std::string& str, unsigned value, int width)
+void NumberFormatter::appendHex(std::string& str, unsigned value, int width, bool lowercase)
 {
 	char result[NF_MAX_INT_STRING_LEN];
 	std::size_t sz = NF_MAX_INT_STRING_LEN;
-	uIntToStr(value, 0x10, result, sz, false, width, '0');
+	intToStr(value, 0x10, result, sz, false, width, '0', 0, lowercase);
 	str.append(result, sz);
 }
 
@@ -173,20 +173,20 @@ void NumberFormatter::append0(std::string& str, long value, int width)
 }
 
 
-void NumberFormatter::appendHex(std::string& str, long value)
+void NumberFormatter::appendHex(std::string& str, long value, bool lowercase)
 {
 	char result[NF_MAX_INT_STRING_LEN];
 	std::size_t sz = NF_MAX_INT_STRING_LEN;
-	uIntToStr(static_cast<unsigned long>(value), 0x10, result, sz);
+	intToStr(static_cast<unsigned long>(value), 0x10, result, sz, false, -1, ' ', 0, lowercase);
 	str.append(result, sz);
 }
 
 
-void NumberFormatter::appendHex(std::string& str, long value, int width)
+void NumberFormatter::appendHex(std::string& str, long value, int width, bool lowercase)
 {
 	char result[NF_MAX_INT_STRING_LEN];
 	std::size_t sz = NF_MAX_INT_STRING_LEN;
-	uIntToStr(static_cast<unsigned long>(value), 0x10, result, sz, false, width, '0');
+	intToStr(static_cast<unsigned long>(value), 0x10, result, sz, false, width, '0', 0, lowercase);
 	str.append(result, sz);
 }
 
@@ -195,7 +195,7 @@ void NumberFormatter::append(std::string& str, unsigned long value)
 {
 	char result[NF_MAX_INT_STRING_LEN];
 	std::size_t sz = NF_MAX_INT_STRING_LEN;
-	uIntToStr(value, 10, result, sz);
+	intToStr(value, 10, result, sz);
 	str.append(result, sz);
 }
 
@@ -204,7 +204,7 @@ void NumberFormatter::append(std::string& str, unsigned long value, int width)
 {
 	char result[NF_MAX_INT_STRING_LEN];
 	std::size_t sz = NF_MAX_INT_STRING_LEN;
-	uIntToStr(value, 10, result, sz, false, width, '0');
+	intToStr(value, 10, result, sz, false, width, '0');
 	str.append(result, sz);
 }
 
@@ -213,25 +213,25 @@ void NumberFormatter::append0(std::string& str, unsigned long value, int width)
 {
 	char result[NF_MAX_INT_STRING_LEN];
 	std::size_t sz = NF_MAX_INT_STRING_LEN;
-	uIntToStr(value, 10, result, sz, false, width, '0');
+	intToStr(value, 10, result, sz, false, width, '0');
 	str.append(result, sz);
 }
 
 
-void NumberFormatter::appendHex(std::string& str, unsigned long value)
+void NumberFormatter::appendHex(std::string& str, unsigned long value, bool lowercase)
 {
 	char result[NF_MAX_INT_STRING_LEN];
 	std::size_t sz = NF_MAX_INT_STRING_LEN;
-	uIntToStr(value, 0x10, result, sz);
+	intToStr(value, 0x10, result, sz, false, -1, ' ', 0, lowercase);
 	str.append(result, sz);
 }
 
 
-void NumberFormatter::appendHex(std::string& str, unsigned long value, int width)
+void NumberFormatter::appendHex(std::string& str, unsigned long value, int width, bool lowercase)
 {
 	char result[NF_MAX_INT_STRING_LEN];
 	std::size_t sz = NF_MAX_INT_STRING_LEN;
-	uIntToStr(value, 0x10, result, sz, false, width, '0');
+	intToStr(value, 0x10, result, sz, false, width, '0', 0, lowercase);
 	str.append(result, sz);
 }
 
@@ -267,20 +267,20 @@ void NumberFormatter::append0(std::string& str, long long value, int width)
 }
 
 
-void NumberFormatter::appendHex(std::string& str, long long value)
+void NumberFormatter::appendHex(std::string& str, long long value, bool lowercase)
 {
 	char result[NF_MAX_INT_STRING_LEN];
 	std::size_t sz = NF_MAX_INT_STRING_LEN;
-	uIntToStr(static_cast<unsigned long long>(value), 0x10, result, sz);
+	intToStr(static_cast<unsigned long long>(value), 0x10, result, sz, false, -1, ' ', 0, lowercase);
 	str.append(result, sz);
 }
 
 
-void NumberFormatter::appendHex(std::string& str, long long value, int width)
+void NumberFormatter::appendHex(std::string& str, long long value, int width, bool lowercase)
 {
 	char result[NF_MAX_INT_STRING_LEN];
 	std::size_t sz = NF_MAX_INT_STRING_LEN;
-	uIntToStr(static_cast<unsigned long long>(value), 0x10, result, sz, false, width, '0');
+	intToStr(static_cast<unsigned long long>(value), 0x10, result, sz, false, width, '0', 0, lowercase);
 	str.append(result, sz);
 }
 
@@ -289,7 +289,7 @@ void NumberFormatter::append(std::string& str, unsigned long long value)
 {
 	char result[NF_MAX_INT_STRING_LEN];
 	std::size_t sz = NF_MAX_INT_STRING_LEN;
-	uIntToStr(value, 10, result, sz);
+	intToStr(value, 10, result, sz);
 	str.append(result, sz);
 }
 
@@ -298,7 +298,7 @@ void NumberFormatter::append(std::string& str, unsigned long long value, int wid
 {
 	char result[NF_MAX_INT_STRING_LEN];
 	std::size_t sz = NF_MAX_INT_STRING_LEN;
-	uIntToStr(value, 10, result, sz, false, width, '0');
+	intToStr(value, 10, result, sz, false, width, '0');
 	str.append(result, sz);
 }
 
@@ -307,25 +307,25 @@ void NumberFormatter::append0(std::string& str, unsigned long long value, int wi
 {
 	char result[NF_MAX_INT_STRING_LEN];
 	std::size_t sz = NF_MAX_INT_STRING_LEN;
-	uIntToStr(value, 10, result, sz, false, width, '0');
+	intToStr(value, 10, result, sz, false, width, '0');
 	str.append(result, sz);
 }
 
 
-void NumberFormatter::appendHex(std::string& str, unsigned long long value)
+void NumberFormatter::appendHex(std::string& str, unsigned long long value, bool lowercase)
 {
 	char result[NF_MAX_INT_STRING_LEN];
 	std::size_t sz = NF_MAX_INT_STRING_LEN;
-	uIntToStr(value, 0x10, result, sz);
+	intToStr(value, 0x10, result, sz, false, -1, ' ', 0, lowercase);
 	str.append(result, sz);
 }
 
 
-void NumberFormatter::appendHex(std::string& str, unsigned long long value, int width)
+void NumberFormatter::appendHex(std::string& str, unsigned long long value, int width, bool lowercase)
 {
 	char result[NF_MAX_INT_STRING_LEN];
 	std::size_t sz = NF_MAX_INT_STRING_LEN;
-	uIntToStr(value, 0x10, result, sz, false, width, '0');
+	intToStr(value, 0x10, result, sz, false, width, '0', 0, lowercase);
 	str.append(result, sz);
 }
 
@@ -360,20 +360,20 @@ void NumberFormatter::append0(std::string& str, Int64 value, int width)
 }
 
 
-void NumberFormatter::appendHex(std::string& str, Int64 value)
+void NumberFormatter::appendHex(std::string& str, Int64 value, bool lowercase)
 {
 	char result[NF_MAX_INT_STRING_LEN];
 	std::size_t sz = NF_MAX_INT_STRING_LEN;
-	uIntToStr(static_cast<UInt64>(value), 0x10, result, sz);
+	intToStr(static_cast<UInt64>(value), 0x10, result, sz, false, -1, ' ', 0, lowercase);
 	str.append(result, sz);
 }
 
 
-void NumberFormatter::appendHex(std::string& str, Int64 value, int width)
+void NumberFormatter::appendHex(std::string& str, Int64 value, int width, bool lowercase)
 {
 	char result[NF_MAX_INT_STRING_LEN];
 	std::size_t sz = NF_MAX_INT_STRING_LEN;
-	uIntToStr(static_cast<UInt64>(value), 0x10, result, sz, false, width, '0');
+	intToStr(static_cast<UInt64>(value), 0x10, result, sz, false, width, '0', 0, lowercase);
 	str.append(result, sz);
 }
 
@@ -382,7 +382,7 @@ void NumberFormatter::append(std::string& str, UInt64 value)
 {
 	char result[NF_MAX_INT_STRING_LEN];
 	std::size_t sz = NF_MAX_INT_STRING_LEN;
-	uIntToStr(value, 10, result, sz);
+	intToStr(value, 10, result, sz);
 	str.append(result, sz);
 }
 
@@ -391,7 +391,7 @@ void NumberFormatter::append(std::string& str, UInt64 value, int width)
 {
 	char result[NF_MAX_INT_STRING_LEN];
 	std::size_t sz = NF_MAX_INT_STRING_LEN;
-	uIntToStr(value, 10, result, sz, false, width, '0');
+	intToStr(value, 10, result, sz, false, width, '0');
 	str.append(result, sz);
 }
 
@@ -400,25 +400,25 @@ void NumberFormatter::append0(std::string& str, UInt64 value, int width)
 {
 	char result[NF_MAX_INT_STRING_LEN];
 	std::size_t sz = NF_MAX_INT_STRING_LEN;
-	uIntToStr(value, 10, result, sz, false, width, '0');
+	intToStr(value, 10, result, sz, false, width, '0');
 	str.append(result, sz);
 }
 
 
-void NumberFormatter::appendHex(std::string& str, UInt64 value)
+void NumberFormatter::appendHex(std::string& str, UInt64 value, bool lowercase)
 {
 	char result[NF_MAX_INT_STRING_LEN];
 	std::size_t sz = NF_MAX_INT_STRING_LEN;
-	uIntToStr(value, 0x10, result, sz);
+	intToStr(value, 0x10, result, sz, false, -1, ' ', 0, lowercase);
 	str.append(result, sz);
 }
 
 
-void NumberFormatter::appendHex(std::string& str, UInt64 value, int width)
+void NumberFormatter::appendHex(std::string& str, UInt64 value, int width, bool lowercase)
 {
 	char result[NF_MAX_INT_STRING_LEN];
 	std::size_t sz = NF_MAX_INT_STRING_LEN;
-	uIntToStr(value, 0x10, result, sz, false, width, '0');
+	intToStr(value, 0x10, result, sz, false, width, '0', 0, lowercase);
 	str.append(result, sz);
 }
 
@@ -477,12 +477,124 @@ void NumberFormatter::append(std::string& str, const void* ptr)
 {
 	char buffer[24];
 #if defined(POCO_PTR_IS_64_BIT)
-	std::sprintf(buffer, "%016" PRIXPTR, (UIntPtr) ptr);
+	std::snprintf(buffer, sizeof(buffer), "%016" PRIXPTR, (UIntPtr) ptr);
 #else
-	std::sprintf(buffer, "%08" PRIXPTR, (UIntPtr) ptr);
+	std::snprintf(buffer, sizeof(buffer), "%08" PRIXPTR, (UIntPtr) ptr);
 #endif
 	str.append(buffer);
 }
 
 
+//
+// Deprecated functions
+//
+
+
+std::string NumberFormatter::formatHex(int value, bool prefix)
+{
+	return formatHex(static_cast<unsigned int>(value), prefix ? Options::PREFIX : Options::DEFAULT);
+}
+
+
+std::string NumberFormatter::formatHex(int value, int width, bool prefix)
+{
+	return formatHex(static_cast<unsigned int>(value), width, prefix ? Options::PREFIX : Options::DEFAULT);
+}
+
+
+std::string NumberFormatter::formatHex(unsigned value, bool prefix)
+{
+	return formatHex(value, prefix ? Options::PREFIX : Options::DEFAULT);
+}
+
+
+std::string NumberFormatter::formatHex(unsigned value, int width, bool prefix)
+{
+	return formatHex(value, width, prefix ? Options::PREFIX : Options::DEFAULT);
+}
+
+
+std::string NumberFormatter::formatHex(long value, bool prefix)
+{
+	return formatHex(static_cast<unsigned long>(value), prefix ? Options::PREFIX : Options::DEFAULT);
+}
+
+
+std::string NumberFormatter::formatHex(long value, int width, bool prefix)
+{
+	return formatHex(static_cast<unsigned long>(value), width, prefix ? Options::PREFIX : Options::DEFAULT);
+}
+
+
+std::string NumberFormatter::formatHex(unsigned long value, bool prefix)
+{
+	return formatHex(value, prefix ? Options::PREFIX : Options::DEFAULT);
+}
+
+
+std::string NumberFormatter::formatHex(unsigned long value, int width, bool prefix)
+{
+	return formatHex(value, width, prefix ? Options::PREFIX : Options::DEFAULT);
+}
+
+
+#ifdef POCO_HAVE_INT64
+#ifdef POCO_INT64_IS_LONG
+
+
+std::string NumberFormatter::formatHex(long long value, bool prefix)
+{
+	return formatHex(static_cast<unsigned long long>(value), prefix ? Options::PREFIX : Options::DEFAULT);
+}
+
+
+std::string NumberFormatter::formatHex(long long value, int width, bool prefix)
+{
+	return formatHex(static_cast<unsigned long long>(value), width, prefix ? Options::PREFIX : Options::DEFAULT);
+}
+
+
+std::string NumberFormatter::formatHex(unsigned long long value, bool prefix)
+{
+	return formatHex(value, prefix ? Options::PREFIX : Options::DEFAULT);
+}
+
+
+std::string NumberFormatter::formatHex(unsigned long long value, int width, bool prefix)
+{
+	return formatHex(value, width, prefix ? Options::PREFIX : Options::DEFAULT);
+}
+
+
+#else // ifndef POCO_LONG_IS_64_BIT
+
+
+std::string NumberFormatter::formatHex(Int64 value, bool prefix)
+{
+	return formatHex(static_cast<UInt64>(value), prefix ? Options::PREFIX : Options::DEFAULT);
+}
+
+
+std::string NumberFormatter::formatHex(Int64 value, int width, bool prefix)
+{
+	return formatHex(static_cast<UInt64>(value), width, prefix ? Options::PREFIX : Options::DEFAULT);
+}
+
+
+std::string NumberFormatter::formatHex(UInt64 value, bool prefix)
+{
+	return formatHex(value, prefix ? Options::PREFIX : Options::DEFAULT);
+}
+
+
+std::string NumberFormatter::formatHex(UInt64 value, int width, bool prefix)
+{
+	return formatHex(value, width, prefix ? Options::PREFIX : Options::DEFAULT);
+}
+
+
+#endif // ifdef POCO_INT64_IS_LONG
+#endif // ifdef POCO_HAVE_INT64
+
+
 } // namespace Poco
