@@ -16,12 +16,8 @@
 
 
 #if defined(POCO_OS_FAMILY_WINDOWS)
-#if defined(_WIN32_WCE)
-#include "RWLock_WINCE.cpp"
-#else
 #include "RWLock_WIN32.cpp"
-#endif
-#elif defined(POCO_ANDROID)
+#elif POCO_OS == POCO_OS_ANDROID
 #include "RWLock_Android.cpp"
 #elif defined(POCO_VXWORKS)
 #include "RWLock_VX.cpp"
@@ -37,7 +33,7 @@ RWLock::RWLock()
 {
 }
 
-	
+
 RWLock::~RWLock()
 {
 }
