@@ -59,7 +59,8 @@ void SharedLibraryImpl::unloadImpl()
 
 bool SharedLibraryImpl::isLoadedImpl() const
 {
-	return _handle != 0; 
+	FastMutex::ScopedLock lock(_mutex);
+	return _handle != 0;
 }
 
 
@@ -91,4 +92,10 @@ std::string SharedLibraryImpl::suffixImpl()
 }
 
 
+bool SharedLibraryImpl::setSearchPathImpl(const std::string&)
+{
+	return false;
+}
+
+
 } // namespace Poco
