@@ -44,10 +44,10 @@ void SharedLibraryImpl::loadImpl(const std::string& path, int /*flags*/)
 
 	if (_handle) throw LibraryAlreadyLoadedException(_path);
 	DWORD flags(0);
-#if !defined(_WIN32_WCE)
+
 	Path p(path);
 	if (p.isAbsolute()) flags |= LOAD_WITH_ALTERED_SEARCH_PATH;
-#endif
+
 	std::wstring upath;
 	UnicodeConverter::toUTF16(path, upath);
 	_handle = LoadLibraryExW(upath.c_str(), 0, flags);
@@ -55,7 +55,7 @@ void SharedLibraryImpl::loadImpl(const std::string& path, int /*flags*/)
 	{
 		DWORD errn = Error::last();
 		std::string err;
-		Poco::format(err, "Error %ul while loading [%s]: [%s]", errn, path, Poco::trim(Error::getMessage(errn)));
+		Poco::format(err, "Error %lu while loading [%s]: [%s]", errn, path, Poco::trim(Error::getMessage(errn)));
 		throw LibraryLoadException(err);
 	}
 	_path = path;
@@ -77,6 +77,7 @@ void SharedLibraryImpl::unloadImpl()
 
 bool SharedLibraryImpl::isLoadedImpl() const
 {
+	FastMutex::ScopedLock lock(_mutex);
 	return _handle != 0;
 }
 
@@ -87,13 +88,7 @@ void* SharedLibraryImpl::findSymbolImpl(const std::string& name)
 
 	if (_handle)
 	{
-#if defined(_WIN32_WCE)
-		std::wstring uname;
-		UnicodeConverter::toUTF16(name, uname);
-		return (void*) GetProcAddressW((HMODULE) _handle, uname.c_str());
-#else
 		return (void*) GetProcAddress((HMODULE) _handle, name.c_str());
-#endif
 	}
 	else return 0;
 }
