@@ -22,11 +22,7 @@
 
 
 #if defined(POCO_OS_FAMILY_WINDOWS)
-#if defined(_WIN32_WCE)
-#include "Timezone_WINCE.cpp"
-#else
 #include "Timezone_WIN32.cpp"
-#endif
 #elif defined(POCO_VXWORKS)
 #include "Timezone_VX.cpp"
 #else
