@@ -31,9 +31,11 @@ using Poco::StreamChannel;
 using Poco::Formatter;
 using Poco::Message;
 using Poco::AutoPtr;
+using Poco::Thread;
+using Poco::Runnable;
 
 
-class SimpleFormatter: public Formatter
+class SimpleFormatter : public Formatter
 {
 public:
 	void format(const Message& msg, std::string& text)
@@ -45,7 +47,33 @@ public:
 };
 
 
-ChannelTest::ChannelTest(const std::string& name): CppUnit::TestCase(name)
+class LogRunnable : public Runnable
+{
+public:
+	LogRunnable(AutoPtr<AsyncChannel> pAsync) :
+		_pAsync(pAsync),
+		_stop(false)
+	{
+	}
+
+	void run()
+	{
+		Message msg;
+		while (!_stop) _pAsync->log(msg);
+	}
+
+	void stop()
+	{
+		_stop = true;
+	}
+
+private:
+	AutoPtr<AsyncChannel> _pAsync;
+	std::atomic<bool> _stop;
+};
+
+
+ChannelTest::ChannelTest(const std::string& name) : CppUnit::TestCase(name)
 {
 }
 
@@ -56,27 +84,50 @@ ChannelTest::~ChannelTest()
 
 
 void ChannelTest::testSplitter()
+{
+	AutoPtr<TestChannel> pChannel1 = new TestChannel;
+	AutoPtr<TestChannel> pChannel2 = new TestChannel;
+	AutoPtr<SplitterChannel> pSplitter = new SplitterChannel;
+	pSplitter->addChannel(pChannel1);
+	pSplitter->addChannel(pChannel2);
+	Message msg;
+	pSplitter->log(msg);
+	assertTrue(pChannel1->list().size() == 1);
+	assertTrue(pChannel2->list().size() == 1);
+}
+
+void ChannelTest::testSplitterAddSameChannelTwice()
 {
 	AutoPtr<TestChannel> pChannel = new TestChannel;
 	AutoPtr<SplitterChannel> pSplitter = new SplitterChannel;
 	pSplitter->addChannel(pChannel);
 	pSplitter->addChannel(pChannel);
+
+	assertTrue(pSplitter->count() == 1);
+
 	Message msg;
 	pSplitter->log(msg);
-	assertTrue (pChannel->list().size() == 2);
-}
 
+	pSplitter->removeChannel(pChannel);
+
+	assertTrue(pSplitter->count() == 0);
+}
 
 void ChannelTest::testAsync()
 {
 	AutoPtr<TestChannel> pChannel = new TestChannel;
 	AutoPtr<AsyncChannel> pAsync = new AsyncChannel(pChannel);
+	LogRunnable lr(pAsync);
 	pAsync->open();
+	Thread t;
+	t.start(lr);
 	Message msg;
 	pAsync->log(msg);
 	pAsync->log(msg);
 	pAsync->close();
-	assertTrue (pChannel->list().size() == 2);
+	lr.stop();
+	t.join();
+	assertTrue(pChannel->list().size() >= 2);
 }
 
 
@@ -87,8 +138,8 @@ void ChannelTest::testFormatting()
 	AutoPtr<FormattingChannel> pFormatterChannel = new FormattingChannel(pFormatter, pChannel);
 	Message msg("Source", "Text", Message::PRIO_INFORMATION);
 	pFormatterChannel->log(msg);
-	assertTrue (pChannel->list().size() == 1);
-	assertTrue (pChannel->list().begin()->getText() == "Source: Text");
+	assertTrue(pChannel->list().size() == 1);
+	assertTrue(pChannel->list().begin()->getText() == "Source: Text");
 }
 
 
@@ -110,7 +161,7 @@ void ChannelTest::testStream()
 	AutoPtr<FormattingChannel> pFormatterChannel = new FormattingChannel(pFormatter, pChannel);
 	Message msg("Source", "Text", Message::PRIO_INFORMATION);
 	pFormatterChannel->log(msg);
-	assertTrue (str.str().find("Source: Text") == 0);
+	assertTrue(str.str().find("Source: Text") == 0);
 }
 
 
@@ -129,6 +180,7 @@ CppUnit::Test* ChannelTest::suite()
 	CppUnit::TestSuite* pSuite = new CppUnit::TestSuite("ChannelTest");
 
 	CppUnit_addTest(pSuite, ChannelTest, testSplitter);
+	CppUnit_addTest(pSuite, ChannelTest, testSplitterAddSameChannelTwice);
 	CppUnit_addTest(pSuite, ChannelTest, testAsync);
 	CppUnit_addTest(pSuite, ChannelTest, testFormatting);
 	CppUnit_addTest(pSuite, ChannelTest, testConsole);
