@@ -41,6 +41,8 @@ public:
 	void testIncrementDecrement();
 	void testUTC();
 	void testLeapSeconds();
+	void testTM();
+	void testInvalid();
 
 	void setUp();
 	void tearDown();
