@@ -24,7 +24,7 @@
 using Poco::DirectoryWatcher;
 
 
-DirectoryWatcherTest::DirectoryWatcherTest(const std::string& name): 
+DirectoryWatcherTest::DirectoryWatcherTest(const std::string& name):
 	CppUnit::TestCase(name),
 	_error(false)
 {
@@ -39,23 +39,24 @@ DirectoryWatcherTest::~DirectoryWatcherTest()
 void DirectoryWatcherTest::testAdded()
 {
 	DirectoryWatcher dw(path().toString(), DirectoryWatcher::DW_FILTER_ENABLE_ALL, 2);
-	
+
 	dw.itemAdded += Poco::delegate(this, &DirectoryWatcherTest::onItemAdded);
 	dw.itemRemoved += Poco::delegate(this, &DirectoryWatcherTest::onItemRemoved);
 	dw.itemModified += Poco::delegate(this, &DirectoryWatcherTest::onItemModified);
 	dw.itemMovedFrom += Poco::delegate(this, &DirectoryWatcherTest::onItemMovedFrom);
 	dw.itemMovedTo += Poco::delegate(this, &DirectoryWatcherTest::onItemMovedTo);
-	
+
 	Poco::Thread::sleep(1000);
-	
+
 	Poco::Path p(path());
 	p.setFileName("test.txt");
 	Poco::FileOutputStream fos(p.toString());
 	fos << "Hello, world!";
 	fos.close();
-	
+
 	Poco::Thread::sleep(2000*dw.scanInterval());
-	
+
+	Poco::Mutex::ScopedLock l(_mutex);
 	assertTrue (_events.size() >= 1);
 	assertTrue (_events[0].callback == "onItemAdded");
 	assertTrue (Poco::Path(_events[0].path).getFileName() == "test.txt");
@@ -73,20 +74,21 @@ void DirectoryWatcherTest::testRemoved()
 	fos.close();
 
 	DirectoryWatcher dw(path().toString(), DirectoryWatcher::DW_FILTER_ENABLE_ALL, 2);
-	
+
 	dw.itemAdded += Poco::delegate(this, &DirectoryWatcherTest::onItemAdded);
 	dw.itemRemoved += Poco::delegate(this, &DirectoryWatcherTest::onItemRemoved);
 	dw.itemModified += Poco::delegate(this, &DirectoryWatcherTest::onItemModified);
 	dw.itemMovedFrom += Poco::delegate(this, &DirectoryWatcherTest::onItemMovedFrom);
 	dw.itemMovedTo += Poco::delegate(this, &DirectoryWatcherTest::onItemMovedTo);
-	
+
 	Poco::Thread::sleep(1000);
-	
+
 	Poco::File f(p.toString());
 	f.remove();
-	
+
 	Poco::Thread::sleep(2000*dw.scanInterval());
-	
+
+	Poco::Mutex::ScopedLock l(_mutex);
 	assertTrue (_events.size() >= 1);
 	assertTrue (_events[0].callback == "onItemRemoved");
 	assertTrue (Poco::Path(_events[0].path).getFileName() == "test.txt");
@@ -104,21 +106,22 @@ void DirectoryWatcherTest::testModified()
 	fos.close();
 
 	DirectoryWatcher dw(path().toString(), DirectoryWatcher::DW_FILTER_ENABLE_ALL, 2);
-	
+
 	dw.itemAdded += Poco::delegate(this, &DirectoryWatcherTest::onItemAdded);
 	dw.itemRemoved += Poco::delegate(this, &DirectoryWatcherTest::onItemRemoved);
 	dw.itemModified += Poco::delegate(this, &DirectoryWatcherTest::onItemModified);
 	dw.itemMovedFrom += Poco::delegate(this, &DirectoryWatcherTest::onItemMovedFrom);
 	dw.itemMovedTo += Poco::delegate(this, &DirectoryWatcherTest::onItemMovedTo);
-	
+
 	Poco::Thread::sleep(1000);
-	
+
 	Poco::FileOutputStream fos2(p.toString(), std::ios::app);
 	fos2 << "Again!";
 	fos2.close();
-	
+
 	Poco::Thread::sleep(2000*dw.scanInterval());
-	
+
+	Poco::Mutex::ScopedLock l(_mutex);
 	assertTrue (_events.size() >= 1);
 	assertTrue (_events[0].callback == "onItemModified");
 	assertTrue (Poco::Path(_events[0].path).getFileName() == "test.txt");
@@ -136,22 +139,23 @@ void DirectoryWatcherTest::testMoved()
 	fos.close();
 
 	DirectoryWatcher dw(path().toString(), DirectoryWatcher::DW_FILTER_ENABLE_ALL, 2);
-	
+
 	dw.itemAdded += Poco::delegate(this, &DirectoryWatcherTest::onItemAdded);
 	dw.itemRemoved += Poco::delegate(this, &DirectoryWatcherTest::onItemRemoved);
 	dw.itemModified += Poco::delegate(this, &DirectoryWatcherTest::onItemModified);
 	dw.itemMovedFrom += Poco::delegate(this, &DirectoryWatcherTest::onItemMovedFrom);
 	dw.itemMovedTo += Poco::delegate(this, &DirectoryWatcherTest::onItemMovedTo);
-	
+
 	Poco::Thread::sleep(1000);
-	
+
 	Poco::Path p2(path());
 	p2.setFileName("test2.txt");
 	Poco::File f(p.toString());
 	f.renameTo(p2.toString());
-	
+
 	Poco::Thread::sleep(2000*dw.scanInterval());
-	
+
+	Poco::Mutex::ScopedLock l(_mutex);
 	if (dw.supportsMoveEvents())
 	{
 		assertTrue (_events.size() >= 2);
@@ -188,11 +192,153 @@ void DirectoryWatcherTest::testMoved()
 }
 
 
+void DirectoryWatcherTest::testSuspend()
+{
+	Poco::Path p(path());
+	p.setFileName("test.txt");
+	Poco::FileOutputStream fos(p.toString());
+	fos << "Hello, world!";
+	fos.close();
+
+	DirectoryWatcher dw(path().toString(), DirectoryWatcher::DW_FILTER_ENABLE_ALL, 2);
+
+	dw.itemAdded += Poco::delegate(this, &DirectoryWatcherTest::onItemAdded);
+	dw.itemRemoved += Poco::delegate(this, &DirectoryWatcherTest::onItemRemoved);
+	dw.itemModified += Poco::delegate(this, &DirectoryWatcherTest::onItemModified);
+	dw.itemMovedFrom += Poco::delegate(this, &DirectoryWatcherTest::onItemMovedFrom);
+	dw.itemMovedTo += Poco::delegate(this, &DirectoryWatcherTest::onItemMovedTo);
+
+	Poco::Thread::sleep(1000);
+
+	dw.suspendEvents();
+
+	Poco::FileOutputStream fos2(p.toString(), std::ios::app);
+	fos2 << "Again!";
+	fos2.close();
+
+	Poco::Thread::sleep(2000*dw.scanInterval());
+
+	Poco::Mutex::ScopedLock l(_mutex);
+	assertTrue (_events.size() == 0);
+	assertTrue (!_error);
+}
+
+
+void DirectoryWatcherTest::testResume()
+{
+	Poco::Path p(path());
+	p.setFileName("test.txt");
+	Poco::FileOutputStream fos(p.toString());
+	fos << "Hello, world!";
+	fos.close();
+
+	DirectoryWatcher dw(path().toString(), DirectoryWatcher::DW_FILTER_ENABLE_ALL, 2);
+
+	dw.itemAdded += Poco::delegate(this, &DirectoryWatcherTest::onItemAdded);
+	dw.itemRemoved += Poco::delegate(this, &DirectoryWatcherTest::onItemRemoved);
+	dw.itemModified += Poco::delegate(this, &DirectoryWatcherTest::onItemModified);
+	dw.itemMovedFrom += Poco::delegate(this, &DirectoryWatcherTest::onItemMovedFrom);
+	dw.itemMovedTo += Poco::delegate(this, &DirectoryWatcherTest::onItemMovedTo);
+
+	Poco::Thread::sleep(1000);
+
+	dw.suspendEvents();
+
+	Poco::FileOutputStream fos2(p.toString(), std::ios::app);
+	fos2 << "Again!";
+	fos2.close();
+
+	{
+		Poco::Mutex::ScopedLock l(_mutex);
+		assertTrue (_events.size() == 0);
+		assertTrue (!_error);
+	}
+
+	dw.resumeEvents();
+
+	Poco::FileOutputStream fos3(p.toString(), std::ios::app);
+	fos3 << "Now it works!";
+	fos3.close();
+
+	Poco::Thread::sleep(2000*dw.scanInterval());
+
+	Poco::Mutex::ScopedLock l(_mutex);
+	assertTrue (_events.size() >= 1);
+	assertTrue (_events[0].callback == "onItemModified");
+	assertTrue (Poco::Path(_events[0].path).getFileName() == "test.txt");
+	assertTrue (_events[0].type == DirectoryWatcher::DW_ITEM_MODIFIED);
+	assertTrue (!_error);
+}
+
+
+void DirectoryWatcherTest::testSuspendMultipleTimes()
+{
+	Poco::Path p(path());
+	p.setFileName("test.txt");
+	Poco::FileOutputStream fos(p.toString());
+	fos << "Hello, world!";
+	fos.close();
+
+	DirectoryWatcher dw(path().toString(), DirectoryWatcher::DW_FILTER_ENABLE_ALL, 2);
+
+	dw.itemAdded += Poco::delegate(this, &DirectoryWatcherTest::onItemAdded);
+	dw.itemRemoved += Poco::delegate(this, &DirectoryWatcherTest::onItemRemoved);
+	dw.itemModified += Poco::delegate(this, &DirectoryWatcherTest::onItemModified);
+	dw.itemMovedFrom += Poco::delegate(this, &DirectoryWatcherTest::onItemMovedFrom);
+	dw.itemMovedTo += Poco::delegate(this, &DirectoryWatcherTest::onItemMovedTo);
+
+	Poco::Thread::sleep(1000);
+
+	dw.suspendEvents();
+	dw.suspendEvents();
+	dw.suspendEvents();
+
+	Poco::FileOutputStream fos2(p.toString(), std::ios::app);
+	fos2 << "Not notified!";
+	fos2.close();
+
+	Poco::Thread::sleep(2000*dw.scanInterval());
+
+	assertTrue (_events.size() == 0);
+	assertTrue (!_error);
+
+	dw.resumeEvents();
+
+	Poco::FileOutputStream fos3(p.toString(), std::ios::app);
+	fos3 << "Still not notified!";
+	fos3.close();
+
+	Poco::Thread::sleep(2000*dw.scanInterval());
+
+	{
+		Poco::Mutex::ScopedLock l(_mutex);
+		assertTrue (_events.size() == 0);
+		assertTrue (!_error);
+	}
+
+	dw.resumeEvents();
+	dw.resumeEvents();
+
+	Poco::FileOutputStream fos4(p.toString(), std::ios::app);
+	fos4 << "Now it works!";
+	fos4.close();
+
+	Poco::Thread::sleep(2000*dw.scanInterval());
+
+	Poco::Mutex::ScopedLock l(_mutex);
+	assertTrue (_events.size() >= 1);
+	assertTrue (_events[0].callback == "onItemModified");
+	assertTrue (Poco::Path(_events[0].path).getFileName() == "test.txt");
+	assertTrue (_events[0].type == DirectoryWatcher::DW_ITEM_MODIFIED);
+	assertTrue (!_error);
+}
+
+
 void DirectoryWatcherTest::setUp()
 {
 	_error = false;
 	_events.clear();
-	
+
 	try
 	{
 		Poco::File d(path().toString());
@@ -226,6 +372,8 @@ void DirectoryWatcherTest::onItemAdded(const Poco::DirectoryWatcher::DirectoryEv
 	de.callback = "onItemAdded";
 	de.path = ev.item.path();
 	de.type = ev.event;
+
+	Poco::Mutex::ScopedLock l(_mutex);
 	_events.push_back(de);
 }
 
@@ -236,6 +384,8 @@ void DirectoryWatcherTest::onItemRemoved(const Poco::DirectoryWatcher::Directory
 	de.callback = "onItemRemoved";
 	de.path = ev.item.path();
 	de.type = ev.event;
+
+	Poco::Mutex::ScopedLock l(_mutex);
 	_events.push_back(de);
 }
 
@@ -246,6 +396,8 @@ void DirectoryWatcherTest::onItemModified(const Poco::DirectoryWatcher::Director
 	de.callback = "onItemModified";
 	de.path = ev.item.path();
 	de.type = ev.event;
+
+	Poco::Mutex::ScopedLock l(_mutex);
 	_events.push_back(de);
 }
 
@@ -256,6 +408,8 @@ void DirectoryWatcherTest::onItemMovedFrom(const Poco::DirectoryWatcher::Directo
 	de.callback = "onItemMovedFrom";
 	de.path = ev.item.path();
 	de.type = ev.event;
+
+	Poco::Mutex::ScopedLock l(_mutex);
 	_events.push_back(de);
 }
 
@@ -266,12 +420,15 @@ void DirectoryWatcherTest::onItemMovedTo(const Poco::DirectoryWatcher::Directory
 	de.callback = "onItemMovedTo";
 	de.path = ev.item.path();
 	de.type = ev.event;
+
+	Poco::Mutex::ScopedLock l(_mutex);
 	_events.push_back(de);
 }
 
 
 void DirectoryWatcherTest::onError(const Poco::Exception& exc)
 {
+
 	_error = true;
 }
 
@@ -292,6 +449,9 @@ CppUnit::Test* DirectoryWatcherTest::suite()
 	CppUnit_addTest(pSuite, DirectoryWatcherTest, testRemoved);
 	CppUnit_addTest(pSuite, DirectoryWatcherTest, testModified);
 	CppUnit_addTest(pSuite, DirectoryWatcherTest, testMoved);
+	CppUnit_addTest(pSuite, DirectoryWatcherTest, testSuspend);
+	CppUnit_addTest(pSuite, DirectoryWatcherTest, testResume);
+	CppUnit_addTest(pSuite, DirectoryWatcherTest, testSuspendMultipleTimes);
 
 	return pSuite;
 }
