@@ -443,7 +443,7 @@ void GlobTest::testGlob()
 	files.clear();
 	Glob::glob("globtest/*/", files);
 	translatePaths(files);
-	assertTrue (files.size() == 3);
+	assertEqual (3, files.size());
 	assertTrue (files.find("globtest/include/") != files.end());
 	assertTrue (files.find("globtest/src/") != files.end());
 	assertTrue (files.find("globtest/testsuite/") != files.end());
@@ -451,7 +451,7 @@ void GlobTest::testGlob()
 	files.clear();
 	Glob::glob("globtest/testsuite/src/*", "globtest/testsuite/", files);
 	translatePaths(files);
-	assertTrue (files.size() == 3);
+	assertEqual (3, files.size());
 	assertTrue (files.find("globtest/testsuite/src/test.h") != files.end());
 	assertTrue (files.find("globtest/testsuite/src/test.c") != files.end());
 	assertTrue (files.find("globtest/testsuite/src/main.c") != files.end());
@@ -460,7 +460,7 @@ void GlobTest::testGlob()
 	files.clear();
 	Glob::glob("globtest/../*/testsuite/*/", files);
 	translatePaths(files);
-	assertTrue (files.size() == 1);
+	assertEqual (1, files.size());
 
 	File dir("globtest");
 	dir.remove(true);
