@@ -9,8 +9,10 @@
 
 
 #include "HashingTestSuite.h"
+#if defined(POCO_TEST_DEPRECATED)
 #include "HashTableTest.h"
 #include "SimpleHashTableTest.h"
+#endif
 #include "LinearHashTableTest.h"
 #include "HashSetTest.h"
 #include "HashMapTest.h"
@@ -20,8 +22,10 @@ CppUnit::Test* HashingTestSuite::suite()
 {
 	CppUnit::TestSuite* pSuite = new CppUnit::TestSuite("HashingTestSuite");
 
+#if defined(POCO_TEST_DEPRECATED)
 	pSuite->addTest(HashTableTest::suite());
 	pSuite->addTest(SimpleHashTableTest::suite());
+#endif
 	pSuite->addTest(LinearHashTableTest::suite());
 	pSuite->addTest(HashSetTest::suite());
 	pSuite->addTest(HashMapTest::suite());
