@@ -30,6 +30,7 @@ public:
 	void testLaunchRedirectOut();
 	void testLaunchEnv();
 	void testLaunchArgs();
+	void testLaunchInvalidCommand();
 	void testIsRunning();
 
 	void setUp();
@@ -38,6 +39,7 @@ public:
 	static CppUnit::Test* suite();
 
 private:
+	static std::string getFullName(const std::string& name);
 };
 
 
