@@ -14,6 +14,7 @@
 #include "NamedEventTest.h"
 #include "SharedMemoryTest.h"
 #include "ProcessRunnerTest.h"
+#include "FileStreamRWLockTest.h"
 
 
 CppUnit::Test* ProcessesTestSuite::suite()
@@ -25,6 +26,7 @@ CppUnit::Test* ProcessesTestSuite::suite()
 	pSuite->addTest(NamedEventTest::suite());
 	pSuite->addTest(SharedMemoryTest::suite());
 	pSuite->addTest(ProcessRunnerTest::suite());
+	pSuite->addTest(FileStreamRWLockTest::suite());
 
 	return pSuite;
 }
