@@ -17,7 +17,6 @@
 #include "Poco/Event.h"
 #include "Poco/Timestamp.h"
 #include "Poco/Timespan.h"
-//#include <iostream>
 #if defined(__sun) && defined(__SVR4) && !defined(__EXTENSIONS__)
 #define __EXTENSIONS__
 #endif
@@ -44,8 +43,10 @@ public:
 		if (pThread)
 		{
 			_threadName = pThread->name();
+#ifndef POCO_NO_THREADNAME
 			auto *pThreadImpl = reinterpret_cast<Poco::ThreadImpl *>(pThread);
 			_osThreadName = pThreadImpl->getOSThreadNameImpl();
+#endif
 		}
 		_ran = true;
 		_event.wait();
@@ -61,10 +62,12 @@ public:
 		return _threadName;
 	}
 
+#ifndef POCO_NO_THREADNAME
 	const std::string& osThreadName() const
 	{
 		return _osThreadName;
 	}
+#endif
 
 	void notify()
 	{
@@ -81,7 +84,9 @@ public:
 private:
 	bool _ran;
 	std::string _threadName;
+#ifndef POCO_NO_THREADNAME
 	std::string _osThreadName;
+#endif
 	Event _event;
 };
 
@@ -123,6 +128,37 @@ private:
 };
 
 
+class JoinRunnable : public Runnable
+{
+public:
+	JoinRunnable() : _stop(false), _running(false)
+	{
+	}
+
+	void run()
+	{
+		_running = true;
+		while (!_stop)
+			Thread::sleep(100);
+		_running = false;
+	}
+
+	void stop()
+	{
+		_stop = true;
+	}
+
+	bool running() const
+	{
+		return _running;
+	}
+
+private:
+	std::atomic<bool> _stop;
+	std::atomic<bool> _running;
+};
+
+
 class TrySleepRunnable : public Runnable
 {
 public:
@@ -179,7 +215,9 @@ void ThreadTest::testThread()
 	assertTrue (!thread.isRunning());
 	assertTrue (r.ran());
 	assertTrue (!r.threadName().empty());
+#ifndef POCO_NO_THREADNAME
 	assertTrue (!r.osThreadName().empty());
+#endif
 }
 
 
@@ -192,7 +230,9 @@ void ThreadTest::testNamedThread()
 	thread.join();
 	assertTrue (r.ran());
 	assertTrue (r.threadName() == "MyThread");
+#ifndef POCO_NO_THREADNAME
 	assertTrue (r.osThreadName() == r.threadName());
+#endif
 
 	// name len > POCO_MAX_THREAD_NAME_LEN
 	Thread thread2("0123456789aaaaaaaaaa9876543210");
@@ -201,7 +241,9 @@ void ThreadTest::testNamedThread()
 	r2.notify();
 	thread2.join();
 	assertTrue (r2.ran());
+#ifndef POCO_NO_THREADNAME
 	assertTrue (r2.osThreadName() == r2.threadName());
+#endif
 	assertTrue (r2.threadName().length() <= POCO_MAX_THREAD_NAME_LEN);
 	assertTrue (std::string(r2.threadName(), 0, 7) == "0123456");
 	assertTrue (std::string(r2.threadName(), r2.threadName().size() - 7) == "6543210");
@@ -269,7 +311,7 @@ void ThreadTest::testThreads()
 }
 
 
-void ThreadTest::testJoin()
+void ThreadTest::testTryJoin()
 {
 	Thread thread;
 	MyRunnable r;
@@ -284,6 +326,22 @@ void ThreadTest::testJoin()
 }
 
 
+void ThreadTest::testJoin()
+{
+	Thread thread;
+	JoinRunnable r;
+	assertTrue(!thread.isRunning());
+	thread.start(r);
+	Thread::sleep(200);
+	assertTrue(thread.isRunning());
+	assertTrue(!thread.tryJoin(100));
+	r.stop();
+	thread.join();
+	assertTrue(!thread.isRunning());
+	assertTrue(!r.running());
+}
+
+
 void ThreadTest::testNotJoin()
 {
 	Thread thread;
@@ -372,10 +430,11 @@ void ThreadTest::testThreadFunction()
 
 	assertTrue (!thread.isRunning());
 
-	int tmp = MyRunnable::_staticVar;
+	MyRunnable::_staticVar = 0;
+	int tmp = 1;
 	thread.start(freeFunc, &tmp);
 	thread.join();
-	assertTrue (tmp * 2 == MyRunnable::_staticVar);
+	assertTrue (tmp == MyRunnable::_staticVar);
 
 	assertTrue (!thread.isRunning());
 
@@ -433,15 +492,16 @@ void ThreadTest::testThreadStackSize()
 	assertTrue (0 == thread.getStackSize());
 	thread.setStackSize(stackSize);
 	assertTrue (stackSize <= thread.getStackSize());
-	int tmp = MyRunnable::_staticVar;
+	MyRunnable::_staticVar = 0;
+	int tmp = 1;
 	thread.start(freeFunc, &tmp);
 	thread.join();
-	assertTrue (tmp * 2 == MyRunnable::_staticVar);
+	assertTrue (1 == MyRunnable::_staticVar);
 
 	stackSize = 1;
 	thread.setStackSize(stackSize);
 
-#if !defined(POCO_OS_FAMILY_BSD) // on BSD family, stack size is rounded
+#if defined(POCO_OS_FAMILY_BSD) // on BSD family, stack size is rounded
 	#ifdef PTHREAD_STACK_MIN
 		assertTrue (PTHREAD_STACK_MIN == thread.getStackSize());
 	#else
@@ -449,17 +509,22 @@ void ThreadTest::testThreadStackSize()
 	#endif
 #endif
 
-	tmp = MyRunnable::_staticVar;
-	thread.start(freeFunc, &tmp);
-	thread.join();
-	assertTrue (tmp * 2 == MyRunnable::_staticVar);
-
-	thread.setStackSize(0);
-	assertTrue (0 == thread.getStackSize());
-	tmp = MyRunnable::_staticVar;
-	thread.start(freeFunc, &tmp);
-	thread.join();
-	assertTrue (tmp * 2 == MyRunnable::_staticVar);
+// disabled on FreeBSD; segfaults due to stack overflow,
+// possibly happens on other BSD OSes)
+#if (POCO_OS == POCO_OS_FREE_BSD)
+	{
+		int tmp = MyRunnable::_staticVar;
+		thread.start(freeFunc, &tmp);
+		thread.join();
+		assertTrue (tmp * 2 == MyRunnable::_staticVar);
+		thread.setStackSize(0);
+		assertTrue (0 == thread.getStackSize());
+		tmp = MyRunnable::_staticVar;
+		thread.start(freeFunc, &tmp);
+		thread.join();
+		assertTrue (tmp * 2 == MyRunnable::_staticVar);
+	}
+#endif
 }
 
 
@@ -506,6 +571,7 @@ CppUnit::Test* ThreadTest::suite()
 	CppUnit_addTest(pSuite, ThreadTest, testNamedThread);
 	CppUnit_addTest(pSuite, ThreadTest, testCurrent);
 	CppUnit_addTest(pSuite, ThreadTest, testThreads);
+	CppUnit_addTest(pSuite, ThreadTest, testTryJoin);
 	CppUnit_addTest(pSuite, ThreadTest, testJoin);
 	CppUnit_addTest(pSuite, ThreadTest, testNotJoin);
 	CppUnit_addTest(pSuite, ThreadTest, testNotRun);
