@@ -19,6 +19,7 @@
 #include "ActiveMethodTest.h"
 #include "ActiveDispatcherTest.h"
 #include "ConditionTest.h"
+#include "ActiveThreadPoolTest.h"
 
 
 CppUnit::Test* ThreadingTestSuite::suite()
@@ -35,6 +36,7 @@ CppUnit::Test* ThreadingTestSuite::suite()
 	pSuite->addTest(ActiveMethodTest::suite());
 	pSuite->addTest(ActiveDispatcherTest::suite());
 	pSuite->addTest(ConditionTest::suite());
+	pSuite->addTest(ActiveThreadPoolTest::suite());
 
 	return pSuite;
 }
