@@ -20,6 +20,15 @@
 
 using Poco::Dynamic::Var;
 
+// Explicitly instatiated shared pointer in JSON library is required to
+// have known instance of the pointer to be used with VarHolder when
+// compiling with -fvisibility=hidden
+#if defined(POCO_OS_FAMILY_WINDOWS)
+template class JSON_API Poco::SharedPtr<Poco::JSON::Array>;
+#else
+template class Poco::SharedPtr<Poco::JSON::Array>;
+#endif
+
 
 namespace Poco {
 namespace JSON {
@@ -33,14 +42,7 @@ Array::Array(int options):
 }
 
 
-Array::Array(const Array& other) :
-	_values(other._values),
-	_pArray(other._pArray),
-	_modified(other._modified),
-	_escapeUnicode(other._escapeUnicode),
-	_lowercaseHex(other._lowercaseHex)
-{
-}
+Array::Array(const Array& other) = default;
 
 
 Array::Array(Array&& other) noexcept:
@@ -79,9 +81,7 @@ Array& Array::operator = (Array&& other) noexcept
 }
 
 
-Array::~Array()
-{
-}
+Array::~Array() = default;
 
 
 Var Array::get(unsigned int index) const
@@ -167,7 +167,7 @@ void Array::stringify(std::ostream& out, unsigned int indent, int step) const
 
 	if (indent > 0) out << std::endl;
 
-	for (ValueVec::const_iterator it = _values.begin(); it != _values.end();)
+	for (auto it = _values.begin(); it != _values.end();)
 	{
 		for (int i = 0; i < indent; i++) out << ' ';
 
@@ -201,14 +201,14 @@ void Array::resetDynArray() const
 
 Array::operator const Poco::Dynamic::Array& () const
 {
-	if (!_values.size())
+	if (_values.empty())
 	{
 		resetDynArray();
 	}
 	else if (_modified)
 	{
-		ValueVec::const_iterator it = _values.begin();
-		ValueVec::const_iterator end = _values.end();
+		auto it = _values.begin();
+		const auto end = _values.end();
 		resetDynArray();
 		int index = 0;
 		for (; it != end; ++it, ++index)
@@ -237,8 +237,8 @@ Poco::Dynamic::Array Array::makeArray(const JSON::Array::Ptr& arr)
 {
 	Poco::Dynamic::Array vec;
 
-	JSON::Array::ConstIterator it  = arr->begin();
-	JSON::Array::ConstIterator end = arr->end();
+	auto it  = arr->begin();
+	const auto end = arr->end();
 	int index = 0;
 	for (; it != end; ++it, ++index)
 	{
@@ -265,7 +265,7 @@ Poco::Dynamic::Array Array::makeArray(const JSON::Array::Ptr& arr)
 void Array::clear()
 {
 	_values.clear();
-	_pArray = 0;
+	_pArray = nullptr;
 }
 
 
