@@ -15,7 +15,6 @@
 #include "Poco/JSON/Stringifier.h"
 #include "Poco/JSON/Array.h"
 #include "Poco/JSON/Object.h"
-#include <iomanip>
 
 
 using Poco::Dynamic::Var;
@@ -34,28 +33,28 @@ void Stringifier::stringify(const Var& any, std::ostream& out, unsigned int inde
 
 	if (any.type() == typeid(Object))
 	{
-		Object& o = const_cast<Object&>(any.extract<Object>());
+		auto& o = const_cast<Object&>(any.extract<Object>());
 		o.setEscapeUnicode(escapeUnicode);
 		o.setLowercaseHex(lowercaseHex);
 		o.stringify(out, indent == 0 ? 0 : indent, step);
 	}
 	else if (any.type() == typeid(Array))
 	{
-		Array& a = const_cast<Array&>(any.extract<Array>());
+		auto& a = const_cast<Array&>(any.extract<Array>());
 		a.setEscapeUnicode(escapeUnicode);
 		a.setLowercaseHex(lowercaseHex);
 		a.stringify(out, indent == 0 ? 0 : indent, step);
 	}
 	else if (any.type() == typeid(Object::Ptr))
 	{
-		Object::Ptr& o = const_cast<Object::Ptr&>(any.extract<Object::Ptr>());
+		auto& o = const_cast<Object::Ptr&>(any.extract<Object::Ptr>());
 		o->setEscapeUnicode(escapeUnicode);
 		o->setLowercaseHex(lowercaseHex);
 		o->stringify(out, indent == 0 ? 0 : indent, step);
 	}
 	else if (any.type() == typeid(Array::Ptr))
 	{
-		Array::Ptr& a = const_cast<Array::Ptr&>(any.extract<Array::Ptr>());
+		auto& a = const_cast<Array::Ptr&>(any.extract<Array::Ptr>());
 		a->setEscapeUnicode(escapeUnicode);
 		a->setLowercaseHex(lowercaseHex);
 		a->stringify(out, indent == 0 ? 0 : indent, step);
@@ -66,7 +65,7 @@ void Stringifier::stringify(const Var& any, std::ostream& out, unsigned int inde
 	}
 	else if (any.isNumeric() || any.isBoolean())
 	{
-		std::string value = any.convert<std::string>();
+		auto value = any.convert<std::string>();
 		if ((Poco::icompare(value, "nan") == 0) ||
 			(Poco::icompare(value, "inf") == 0)) value = "null";
 		if (any.type() == typeid(char)) formatString(value, out, options);
@@ -74,7 +73,7 @@ void Stringifier::stringify(const Var& any, std::ostream& out, unsigned int inde
 	}
 	else if (any.isString() || any.isDateTime() || any.isDate() || any.isTime())
 	{
-		std::string value = any.convert<std::string>();
+		auto value = any.convert<std::string>();
 		formatString(value, out, options);
 	}
 	else
