@@ -47,7 +47,7 @@ Element::Ptr Document::get(const std::string& name) const
 {
 	Element::Ptr element;
 
-	ElementSet::const_iterator it = std::find_if(_elements.begin(), _elements.end(), ElementFindByName(name));
+	auto it = std::find_if(_elements.begin(), _elements.end(), ElementFindByName(name));
 	if (it != _elements.end())
 	{
 		return *it;
@@ -167,7 +167,7 @@ std::string Document::toString(int indent) const
 	if (indent > 0) oss << std::endl;
 
 
-	for (ElementSet::const_iterator it = _elements.begin(); it != _elements.end(); ++it)
+	for (auto it = _elements.begin(), total = _elements.end(); it != total; ++it)
 	{
 		if (it != _elements.begin())
 		{
