@@ -322,18 +322,13 @@ std::ostream& HTTPClientSession::sendRequestImpl(const HTTPRequest& request)
 #endif
 		request.write(*_pRequestStream);
 	}
-	else if ((method != HTTPRequest::HTTP_PUT && method != HTTPRequest::HTTP_POST && method != HTTPRequest::HTTP_PATCH) || request.has(HTTPRequest::UPGRADE))
+	else 
 	{
 		Poco::CountingOutputStream cs;
 		request.write(cs);
 		_pRequestStream = new HTTPFixedLengthOutputStream(*this, cs.chars());
 		request.write(*_pRequestStream);
 	}
-	else
-	{
-		_pRequestStream = new HTTPOutputStream(*this);
-		request.write(*_pRequestStream);
-	}
 	_lastRequest.update();
 	return *_pRequestStream;
 }
