@@ -23,7 +23,8 @@ HTTPServerParams::HTTPServerParams():
 	_timeout(60000000),
 	_keepAlive(true),
 	_maxKeepAliveRequests(0),
-	_keepAliveTimeout(15000000)
+	_keepAliveTimeout(15000000),
+	_autoDecodeHeaders(true)
 {
 }
 
@@ -32,12 +33,12 @@ HTTPServerParams::~HTTPServerParams()
 {
 }
 
-	
+
 void HTTPServerParams::setServerName(const std::string& serverName)
 {
 	_serverName = serverName;
 }
-	
+
 
 void HTTPServerParams::setSoftwareVersion(const std::string& softwareVersion)
 {
@@ -50,24 +51,30 @@ void HTTPServerParams::setTimeout(const Poco::Timespan& timeout)
 	_timeout = timeout;
 }
 
-	
+
 void HTTPServerParams::setKeepAlive(bool keepAlive)
 {
 	_keepAlive = keepAlive;
 }
 
-	
+
 void HTTPServerParams::setKeepAliveTimeout(const Poco::Timespan& timeout)
 {
 	_keepAliveTimeout = timeout;
 }
 
-	
+
 void HTTPServerParams::setMaxKeepAliveRequests(int maxKeepAliveRequests)
 {
 	poco_assert (maxKeepAliveRequests >= 0);
 	_maxKeepAliveRequests = maxKeepAliveRequests;
 }
-	
+
+
+void HTTPServerParams::setAutoDecodeHeaders(bool autoDecode)
+{
+	_autoDecodeHeaders = autoDecode;
+}
+
 
 } } // namespace Poco::Net
