@@ -32,6 +32,7 @@ using Poco::URIStreamFactory;
 using Poco::URI;
 using Poco::URIStreamOpener;
 using Poco::UnbufferedStreamBuf;
+using namespace std::string_literals;
 
 
 namespace Poco {
@@ -115,11 +116,11 @@ std::istream* HTTPStreamFactory::open(const URI& uri)
 				cred.authenticate(req, res);
 			}
 
-			req.set("User-Agent", Poco::format("poco/%d.%d.%d",
+			req.set("User-Agent"s, Poco::format("poco/%d.%d.%d"s,
 				(POCO_VERSION >> 24) & 0xFF,
 				(POCO_VERSION >> 16) & 0xFF,
 				(POCO_VERSION >> 8) & 0xFF));
-			req.set("Accept", "*/*");
+			req.set("Accept"s, "*/*"s);
 
 			pSession->sendRequest(req);
 			std::istream& rs = pSession->receiveResponse(res);
@@ -129,7 +130,7 @@ std::istream* HTTPStreamFactory::open(const URI& uri)
 						  res.getStatus() == HTTPResponse::HTTP_TEMPORARY_REDIRECT);
 			if (moved)
 			{
-				resolvedURI.resolve(res.get("Location"));
+				resolvedURI.resolve(res.get("Location"s));
 				if (!username.empty())
 				{
 					resolvedURI.setUserInfo(username + ":" + password);
@@ -147,7 +148,7 @@ std::istream* HTTPStreamFactory::open(const URI& uri)
 				// URI of the proxy. The recipient is expected to repeat this
 				// single request via the proxy. 305 responses MUST only be generated by origin servers.
 				// only use for one single request!
-				proxyUri.resolve(res.get("Location"));
+				proxyUri.resolve(res.get("Location"s));
 				delete pSession;
 				pSession = 0;
 				retry = true; // only allow useproxy once
@@ -174,13 +175,13 @@ std::istream* HTTPStreamFactory::open(const URI& uri)
 
 void HTTPStreamFactory::registerFactory()
 {
-	URIStreamOpener::defaultOpener().registerStreamFactory("http", new HTTPStreamFactory);
+	URIStreamOpener::defaultOpener().registerStreamFactory("http"s, new HTTPStreamFactory);
 }
 
 
 void HTTPStreamFactory::unregisterFactory()
 {
-	URIStreamOpener::defaultOpener().unregisterStreamFactory("http");
+	URIStreamOpener::defaultOpener().unregisterStreamFactory("http"s);
 }
 
 
