@@ -104,9 +104,19 @@ namespace
 				NameValueCollection::ConstIterator it = header.begin();
 				NameValueCollection::ConstIterator end = header.end();
 				bool added = false;
+
+				if (contentDisp.empty())
+				{
+					_pMsg->addContent(pPS, cte);
+					added = true;
+				}
+
+				static const auto lcContentDisposition = Poco::toLower(MailMessage::HEADER_CONTENT_DISPOSITION);
+
 				for (; it != end; ++it)
 				{
-					if (!added && MailMessage::HEADER_CONTENT_DISPOSITION == it->first)
+					const auto lcHdr = Poco::toLower(it->first);
+					if (!added && lcContentDisposition == lcHdr)
 					{
 						if (it->second == "inline")
 							_pMsg->addContent(pPS, cte);
@@ -118,12 +128,6 @@ namespace
 					pPS->headers().set(it->first, it->second);
 				}
 
-				if (contentDisp.empty())
-				{
-					_pMsg->addContent(pPS, cte);
-					added = true;
-				}
-
 				if (!added) delete pPS;
 			}
 		}
