@@ -14,16 +14,16 @@
 
 #include "Poco/Net/PollSet.h"
 #include "Poco/Net/SocketImpl.h"
-#include "Poco/TemporaryFile.h"
 #include "Poco/Mutex.h"
 #include <set>
 
 
 #if defined(POCO_HAVE_FD_EPOLL)
 	#ifdef POCO_OS_FAMILY_WINDOWS
-		#include "Poco/Net/ServerSocket.h"
+		#include "Poco/Net/DatagramSocket.h"
 		#include "Poco/Net/SocketAddress.h"
 		#include "wepoll.h"
+		#include <memory>
 	#else
 		#include <sys/epoll.h>
 		#include <sys/eventfd.h>
@@ -48,16 +48,13 @@ namespace Net {
 
 
 #ifdef WEPOLL_H_
-
-namespace {
-
-int close(HANDLE h)
+namespace 
 {
-	return epoll_close(h);
+	int close(HANDLE h)
+	{
+		return epoll_close(h);
+	}
 }
-
-}
-
 #endif // WEPOLL_H_
 
 
@@ -72,11 +69,7 @@ public:
 	static const epoll_event EPOLL_NULL_EVENT;
 
 	PollSetImpl(): _events(FD_SETSIZE, EPOLL_NULL_EVENT),
-#if defined(WEPOLL_H_)
-		_eventfd(eventfd()),
-#else
 		_eventfd(eventfd(0, 0)),
-#endif // WEPOLL_H_
 		_epollfd(epoll_create(1))
 	{
 		int err = addFD(_eventfd, PollSet::POLL_READ, EPOLL_CTL_ADD);
@@ -174,8 +167,7 @@ public:
 		while (true)
 		{
 			Poco::Timestamp start;
-			rc = epoll_wait(_epollfd, &_events[0],
-				static_cast<int>(_events.size()), static_cast<int>(remainingTime.totalMilliseconds()));
+			rc = epoll_wait(_epollfd, _events.data(), static_cast<int>(_events.size()), static_cast<int>(remainingTime.totalMilliseconds()));
 			if (rc == 0)
 			{
 				if (keepWaiting(start, remainingTime)) continue;
@@ -185,7 +177,10 @@ public:
 			// if we are hitting the events limit, resize it; even without resizing, the subseqent
 			// calls would round-robin through the remaining ready sockets, but it's better to give
 			// the call enough room once we start hitting the boundary
-			if (rc >= _events.size()) _events.resize(_events.size()*2);
+			if (rc > 0 && static_cast<size_t>(rc) >= _events.size()) 
+			{
+				_events.resize(_events.size()*2);
+			}
 			else if (rc < 0)
 			{
 				// if interrupted and there's still time left, keep waiting
@@ -217,11 +212,15 @@ public:
 			}
 			else if (_events[i].events & EPOLLIN) // eventfd signaled
 			{
-				uint64_t val;
 #ifdef WEPOLL_H_
-				if (_pSocket && _pSocket->available())
-					_pSocket->impl()->receiveBytes(&val, sizeof(val));
+				if (_pEventSocket)
+				{
+					char val;
+					Poco::Net::SocketAddress sa;
+					_pEventSocket->receiveFrom(&val, sizeof(val), sa);
+				}
 #else
+				std::uint64_t val;
 				read(_eventfd, &val, sizeof(val));
 #endif
 			}
@@ -231,27 +230,22 @@ public:
 
 	void wakeUp()
 	{
-		uint64_t val = 1;
 #ifdef WEPOLL_H_
-	#ifdef POCO_HAS_UNIX_SOCKET
-		poco_check_ptr (_pSockFile);
-		StreamSocket ss(SocketAddress(_pSockFile->path()));
-	#else
-		StreamSocket ss(SocketAddress("127.0.0.1", _port));
-	#endif
-		ss.sendBytes(&val, sizeof(val));
+		char val = 1;
+		_pEventSocket->sendTo(&val, sizeof(val), _pEventSocket->address());
 #else
 		// This is guaranteed to write into a valid fd,
 		// or 0 (meaning PollSet is being destroyed).
 		// Errors are ignored.
+		std::uint64_t val = 1;
 		write(_eventfd, &val, sizeof(val));
 #endif
 	}
 
-	int count() const
+	std::size_t size() const
 	{
 		ScopedLock lock(_mutex);
-		return static_cast<int>(_socketMap.size());
+		return _socketMap.size();
 	}
 
 private:
@@ -319,31 +313,18 @@ private:
 #else // WEPOLL_H_
 	using EPollHandle = std::atomic<HANDLE>;
 
-	#ifdef POCO_HAS_UNIX_SOCKET
-		int eventfd()
+	int eventfd(int, int)
+	{
+		static const SocketAddress eventSA("127.0.0.238"s, 0);
+		if (!_pEventSocket)
 		{
-			if (!_pSockFile)
-			{
-				_pSockFile.reset(new TemporaryFile);
-				_pSocket.reset(new ServerSocket(SocketAddress(_pSockFile->path())));
-			}
-			_pSocket->setBlocking(false);
-			return static_cast<int>(_pSocket->impl()->sockfd());
+			_pEventSocket.reset(new DatagramSocket(eventSA, true));
+			_pEventSocket->setBlocking(false);
 		}
-		std::unique_ptr<TemporaryFile> _pSockFile;
-	#else // no unix socket, listen on localhost
-		int eventfd()
-		{
-			if (!_pSocket)
-				_pSocket.reset(new ServerSocket(SocketAddress("127.0.0.1", 0)));
-			_port = _pSocket->address().port();
-			_pSocket->setBlocking(false);
-			return static_cast<int>(_pSocket->impl()->sockfd());
-		}
-		int _port = 0;
-	#endif // POCO_HAS_UNIX_SOCKET
+		return static_cast<int>(_pEventSocket->impl()->sockfd());
+	}
 
-	std::unique_ptr<ServerSocket> _pSocket;
+	std::unique_ptr<DatagramSocket> _pEventSocket;
 #endif // WEPOLL_H_
 
 	mutable Mutex _mutex;
@@ -353,8 +334,10 @@ private:
 	EPollHandle      _epollfd;
 };
 
+
 const epoll_event PollSetImpl::EPOLL_NULL_EVENT = {0, {0}};
 
+
 #elif defined(POCO_HAVE_FD_POLL)
 
 
@@ -411,13 +394,13 @@ public:
 	{
 		Poco::FastMutex::ScopedLock lock(_mutex);
 		poco_socket_t fd = socket.impl()->sockfd();
-		for (auto it = _pollfds.begin(); it != _pollfds.end(); ++it)
+		for (auto& _pollfd : _pollfds)
 		{
-			if (it->fd == fd)
+			if (_pollfd.fd == fd)
 			{
-				it->events = 0;
-				it->revents = 0;
-				setMode(it->events, mode);
+				_pollfd.events = 0;
+				_pollfd.revents = 0;
+				setMode(_pollfd.events, mode);
 			}
 		}
 	}
@@ -452,13 +435,13 @@ public:
 			}
 
 			_pollfds.reserve(_pollfds.size() + _addMap.size());
-			for (auto it = _addMap.begin(); it != _addMap.end(); ++it)
+			for (auto& it : _addMap)
 			{
 				pollfd pfd;
-				pfd.fd = it->first;
+				pfd.fd = it.first;
 				pfd.events = 0;
 				pfd.revents = 0;
-				setMode(pfd.events, it->second);
+				setMode(pfd.events, it.second);
 				_pollfds.push_back(pfd);
 			}
 			_addMap.clear();
@@ -471,7 +454,7 @@ public:
 		do
 		{
 			Poco::Timestamp start;
-			rc = ::poll(&_pollfds[0], _pollfds.size(), remainingTime.totalMilliseconds());
+			rc = ::poll(_pollfds.data(), _pollfds.size(), remainingTime.totalMilliseconds());
 			if (rc < 0 && SocketImpl::lastError() == POCO_EINTR)
 			{
 				Poco::Timestamp end;
@@ -498,7 +481,7 @@ public:
 			{
 				for (auto it = _pollfds.begin() + 1; it != _pollfds.end(); ++it)
 				{
-					std::map<poco_socket_t, Socket>::const_iterator its = _socketMap.find(it->fd);
+					auto its = _socketMap.find(it->fd);
 					if (its != _socketMap.end())
 					{
 						if (it->revents & POLLIN)
@@ -522,14 +505,13 @@ public:
 		_pipe.writeBytes(&c, 1);
 	}
 
-	int count() const
+	std::size_t size() const
 	{
 		Poco::FastMutex::ScopedLock lock(_mutex);
-		return static_cast<int>(_socketMap.size());
+		return _socketMap.size();
 	}
 
 private:
-
 	void setMode(short& target, int mode)
 	{
 		if (mode & PollSet::POLL_READ)
@@ -687,10 +669,10 @@ public:
 		// TODO
 	}
 
-	int count() const
+	std::size_t size() const
 	{
 		Poco::FastMutex::ScopedLock lock(_mutex);
-		return static_cast<int>(_map.size());
+		return _map.size();
 	}
 
 private:
@@ -758,7 +740,13 @@ PollSet::SocketModeMap PollSet::poll(const Poco::Timespan& timeout)
 
 int PollSet::count() const
 {
-	return _pImpl->count();
+	return static_cast<int>(_pImpl->size());
+}
+
+
+std::size_t PollSet::size() const
+{
+	return _pImpl->size();
 }
 
 
