@@ -61,7 +61,7 @@ int StreamSocketImpl::sendBytes(const void* buffer, int length, int flags)
 	while (remaining > 0)
 	{
 		int n = SocketImpl::sendBytes(p, remaining, flags);
-		poco_assert_dbg (n >= 0);
+		poco_assert_dbg (!blocking || n >= 0);
 		p += n;
 		sent += n;
 		remaining -= n;
