@@ -15,6 +15,7 @@
 
 
 #include "Poco/Net/Net.h"
+#include "Poco/Net/SocketAddress.h"
 #include "CppUnit/TestCase.h"
 
 
@@ -25,9 +26,13 @@ public:
 	~DatagramSocketTest();
 
 	void testEcho();
+	void testMoveDatagramSocket();
 	void testEchoBuffer();
+	void testReceiveFromAvailable();
 	void testSendToReceiveFrom();
 	void testUnbound();
+	void testReuseAddressPortWildcard();
+	void testReuseAddressPortSpecific();
 	void testBroadcast();
 	void testGatherScatterFixed();
 	void testGatherScatterVariable();
@@ -38,6 +43,8 @@ public:
 	static CppUnit::Test* suite();
 
 private:
+	static Poco::UInt16 getFreePort(Poco::Net::SocketAddress::Family family, std::uint16_t port);
+
 	// "STRF" are sendto/recvfrom versions of the same functionality
 	void testGatherScatterFixedWin();
 	void testGatherScatterSTRFFixedWin();
