@@ -31,6 +31,7 @@ public:
 	void testAuthenticationParamsMultipleHeaders();
 	void testDigestCredentials();
 	void testDigestCredentialsQoP();
+	void testDigestCredentialsQoPSHA256();
 	void testCredentialsBasic();
 	void testProxyCredentialsBasic();
 	void testCredentialsDigest();
@@ -39,6 +40,8 @@ public:
 	void testExtractCredentials();
 	void testVerifyAuthInfo();
 	void testVerifyAuthInfoQoP();
+	void testVerifyAuthInfoQoPSHA256();
+	void testIsAlgorithmSupported();
 
 	void setUp();
 	void tearDown();
