@@ -27,10 +27,8 @@ public:
 	void testIdentityRequest();
 	void testPutIdentityRequest();
 	void testChunkedRequest();
-	void testClosedRequest();
 	void testIdentityRequestKeepAlive();
 	void testChunkedRequestKeepAlive();
-	void testClosedRequestKeepAlive();
 	void testMaxKeepAlive();
 	void testKeepAliveTimeout();
 	void test100Continue();
@@ -38,6 +36,7 @@ public:
 	void testAuth();
 	void testNotImpl();
 	void testBuffer();
+	void testFile();
 	void testChunkedTrailer();
 
 	void setUp();
