@@ -27,21 +27,24 @@ public:
 	HTTPTestServer();
 		/// Creates the HTTPTestServer.
 
+	HTTPTestServer(const std::string& addr);
+	/// Creates the HTTPTestServer on the specified address.
+
 	~HTTPTestServer();
 		/// Destroys the HTTPTestServer.
 
 	Poco::UInt16 port() const;
 		/// Returns the port the echo server is
 		/// listening on.
-		
+
 	void run();
 		/// Does the work.
-		
+
 	const std::string& lastRequest() const;
 		/// Returns the last request.
 
 	static const std::string SMALL_BODY;
-	static const std::string LARGE_BODY;	
+	static const std::string LARGE_BODY;
 
 protected:
 	bool requestComplete() const;
@@ -51,7 +54,7 @@ private:
 	Poco::Net::ServerSocket  _socket;
 	Poco::Thread _thread;
 	Poco::Event  _ready;
-	bool         _stop;
+	std::atomic<bool> _stop;
 	std::string  _lastRequest;
 };
 
