@@ -18,6 +18,7 @@
 #include "CppUnit/TestCase.h"
 #include "Poco/Net/ICMPClient.h"
 #include "Poco/Net/ICMPEventArgs.h"
+#include "Poco/Mutex.h"
 
 
 class ICMPClientTest: public CppUnit::TestCase
@@ -27,6 +28,7 @@ public:
 	~ICMPClientTest();
 
 	void testPing();
+	void testBigPing();
 
 	void setUp();
 	void tearDown();
@@ -39,7 +41,9 @@ public:
 	void onEnd(const void* pSender, Poco::Net::ICMPEventArgs& args);
 
 private:
-	Poco::Net::ICMPClient _icmpClient;
+	void registerDelegates(const Poco::Net::ICMPClient& icmpClient);
+	void unregisterDelegates(const Poco::Net::ICMPClient& icmpClient);
+	static Poco::FastMutex _mutex;
 };
 
 
