@@ -72,6 +72,7 @@ void MailStreamTest::testMailOutputStream()
 		"Subject: test\r\n"
 		"\r\n"
 		"This is a test.\r\n"
+		"\n.\n"
 		"\rThis.is.\ngarbage\r.\r\n"
 		".This line starts with a period.\r\n"
 		"\r\n"
@@ -90,7 +91,8 @@ void MailStreamTest::testMailOutputStream()
 		"Subject: test\r\n"
 		"\r\n"
 		"This is a test.\r\n"
-		"\rThis.is.\ngarbage\r.\r\n"
+		"\r\n..\r\n"
+		"\rThis.is.\r\ngarbage\r.\r\n"
 		"..This line starts with a period.\r\n"
 		"\r\n"
 		"..and this one too\r\n"
