@@ -40,7 +40,10 @@ public:
 	void testSplitElements();
 	void testSplitParameters();
 	void testFieldLimit();
+	void testNameLengthLimit();
+	void testValueLengthLimit();
 	void testDecodeWord();
+	void testAutoDecode();
 
 	void setUp();
 	void tearDown();
