@@ -22,9 +22,10 @@ class SocketTest: public CppUnit::TestCase
 {
 public:
 	SocketTest(const std::string& name);
-	~SocketTest();
+	~SocketTest() override;
 
 	void testEcho();
+	void testPeek();
 	void testMoveStreamSocket();
 	void testPoll();
 	void testAvailable();
@@ -38,15 +39,22 @@ public:
 	void testTimeout();
 	void testBufferSize();
 	void testOptions();
+
+#if defined(POCO_TEST_DEPRECATED)
 	void testSelect();
 	void testSelect2();
 	void testSelect3();
+#endif
+
 	void testEchoUnixLocal();
 	void testUnixLocalAbstract();
 	void testUseFd();
+	void testSendFile();
+	void testSendFileLarge();
+	void testSendFileRange();
 
-	void setUp();
-	void tearDown();
+	void setUp() override;
+	void tearDown() override;
 
 	static CppUnit::Test* suite();
 
