@@ -41,10 +41,9 @@ HTTPClientSession* HTTPSSessionInstantiator::createClientSession(const Poco::URI
 {
 	poco_assert (uri.getScheme() == "https");
 	HTTPSClientSession* pSession = _pContext.isNull() ? new HTTPSClientSession(uri.getHost(), uri.getPort()) : new HTTPSClientSession(uri.getHost(), uri.getPort(), _pContext);
-	if (!proxyHost().empty())
+	if (!getProxyConfig().host.empty())
 	{
-		pSession->setProxy(proxyHost(), proxyPort());
-		pSession->setProxyCredentials(proxyUsername(), proxyPassword());
+		pSession->setProxyConfig(getProxyConfig());
 	}
 	return pSession;
 }
