@@ -80,7 +80,7 @@ std::istream* HTTPSStreamFactory::open(const URI& uri)
 		int redirects = 0;
 		std::string username;
 		std::string password;
-		
+
 		do
 		{
 			if (!pSession)
@@ -110,7 +110,7 @@ std::istream* HTTPSStreamFactory::open(const URI& uri)
 			std::string path = resolvedURI.getPathAndQuery();
 			if (path.empty()) path = "/";
 			HTTPRequest req(HTTPRequest::HTTP_GET, path, HTTPMessage::HTTP_1_1);
-			
+
 			if (authorize)
 			{
 				HTTPCredentials::extractCredentials(uri, username, password);
@@ -118,7 +118,7 @@ std::istream* HTTPSStreamFactory::open(const URI& uri)
 				cred.authenticate(req, res);
 			}
 
-			req.set("User-Agent", Poco::format("poco/%d.%d.%d", 
+			req.set("User-Agent", Poco::format("poco/%d.%d.%d",
 				(POCO_VERSION >> 24) & 0xFF,
 				(POCO_VERSION >> 16) & 0xFF,
 				(POCO_VERSION >> 8) & 0xFF));
@@ -126,8 +126,8 @@ std::istream* HTTPSStreamFactory::open(const URI& uri)
 
 			pSession->sendRequest(req);
 			std::istream& rs = pSession->receiveResponse(res);
-			bool moved = (res.getStatus() == HTTPResponse::HTTP_MOVED_PERMANENTLY || 
-			              res.getStatus() == HTTPResponse::HTTP_FOUND || 
+			bool moved = (res.getStatus() == HTTPResponse::HTTP_MOVED_PERMANENTLY ||
+			              res.getStatus() == HTTPResponse::HTTP_FOUND ||
 			              res.getStatus() == HTTPResponse::HTTP_SEE_OTHER ||
 						  res.getStatus() == HTTPResponse::HTTP_TEMPORARY_REDIRECT);
 			if (moved)
@@ -138,7 +138,7 @@ std::istream* HTTPSStreamFactory::open(const URI& uri)
 					resolvedURI.setUserInfo(username + ":" + password);
 					authorize = false;
 				}
-				delete pSession; 
+				delete pSession;
 				pSession = 0;
 				++redirects;
 				retry = true;
@@ -147,15 +147,15 @@ std::istream* HTTPSStreamFactory::open(const URI& uri)
 			{
 				return new HTTPResponseStream(rs, pSession);
 			}
-			else if (res.getStatus() == HTTPResponse::HTTP_USEPROXY && !retry)
+			else if (res.getStatus() == HTTPResponse::HTTP_USE_PROXY && !retry)
 			{
-				// The requested resource MUST be accessed through the proxy 
-				// given by the Location field. The Location field gives the 
-				// URI of the proxy. The recipient is expected to repeat this 
+				// The requested resource MUST be accessed through the proxy
+				// given by the Location field. The Location field gives the
+				// URI of the proxy. The recipient is expected to repeat this
 				// single request via the proxy. 305 responses MUST only be generated by origin servers.
 				// only use for one single request!
 				proxyUri.resolve(res.get("Location"));
-				delete pSession; 
+				delete pSession;
 				pSession = 0;
 				retry = true; // only allow useproxy once
 			}
