@@ -22,10 +22,7 @@
 #include "Poco/Net/SecureStreamSocketImpl.h"
 #include "Poco/Net/StreamSocketImpl.h"
 #include "Poco/Net/StreamSocket.h"
-#include "Poco/Net/NetException.h"
-#include "Poco/Net/DNS.h"
 #include "Poco/NumberFormatter.h"
-#include "Poco/NumberParser.h"
 #include "Poco/Format.h"
 #include <openssl/x509v3.h>
 #include <openssl/err.h>
@@ -38,16 +35,12 @@ using Poco::NumberFormatter;
 using Poco::Timespan;
 
 
-// workaround for C++-incompatible macro
-#define POCO_BIO_set_nbio_accept(b,n) BIO_ctrl(b,BIO_C_SET_ACCEPT,1,(void*)((n)?"a":NULL))
-
-
 namespace Poco {
 namespace Net {
 
 
 SecureSocketImpl::SecureSocketImpl(Poco::AutoPtr<SocketImpl> pSocketImpl, Context::Ptr pContext):
-	_pSSL(0),
+	_pSSL(nullptr),
 	_pSocket(pSocketImpl),
 	_pContext(pContext),
 	_needHandshake(false)
@@ -61,6 +54,7 @@ SecureSocketImpl::~SecureSocketImpl()
 {
 	try
 	{
+		close();
 		reset();
 	}
 	catch (...)
@@ -86,14 +80,16 @@ void SecureSocketImpl::acceptSSL()
 {
 	poco_assert (!_pSSL);
 
-	BIO* pBIO = BIO_new(BIO_s_socket());
+	LockT l(_mutex);
+
+	BIO* pBIO = ::BIO_new(BIO_s_socket());
 	if (!pBIO) throw SSLException("Cannot create BIO object");
 	BIO_set_fd(pBIO, static_cast<int>(_pSocket->sockfd()), BIO_NOCLOSE);
 
-	_pSSL = SSL_new(_pContext->sslContext());
+	_pSSL = ::SSL_new(_pContext->sslContext());
 	if (!_pSSL)
 	{
-		BIO_free(pBIO);
+		::BIO_free(pBIO);
 		throw SSLException("Cannot create SSL object");
 	}
 
@@ -105,15 +101,15 @@ void SecureSocketImpl::acceptSSL()
 	* tickets. */
 	if (1 != SSL_set_num_tickets(_pSSL, 0))
 	{
-		BIO_free(pBIO);
+		::BIO_free(pBIO);
 		throw SSLException("Cannot create SSL object");
 	}
 	//Otherwise we can perform two-way shutdown. Client must call SSL_read() before the final SSL_shutdown().
 #endif
 
-	SSL_set_bio(_pSSL, pBIO, pBIO);
-	SSL_set_accept_state(_pSSL);
-	SSL_set_ex_data(_pSSL, SSLManager::instance().socketIndex(), this);
+	::SSL_set_bio(_pSSL, pBIO, pBIO);
+	::SSL_set_accept_state(_pSSL);
+	::SSL_set_ex_data(_pSSL, SSLManager::instance().socketIndex(), this);
 	_needHandshake = true;
 }
 
@@ -162,18 +158,20 @@ void SecureSocketImpl::connectSSL(bool performHandshake)
 	poco_assert (!_pSSL);
 	poco_assert (_pSocket->initialized());
 
-	BIO* pBIO = BIO_new(BIO_s_socket());
+	LockT l(_mutex);
+
+	::BIO* pBIO = ::BIO_new(BIO_s_socket());
 	if (!pBIO) throw SSLException("Cannot create SSL BIO object");
 	BIO_set_fd(pBIO, static_cast<int>(_pSocket->sockfd()), BIO_NOCLOSE);
 
-	_pSSL = SSL_new(_pContext->sslContext());
+	_pSSL = ::SSL_new(_pContext->sslContext());
 	if (!_pSSL)
 	{
-		BIO_free(pBIO);
+		::BIO_free(pBIO);
 		throw SSLException("Cannot create SSL object");
 	}
-	SSL_set_bio(_pSSL, pBIO, pBIO);
-	SSL_set_ex_data(_pSSL, SSLManager::instance().socketIndex(), this);
+	::SSL_set_bio(_pSSL, pBIO, pBIO);
+	::SSL_set_ex_data(_pSSL, SSLManager::instance().socketIndex(), this);
 
 	if (!_peerHostName.empty())
 	{
@@ -189,27 +187,27 @@ void SecureSocketImpl::connectSSL(bool performHandshake)
 
 	if (_pSession && _pSession->isResumable())
 	{
-		SSL_set_session(_pSSL, _pSession->sslSession());
+		::SSL_set_session(_pSSL, _pSession->sslSession());
 	}
 
 	try
 	{
 		if (performHandshake && _pSocket->getBlocking())
 		{
-			int ret = SSL_connect(_pSSL);
+			int ret = ::SSL_connect(_pSSL);
 			handleError(ret);
 			verifyPeerCertificate();
 		}
 		else
 		{
-			SSL_set_connect_state(_pSSL);
+			::SSL_set_connect_state(_pSSL);
 			_needHandshake = true;
 		}
 	}
 	catch (...)
 	{
-		SSL_free(_pSSL);
-		_pSSL = 0;
+		::SSL_free(_pSSL);
+		_pSSL = nullptr;
 		throw;
 	}
 }
@@ -255,64 +253,39 @@ void SecureSocketImpl::listen(int backlog)
 }
 
 
-void SecureSocketImpl::shutdown()
+int SecureSocketImpl::shutdown()
 {
 	if (_pSSL)
 	{
-        // Don't shut down the socket more than once.
-        int shutdownState = SSL_get_shutdown(_pSSL);
-        bool shutdownSent = (shutdownState & SSL_SENT_SHUTDOWN) == SSL_SENT_SHUTDOWN;
-        if (!shutdownSent)
-        {
-			// A proper clean shutdown would require us to
-			// retry the shutdown if we get a zero return
-			// value, until SSL_shutdown() returns 1.
-			// However, this will lead to problems with
-			// most web browsers, so we just set the shutdown
-			// flag by calling SSL_shutdown() once and be
-			// done with it.
-#if OPENSSL_VERSION_NUMBER >= 0x30000000L
-			int rc = 0;
-			if (!_bidirectShutdown)
-				rc = SSL_shutdown(_pSSL);
-			else
+		UnLockT l(_mutex);
+
+		int shutdownState = ::SSL_get_shutdown(_pSSL);
+		bool shutdownSent = (shutdownState & SSL_SENT_SHUTDOWN) == SSL_SENT_SHUTDOWN;
+		if (!shutdownSent)
+		{
+			int rc = ::SSL_shutdown(_pSSL);
+			if (rc < 0) 
 			{
-				Poco::Timespan recvTimeout = _pSocket->getReceiveTimeout();
-				Poco::Timespan pollTimeout(0, 100000);
-				Poco::Timestamp tsNow;
-				do
-				{
-					rc = SSL_shutdown(_pSSL);
-					if (rc == 1) break;
-					if (rc < 0)
-					{
-						int err = SSL_get_error(_pSSL, rc);
-						if (err == SSL_ERROR_WANT_READ)
-							_pSocket->poll(pollTimeout, Poco::Net::Socket::SELECT_READ);
-						else if (err == SSL_ERROR_WANT_WRITE)
-							_pSocket->poll(pollTimeout, Poco::Net::Socket::SELECT_WRITE);
-						else
-						{
-							int socketError = SocketImpl::lastError();
-							long lastError = ERR_get_error();
-							if ((err == SSL_ERROR_SSL) && (socketError == 0) && (lastError == 0x0A000123))
-								rc = 0;
-							break;
-						}
-					}
-					else _pSocket->poll(pollTimeout, Poco::Net::Socket::SELECT_READ);
-				} while (!tsNow.isElapsed(recvTimeout.totalMicroseconds()));
+				if (SocketImpl::lastError() == POCO_EWOULDBLOCK)
+					rc = SecureStreamSocket::ERR_SSL_WOULD_BLOCK;
+				else
+					rc = handleError(rc);
 			}
-#else
-			int rc = SSL_shutdown(_pSSL);
-#endif
-			if (rc < 0) handleError(rc);
-			if (_pSocket->getBlocking())
+
+			l.unlock();
+
+			if (rc >= 0)
 			{
-				_pSocket->shutdown();
+				_pSocket->shutdownSend();
 			}
+			return rc;
+		}
+		else 
+		{
+			return (shutdownState & SSL_RECEIVED_SHUTDOWN) == SSL_RECEIVED_SHUTDOWN;
 		}
 	}
+	return 1;
 }
 
 
@@ -329,28 +302,15 @@ void SecureSocketImpl::close()
 }
 
 
-void SecureSocketImpl::setBlocking(bool flag)
-{
-	poco_check_ptr (_pSocket);
-
-	_pSocket->setBlocking(flag);
-}
-
-
-bool SecureSocketImpl::getBlocking() const
-{
-	poco_check_ptr (_pSocket);
-
-	return _pSocket->getBlocking();
-}
-
-
 int SecureSocketImpl::sendBytes(const void* buffer, int length, int flags)
 {
 	poco_assert (_pSocket->initialized());
 	poco_check_ptr (_pSSL);
 
 	int rc;
+
+	LockT l(_mutex);
+
 	if (_needHandshake)
 	{
 		rc = completeHandshake();
@@ -361,11 +321,17 @@ int SecureSocketImpl::sendBytes(const void* buffer, int length, int flags)
 		else
 			return rc;
 	}
-	do
+	const auto sendTimeout = _pSocket->getSendTimeout();
+	Poco::Timestamp tsStart;
+	while (true)
 	{
-		rc = SSL_write(_pSSL, buffer, length);
-	}
-	while (mustRetry(rc));
+		rc = ::SSL_write(_pSSL, buffer, length);
+		if (!mustRetry(rc))
+			break;
+
+		if (tsStart.isElapsed(sendTimeout.totalMicroseconds()))
+			throw Poco::TimeoutException();
+	};
 	if (rc <= 0)
 	{
 		rc = handleError(rc);
@@ -381,6 +347,9 @@ int SecureSocketImpl::receiveBytes(void* buffer, int length, int flags)
 	poco_check_ptr (_pSSL);
 
 	int rc;
+
+	LockT l(_mutex);
+
 	if (_needHandshake)
 	{
 		rc = completeHandshake();
@@ -389,12 +358,25 @@ int SecureSocketImpl::receiveBytes(void* buffer, int length, int flags)
 		else
 			return rc;
 	}
-	do
+
+	const auto recvTimeout = _pSocket->getReceiveTimeout();
+	Poco::Timestamp tsStart;
+	while (true)
 	{
-		rc = SSL_read(_pSSL, buffer, length);
-	}
-	while (mustRetry(rc));
-	_bidirectShutdown = false;
+		if (flags & MSG_PEEK)
+		{
+			rc = SSL_peek(_pSSL, buffer, length);
+		}
+		else
+		{
+			rc = SSL_read(_pSSL, buffer, length);
+		}
+		if (!mustRetry(rc))
+			break;
+
+		if (tsStart.isElapsed(recvTimeout.totalMicroseconds()))
+			throw Poco::TimeoutException();
+	};
 	if (rc <= 0)
 	{
 		return handleError(rc);
@@ -407,7 +389,9 @@ int SecureSocketImpl::available() const
 {
 	poco_check_ptr (_pSSL);
 
-	return SSL_pending(_pSSL);
+	LockT l(_mutex);
+
+	return ::SSL_pending(_pSSL);
 }
 
 
@@ -417,11 +401,17 @@ int SecureSocketImpl::completeHandshake()
 	poco_check_ptr (_pSSL);
 
 	int rc;
-	do
+	const auto recvTimeout = _pSocket->getReceiveTimeout();
+	Poco::Timestamp tsStart;
+	while (true)
 	{
-		rc = SSL_do_handshake(_pSSL);
-	}
-	while (mustRetry(rc));
+		rc = ::SSL_do_handshake(_pSSL);
+		if (!mustRetry(rc))
+			break;
+
+		if (tsStart.isElapsed(recvTimeout.totalMicroseconds()))
+			throw Poco::TimeoutException();
+	};
 	if (rc <= 0)
 	{
 		return handleError(rc);
@@ -455,12 +445,12 @@ long SecureSocketImpl::verifyPeerCertificateImpl(const std::string& hostName)
 {
 	Context::VerificationMode mode = _pContext->verificationMode();
 	if (mode == Context::VERIFY_NONE || !_pContext->extendedCertificateVerificationEnabled() ||
-	    (mode != Context::VERIFY_STRICT && isLocalHost(hostName)))
+	   (mode != Context::VERIFY_STRICT && isLocalHost(hostName)))
 	{
 		return X509_V_OK;
 	}
 
-	X509* pCert = SSL_get_peer_certificate(_pSSL);
+	::X509* pCert = ::SSL_get_peer_certificate(_pSSL);
 	if (pCert)
 	{
 		X509Certificate cert(pCert);
@@ -477,7 +467,7 @@ bool SecureSocketImpl::isLocalHost(const std::string& hostName)
 		SocketAddress addr(hostName, 0);
 		return addr.host().isLoopback();
 	}
-	catch (Poco::Exception&)
+	catch (const Poco::Exception&)
 	{
 		return false;
 	}
@@ -486,10 +476,12 @@ bool SecureSocketImpl::isLocalHost(const std::string& hostName)
 
 X509* SecureSocketImpl::peerCertificate() const
 {
+	LockT l(_mutex);
+
 	if (_pSSL)
-		return SSL_get_peer_certificate(_pSSL);
+		return ::SSL_get_peer_certificate(_pSSL);
 	else
-		return 0;
+		return nullptr;
 }
 
 
@@ -497,26 +489,24 @@ bool SecureSocketImpl::mustRetry(int rc)
 {
 	if (rc <= 0)
 	{
-		int sslError = SSL_get_error(_pSSL, rc);
+		static const Poco::Timespan pollTimeout(0, 100000);
+
+		int sslError = ::SSL_get_error(_pSSL, rc);
 		int socketError = _pSocket->lastError();
 		switch (sslError)
 		{
 		case SSL_ERROR_WANT_READ:
 			if (_pSocket->getBlocking())
 			{
-				if (_pSocket->poll(_pSocket->getReceiveTimeout(), Poco::Net::Socket::SELECT_READ))
-					return true;
-				else
-					throw Poco::TimeoutException();
+				_pSocket->poll(pollTimeout, Poco::Net::Socket::SELECT_READ);
+				return true;
 			}
 			break;
 		case SSL_ERROR_WANT_WRITE:
 			if (_pSocket->getBlocking())
 			{
-				if (_pSocket->poll(_pSocket->getSendTimeout(), Poco::Net::Socket::SELECT_WRITE))
-					return true;
-				else
-					throw Poco::TimeoutException();
+				_pSocket->poll(pollTimeout, Poco::Net::Socket::SELECT_WRITE);
+				return true;
 			}
 			break;
 		case SSL_ERROR_SYSCALL:
@@ -533,7 +523,7 @@ int SecureSocketImpl::handleError(int rc)
 {
 	if (rc > 0) return rc;
 
-	int sslError = SSL_get_error(_pSSL, rc);
+	int sslError = ::SSL_get_error(_pSSL, rc);
 	int socketError = SocketImpl::lastError();
 
 	switch (sslError)
@@ -564,17 +554,20 @@ int SecureSocketImpl::handleError(int rc)
 	case SSL_ERROR_SYSCALL:
 		if (socketError)
 		{
-			SocketImpl::error(socketError);
+			if (socketError == POCO_EWOULDBLOCK)
+				return SecureStreamSocket::ERR_SSL_WOULD_BLOCK;
+			else
+				SocketImpl::error(socketError);
 		}
 		// fallthrough
 	default:
 		{
-			long lastError = ERR_get_error();
+		long lastError = ::ERR_get_error();
 			std::string msg;
 			if (lastError)
 			{
 				char buffer[256];
-				ERR_error_string_n(lastError, buffer, sizeof(buffer));
+				::ERR_error_string_n(lastError, buffer, sizeof(buffer));
 				msg = buffer;
 			}
 			// SSL_GET_ERROR(3ossl):
@@ -624,12 +617,13 @@ void SecureSocketImpl::setPeerHostName(const std::string& peerHostName)
 
 void SecureSocketImpl::reset()
 {
-	close();
 	if (_pSSL)
 	{
-		SSL_set_ex_data(_pSSL, SSLManager::instance().socketIndex(), nullptr);
-		SSL_free(_pSSL);
-		_pSSL = 0;
+		LockT l(_mutex);
+
+		::SSL_set_ex_data(_pSSL, SSLManager::instance().socketIndex(), nullptr);
+		::SSL_free(_pSSL);
+		_pSSL = nullptr;
 	}
 }
 
@@ -642,6 +636,14 @@ void SecureSocketImpl::abort()
 
 Session::Ptr SecureSocketImpl::currentSession()
 {
+	if (!_pSession && _pSSL)
+	{
+		SSL_SESSION* pSession = SSL_get1_session(_pSSL);
+		if (pSession)
+		{
+			_pSession = new Session(pSession);
+		}
+	}
 	return _pSession;
 }
 
@@ -655,15 +657,18 @@ void SecureSocketImpl::useSession(Session::Ptr pSession)
 bool SecureSocketImpl::sessionWasReused()
 {
 	if (_pSSL)
-		return SSL_session_reused(_pSSL) != 0;
-	else
-		return false;
+	{
+		LockT l(_mutex);
+		return ::SSL_session_reused(_pSSL) != 0;
+	}
+
+	return false;
 }
 
 
 int SecureSocketImpl::onSessionCreated(SSL* pSSL, SSL_SESSION* pSession)
 {
-	void* pEx = SSL_get_ex_data(pSSL, SSLManager::instance().socketIndex());
+	void* pEx = ::SSL_get_ex_data(pSSL, SSLManager::instance().socketIndex());
 	if (pEx)
 	{
 		SecureSocketImpl* pThis = reinterpret_cast<SecureSocketImpl*>(pEx);
