@@ -269,6 +269,16 @@ Command Command::hvals(const std::string& hash)
 }
 
 
+Command Command::keys(const std::string& pattern)
+{
+	Command cmd("KEYS");
+
+	cmd << pattern;
+
+	return cmd;
+}
+
+
 Command Command::incr(const std::string& key, Int64 by)
 {
 	Command cmd(by == 0 ? "INCR" : "INCRBY");
@@ -479,7 +489,7 @@ Command Command::set(const std::string& key, const std::string& value, bool over
 	cmd << key << value;
 	if (! overwrite) cmd << "NX";
 	if (! create) cmd << "XX";
-	if (expireTime.totalMicroseconds() > 0) cmd << "PX" << expireTime.totalMilliseconds();
+	if (expireTime.totalMicroseconds() > 0) cmd << "PX" << NumberFormatter::format(expireTime.totalMilliseconds());
 
 	return cmd;
 }
@@ -735,4 +745,22 @@ Command Command::discard()
 }
 
 
+Command Command::auth(const std::string& password)
+{
+	Command cmd("AUTH");
+	cmd << password;
+
+	return cmd;
+}
+
+
+Command Command::auth(const std::string& username, const std::string& password)
+{
+	Command cmd("AUTH");
+	cmd << username << password;
+
+	return cmd;
+}
+
+
 } } // namespace Poco::Redis
