@@ -23,6 +23,7 @@
 #include "Poco/RefCountedObject.h"
 #include "Poco/AutoPtr.h"
 #include "Poco/Timestamp.h"
+#include "Poco/Mutex.h"
 
 
 namespace Poco {
@@ -62,6 +63,9 @@ public:
 		///
 		/// Returns 0 if the timer has never been executed.
 
+	void updateLastExecution();
+		/// Updates the last execution of the timer task.
+
 protected:
 	~TimerTask();
 		/// Destroys the TimerTask.
@@ -71,9 +75,8 @@ private:
 	TimerTask& operator = (const TimerTask&);
 
 	Poco::Timestamp _lastExecution;
-	bool _isCancelled;
-
-	friend class TaskNotification;
+	std::atomic<bool> _isCancelled;
+	mutable FastMutex _mutex;
 };
 
 
@@ -114,10 +117,18 @@ inline bool TimerTask::isCancelled() const
 
 inline Poco::Timestamp TimerTask::lastExecution() const
 {
+	FastMutex::ScopedLock l(_mutex);
 	return _lastExecution;
 }
 
 
+inline void TimerTask::updateLastExecution()
+{
+	FastMutex::ScopedLock l(_mutex);
+	_lastExecution.update();
+}
+
+
 } } // namespace Poco::Util
 
 
