@@ -27,6 +27,7 @@
 #include "Poco/Util/Option.h"
 #include "Poco/Util/OptionProcessor.h"
 #include "Poco/Util/Validator.h"
+#include "Poco/Util/OptionException.h"
 #include "Poco/Environment.h"
 #include "Poco/Exception.h"
 #include "Poco/NumberFormatter.h"
@@ -61,6 +62,9 @@ using Poco::AutoPtr;
 using Poco::icompare;
 
 
+using namespace std::string_literals;
+
+
 namespace Poco {
 namespace Util {
 
@@ -72,8 +76,9 @@ Application::Application():
 	_pConfig(new LayeredConfiguration),
 	_initialized(false),
 	_unixOptions(true),
-	_pLogger(&Logger::get("ApplicationStartup")),
-	_stopOptionsProcessing(false)
+	_pLogger(&Logger::get("ApplicationStartup"s)),
+	_stopOptionsProcessing(false),
+	_ignoreUnknownOptions(false)
 {
 	setup();
 }
@@ -83,8 +88,9 @@ Application::Application(int argc, char* argv[]):
 	_pConfig(new LayeredConfiguration),
 	_initialized(false),
 	_unixOptions(true),
-	_pLogger(&Logger::get("ApplicationStartup")),
-	_stopOptionsProcessing(false)
+	_pLogger(&Logger::get("ApplicationStartup"s)),
+	_stopOptionsProcessing(false),
+	_ignoreUnknownOptions(false)
 {
 	setup();
 	init(argc, argv);
@@ -119,7 +125,7 @@ void Application::setup()
 	_pInstance = this;
 
 	AutoPtr<ConsoleChannel> pCC = new ConsoleChannel;
-	Logger::setChannel("", pCC);
+	Logger::setChannel(""s, pCC);
 }
 
 
@@ -164,14 +170,14 @@ void Application::init()
 {
 	Path appPath;
 	getApplicationPath(appPath);
-	_pConfig->setString("application.path", appPath.toString());
-	_pConfig->setString("application.name", appPath.getFileName());
-	_pConfig->setString("application.baseName", appPath.getBaseName());
-	_pConfig->setString("application.dir", appPath.parent().toString());
-	_pConfig->setString("application.configDir", Path::configHome() + appPath.getBaseName() + Path::separator());
-	_pConfig->setString("application.cacheDir", Path::cacheHome() + appPath.getBaseName() + Path::separator());
-	_pConfig->setString("application.tempDir", Path::tempHome() + appPath.getBaseName() + Path::separator());
-	_pConfig->setString("application.dataDir", Path::dataHome() + appPath.getBaseName() + Path::separator());
+	_pConfig->setString("application.path"s, appPath.toString());
+	_pConfig->setString("application.name"s, appPath.getFileName());
+	_pConfig->setString("application.baseName"s, appPath.getBaseName());
+	_pConfig->setString("application.dir"s, appPath.parent().toString());
+	_pConfig->setString("application.configDir"s, Path::configHome() + appPath.getBaseName() + Path::separator());
+	_pConfig->setString("application.cacheDir"s, Path::cacheHome() + appPath.getBaseName() + Path::separator());
+	_pConfig->setString("application.tempDir"s, Path::tempHome() + appPath.getBaseName() + Path::separator());
+	_pConfig->setString("application.dataDir"s, Path::dataHome() + appPath.getBaseName() + Path::separator());
 	processOptions();
 }
 
@@ -186,7 +192,7 @@ void Application::initialize(Application& self)
 {
 	for (auto& pSub: _subsystems)
 	{
-		_pLogger->debug(std::string("Initializing subsystem: ") + pSub->name());
+		_pLogger->debug("Initializing subsystem: "s + pSub->name());
 		pSub->initialize(self);
 	}
 	_initialized = true;
@@ -199,7 +205,7 @@ void Application::uninitialize()
 	{
 		for (SubsystemVec::reverse_iterator it = _subsystems.rbegin(); it != _subsystems.rend(); ++it)
 		{
-			_pLogger->debug(std::string("Uninitializing subsystem: ") + (*it)->name());
+			_pLogger->debug("Uninitializing subsystem: "s + (*it)->name());
 			(*it)->uninitialize();
 		}
 		_initialized = false;
@@ -211,7 +217,7 @@ void Application::reinitialize(Application& self)
 {
 	for (auto& pSub: _subsystems)
 	{
-		_pLogger->debug(std::string("Re-initializing subsystem: ") + pSub->name());
+		_pLogger->debug("Re-initializing subsystem: "s + pSub->name());
 		pSub->reinitialize(self);
 	}
 }
@@ -229,27 +235,27 @@ int Application::loadConfiguration(int priority)
 	Path appPath;
 	getApplicationPath(appPath);
 	Path confPath;
-	if (findAppConfigFile(appPath.getBaseName(), "properties", confPath))
+	if (findAppConfigFile(appPath.getBaseName(), "properties"s, confPath))
 	{
 		_pConfig->add(new PropertyFileConfiguration(confPath.toString()), priority, false);
 		++n;
 	}
 #ifndef POCO_UTIL_NO_INIFILECONFIGURATION
-	if (findAppConfigFile(appPath.getBaseName(), "ini", confPath))
+	if (findAppConfigFile(appPath.getBaseName(), "ini"s, confPath))
 	{
 		_pConfig->add(new IniFileConfiguration(confPath.toString()), priority, false);
 		++n;
 	}
 #endif
 #ifndef POCO_UTIL_NO_JSONCONFIGURATION
-	if (findAppConfigFile(appPath.getBaseName(), "json", confPath))
+	if (findAppConfigFile(appPath.getBaseName(), "json"s, confPath))
 	{
 		_pConfig->add(new JSONConfiguration(confPath.toString()), priority, false);
 		++n;
 	}
 #endif
 #ifndef POCO_UTIL_NO_XMLCONFIGURATION
-	if (findAppConfigFile(appPath.getBaseName(), "xml", confPath))
+	if (findAppConfigFile(appPath.getBaseName(), "xml"s, confPath))
 	{
 		_pConfig->add(new XMLConfiguration(confPath.toString()), priority, false);
 		++n;
@@ -258,9 +264,9 @@ int Application::loadConfiguration(int priority)
 	if (n > 0)
 	{
 		if (!confPath.isAbsolute())
-			_pConfig->setString("application.configDir", confPath.absolute().parent().toString());
+			_pConfig->setString("application.configDir"s, confPath.absolute().parent().toString());
 		else
-			_pConfig->setString("application.configDir", confPath.parent().toString());
+			_pConfig->setString("application.configDir"s, confPath.parent().toString());
 	}
 	return n;
 }
@@ -299,25 +305,25 @@ void Application::loadConfiguration(const std::string& path, int priority)
 #endif
 	else throw Poco::InvalidArgumentException("Unsupported configuration file type", ext);
 
-	if (n > 0 && !_pConfig->has("application.configDir"))
+	if (n > 0 && !_pConfig->has("application.configDir"s))
 	{
 		if (!confPath.isAbsolute())
-			_pConfig->setString("application.configDir", confPath.absolute().parent().toString());
+			_pConfig->setString("application.configDir"s, confPath.absolute().parent().toString());
 		else
-			_pConfig->setString("application.configDir", confPath.parent().toString());
+			_pConfig->setString("application.configDir"s, confPath.parent().toString());
 	}
 }
 
 
 std::string Application::commandName() const
 {
-	return _pConfig->getString("application.baseName");
+	return _pConfig->getString("application.baseName"s);
 }
 
 
 std::string Application::commandPath() const
 {
-	return _pConfig->getString("application.path");
+	return _pConfig->getString("application.path"s);
 }
 
 
@@ -327,6 +333,11 @@ void Application::stopOptionsProcessing()
 }
 
 
+void Application::ignoreUnknownOptions()
+{
+	_ignoreUnknownOptions = true;
+}
+
 Application::WindowSize Application::windowSize()
 {
 	WindowSize size{0, 0};
@@ -371,7 +382,7 @@ int Application::run()
 	}
 	catch (...)
 	{
-		logger().fatal("system exception");
+		logger().fatal("system exception"s);
 	}
 
 	uninitialize();
@@ -388,7 +399,7 @@ int Application::main(const ArgVec& args)
 void Application::setArgs(int argc, char* argv[])
 {
 	_command = argv[0];
-	_pConfig->setInt("application.argc", argc);
+	_pConfig->setInt("application.argc"s, argc);
 	_unprocessedArgs.reserve(argc);
 	std::string argvKey = "application.argv[";
 	for (int i = 0; i < argc; ++i)
@@ -405,7 +416,7 @@ void Application::setArgs(const ArgVec& args)
 	poco_assert (!args.empty());
 
 	_command = args[0];
-	_pConfig->setInt("application.argc", (int) args.size());
+	_pConfig->setInt("application.argc"s, (int) args.size());
 	_unprocessedArgs = args;
 	std::string argvKey = "application.argv[";
 	for (int i = 0; i < args.size(); ++i)
@@ -427,7 +438,21 @@ void Application::processOptions()
 	{
 		std::string name;
 		std::string value;
-		if (processor.process(*it, name, value))
+		bool success = false;
+
+		if (_ignoreUnknownOptions)
+		{
+			try
+			{
+				success = processor.process(*it, name, value);
+			} catch (Poco::Util::UnknownOptionException&) { }
+		}
+		else
+		{
+			success = processor.process(*it, name, value);
+		}
+
+		if (success)
 		{
 			if (!name.empty()) // "--" option to end options processing or deferred argument
 			{
@@ -435,10 +460,15 @@ void Application::processOptions()
 			}
 			it = _unprocessedArgs.erase(it);
 		}
-		else ++it;
+		else
+		{
+			++it;
+		}
 	}
 	if (!_stopOptionsProcessing)
+	{
 		processor.checkRequired();
+	}
 }
 
 
@@ -460,7 +490,7 @@ void Application::getApplicationPath(Poco::Path& appPath) const
 	}
 	else
 	{
-		if (!Path::find(Environment::get("PATH"), _command, appPath))
+		if (!Path::find(Environment::get("PATH"s), _command, appPath))
 			appPath = Path(_workingDirAtLaunch, _command);
 		appPath.makeAbsolute();
 	}
@@ -480,6 +510,14 @@ void Application::getApplicationPath(Poco::Path& appPath) const
 }
 
 
+void Application::getApplicationDirectory(Poco::Path& dir) const
+{
+	Path appPath;
+	getApplicationPath(appPath);
+	dir = appPath.parent();
+}
+
+
 bool Application::findFile(Poco::Path& path) const
 {
 	if (path.isAbsolute()) return true;
@@ -526,29 +564,6 @@ bool Application::findAppConfigFile(const std::string& appName, const std::strin
 }
 
 
-bool Application::findAppConfigFile(const Path& basePath, const std::string& appName, const std::string& extension, Path& path) const
-{
-	poco_assert (!appName.empty());
-
-	Path p(basePath,appName);
-	p.setExtension(extension);
-	bool found = findFile(p);
-	if (!found)
-	{
-#if defined(_DEBUG)
-		if (appName[appName.length() - 1] == 'd')
-		{
-			p.setBaseName(appName.substr(0, appName.length() - 1));
-			found = findFile(p);
-		}
-#endif
-	}
-	if (found)
-		path = p;
-	return found;
-}
-
-
 void Application::defineOptions(OptionSet& options)
 {
 	for (auto& pSub: _subsystems)
