@@ -46,6 +46,7 @@
 using Poco::NumberFormatter;
 using Poco::Exception;
 using Poco::SystemException;
+using namespace std::string_literals;
 
 
 namespace Poco {
@@ -79,7 +80,7 @@ ServerApplication::~ServerApplication()
 
 bool ServerApplication::isInteractive() const
 {
-	bool runsInBackground = config().getBool("application.runAsDaemon", false) || config().getBool("application.runAsService", false);
+	bool runsInBackground = config().getBool("application.runAsDaemon"s, false) || config().getBool("application.runAsService"s, false);
 	return !runsInBackground;
 }
 
@@ -90,8 +91,22 @@ int ServerApplication::run()
 }
 
 
+void ServerApplication::terminateCallback()
+{
+	if (!_terminationGuard.exchange(true))
+	{
+		if (_terminateCallback)
+		{
+			_terminateCallback(_terminateMessage);
+			_terminateCallback = nullptr;
+		}
+	}
+}
+
+
 void ServerApplication::terminate()
 {
+	terminateCallback();
 #if defined(POCO_OS_FAMILY_WINDOWS)
 	_terminate.set();
 #elif defined(POCO_VXWORKS) || POCO_OS == POCO_OS_ANDROID
@@ -102,6 +117,13 @@ void ServerApplication::terminate()
 }
 
 
+void ServerApplication::registerTerminateCallback(TerminateCallback tCB, const std::string& message)
+{
+	_terminateCallback = tCB;
+	_terminateMessage = message;
+}
+
+
 #if defined(POCO_OS_FAMILY_WINDOWS)
 
 
@@ -143,7 +165,7 @@ void ServerApplication::ServiceMain(DWORD argc, LPWSTR* argv)
 {
 	ServerApplication& app = static_cast<ServerApplication&>(Application::instance());
 
-	app.config().setBool("application.runAsService", true);
+	app.config().setBool("application.runAsService"s, true);
 
 	_serviceStatusHandle = RegisterServiceCtrlHandlerW(L"", ServiceControlHandler);
 	if (!_serviceStatusHandle)
@@ -182,7 +204,7 @@ void ServerApplication::ServiceMain(DWORD argc, LPWSTR* argv)
 	}
 	catch (...)
 	{
-		app.logger().error("fatal error - aborting");
+		app.logger().error("fatal error - aborting"s);
 		_serviceStatus.dwWin32ExitCode           = ERROR_SERVICE_SPECIFIC_ERROR;
 		_serviceStatus.dwServiceSpecificExitCode = EXIT_SOFTWARE;
 	}
@@ -195,6 +217,7 @@ void ServerApplication::waitForTerminationRequest()
 {
 	SetConsoleCtrlHandler(ConsoleCtrlHandler, TRUE);
 	_terminate.wait();
+	terminateCallback();
 	_terminated.set();
 }
 
@@ -327,8 +350,8 @@ bool ServerApplication::hasConsole()
 
 void ServerApplication::registerService()
 {
-	std::string name = config().getString("application.baseName");
-	std::string path = Poco::format("\"%s\"", config().getString("application.path"));
+	std::string name = config().getString("application.baseName"s);
+	std::string path = Poco::format("\"%s\""s, config().getString("application.path"s));
 
 	WinService service(name);
 	if (_displayName.empty())
@@ -347,11 +370,11 @@ void ServerApplication::registerService()
 
 void ServerApplication::unregisterService()
 {
-	std::string name = config().getString("application.baseName");
+	std::string name = config().getString("application.baseName"s);
 
 	WinService service(name);
 	service.unregisterService();
-	logger().information("The service has been successfully unregistered.");
+	logger().information("The service has been successfully unregistered."s);
 }
 
 
@@ -360,37 +383,44 @@ void ServerApplication::defineOptions(OptionSet& options)
 	Application::defineOptions(options);
 
 	options.addOption(
-		Option("registerService", "", "Register the application as a service.")
+		Option("registerService"s, ""s, "Register the application as a service."s)
 			.required(false)
 			.repeatable(false)
 			.callback(OptionCallback<ServerApplication>(this, &ServerApplication::handleRegisterService)));
 
 	options.addOption(
-		Option("unregisterService", "", "Unregister the application as a service.")
+		Option("unregisterService"s, ""s, "Unregister the application as a service."s)
 			.required(false)
 			.repeatable(false)
 			.callback(OptionCallback<ServerApplication>(this, &ServerApplication::handleUnregisterService)));
 
 	options.addOption(
-		Option("displayName", "", "Specify a display name for the service (only with /registerService).")
+		Option("displayName"s, ""s, "Specify a display name for the service (only with /registerService)."s)
 			.required(false)
 			.repeatable(false)
-			.argument("name")
+			.argument("name"s)
 			.callback(OptionCallback<ServerApplication>(this, &ServerApplication::handleDisplayName)));
 
 	options.addOption(
-		Option("description", "", "Specify a description for the service (only with /registerService).")
+		Option("description"s, ""s, "Specify a description for the service (only with /registerService)."s)
 			.required(false)
 			.repeatable(false)
-			.argument("text")
+			.argument("text"s)
 			.callback(OptionCallback<ServerApplication>(this, &ServerApplication::handleDescription)));
 
 	options.addOption(
-		Option("startup", "", "Specify the startup mode for the service (only with /registerService).")
+		Option("startup"s, ""s, "Specify the startup mode for the service (only with /registerService)."s)
 			.required(false)
 			.repeatable(false)
-			.argument("automatic|manual")
+			.argument("automatic|manual"s)
 			.callback(OptionCallback<ServerApplication>(this, &ServerApplication::handleStartup)));
+	
+	options.addOption(
+		Option("pidfile"s, ""s, "Write the process ID of the application to given file."s)
+			.required(false)
+			.repeatable(false)
+			.argument("path")
+			.callback(OptionCallback<ServerApplication>(this, &ServerApplication::handlePidFile)));
 }
 
 
@@ -420,9 +450,9 @@ void ServerApplication::handleDescription(const std::string& name, const std::st
 
 void ServerApplication::handleStartup(const std::string& name, const std::string& value)
 {
-	if (Poco::icompare(value, 4, std::string("auto")) == 0)
+	if (Poco::icompare(value, 4, "auto"s) == 0)
 		_startup = "auto";
-	else if (Poco::icompare(value, std::string("manual")) == 0)
+	else if (Poco::icompare(value, "manual"s) == 0)
 		_startup = "manual";
 	else
 		throw InvalidArgumentException("argument to startup option must be 'auto[matic]' or 'manual'");
@@ -436,6 +466,7 @@ void ServerApplication::handleStartup(const std::string& name, const std::string
 void ServerApplication::waitForTerminationRequest()
 {
 	_terminate.wait();
+	terminateCallback();
 }
 
 
@@ -492,11 +523,13 @@ void ServerApplication::waitForTerminationRequest()
 	}
 	sigaddset(&sset, SIGQUIT);
 	sigaddset(&sset, SIGTERM);
-	sigprocmask(SIG_BLOCK, &sset, NULL);
+	sigprocmask(SIG_BLOCK, &sset, nullptr);
 	int sig;
 	sigwait(&sset, &sig);
+	terminateCallback();
 #else // POCO_OS != POCO_OS_ANDROID
 	_terminate.wait();
+	terminateCallback();
 #endif
 }
 
@@ -561,7 +594,7 @@ int ServerApplication::run(const std::vector<std::string>& args)
 
 bool ServerApplication::isDaemon(int argc, char** argv)
 {
-	std::string option("--daemon");
+	std::string option("--daemon"s);
 	for (int i = 1; i < argc; ++i)
 	{
 		if (option == argv[i])
@@ -604,20 +637,20 @@ void ServerApplication::defineOptions(OptionSet& options)
 	Application::defineOptions(options);
 
 	options.addOption(
-		Option("daemon", "", "Run application as a daemon.")
+		Option("daemon"s, ""s, "Run application as a daemon."s)
 			.required(false)
 			.repeatable(false)
 			.callback(OptionCallback<ServerApplication>(this, &ServerApplication::handleDaemon)));
 
 	options.addOption(
-		Option("umask", "", "Set the daemon's umask (octal, e.g. 027).")
+		Option("umask"s, ""s, "Set the daemon's umask (octal, e.g. 027)."s)
 			.required(false)
 			.repeatable(false)
 			.argument("mask")
 			.callback(OptionCallback<ServerApplication>(this, &ServerApplication::handleUMask)));
 
 	options.addOption(
-		Option("pidfile", "", "Write the process ID of the application to given file.")
+		Option("pidfile"s, ""s, "Write the process ID of the application to given file."s)
 			.required(false)
 			.repeatable(false)
 			.argument("path")
@@ -627,7 +660,7 @@ void ServerApplication::defineOptions(OptionSet& options)
 
 void ServerApplication::handleDaemon(const std::string& name, const std::string& value)
 {
-	config().setBool("application.runAsDaemon", true);
+	config().setBool("application.runAsDaemon"s, true);
 }
 
 
