@@ -33,6 +33,7 @@
 
 using Poco::Environment;
 using Poco::Path;
+using namespace std::string_literals;
 
 
 namespace Poco {
@@ -170,28 +171,28 @@ void SystemConfiguration::enumerate(const std::string& key, Keys& range) const
 {
 	if (key.empty())
 	{
-		range.push_back("system");
+		range.push_back("system"s);
 	}
 	else if (key == "system")
 	{
-		range.push_back("osName");
-		range.push_back("osVersion");
-		range.push_back("osArchitecture");
-		range.push_back("nodeName");
-		range.push_back("nodeId");
-		range.push_back("currentDir");
-		range.push_back("homeDir");
-		range.push_back("configHomeDir");
-		range.push_back("cacheHomeDir");
-		range.push_back("dataHomeDir");
-		range.push_back("tempHomeDir");
-		range.push_back("tempDir");
-		range.push_back("configDir");
-		range.push_back("dateTime");
+		range.push_back("osName"s);
+		range.push_back("osVersion"s);
+		range.push_back("osArchitecture"s);
+		range.push_back("nodeName"s);
+		range.push_back("nodeId"s);
+		range.push_back("currentDir"s);
+		range.push_back("homeDir"s);
+		range.push_back("configHomeDir"s);
+		range.push_back("cacheHomeDir"s);
+		range.push_back("dataHomeDir"s);
+		range.push_back("tempHomeDir"s);
+		range.push_back("tempDir"s);
+		range.push_back("configDir"s);
+		range.push_back("dateTime"s);
 #if !defined(POCO_VXWORKS)
-		range.push_back("pid");
+		range.push_back("pid"s);
 #endif
-		range.push_back("env");
+		range.push_back("env"s);
 	}
 }
 
