@@ -96,8 +96,10 @@ void IniFileConfigurationTest::testLoad()
 	}
 	catch (Poco::IOException& exc)
 	{
+#ifndef POCO_ENABLE_TRACE
 		std::string s(exc.message());
 		assertTrue (s == "Broken input stream");
+#endif
 	}
 }
 
