@@ -21,6 +21,9 @@
 #include <sstream>
 
 
+using namespace std::string_literals;
+
+
 namespace Poco {
 namespace XML {
 
@@ -61,7 +64,7 @@ XMLWriter::XMLWriter(XMLByteOutputStream& str, int options):
 	_pInEncoding(new NATIVE_ENCODING),
 	_pOutEncoding(new Poco::UTF8Encoding),
 	_options(options),
-	_encoding("UTF-8"),
+	_encoding("UTF-8"s),
 	_depth(-1),
 	_elementCount(0),
 	_inFragment(false),
@@ -302,7 +305,7 @@ void XMLWriter::emptyElement(const XMLString& namespaceURI, const XMLString& loc
 	else
 		writeStartElement(namespaceURI, localName, qname, attributes);
 	_contentWritten = false;
-	writeMarkup("/");
+	writeMarkup("/"s);
 	closeStartTag();
 	_namespaces.popContext();
 }
@@ -368,14 +371,14 @@ void XMLWriter::processingInstruction(const XMLString& target, const XMLString&
 {
 	if (_unclosedStartTag) closeStartTag();
 	prettyPrint();
-	writeMarkup("<?");
+	writeMarkup("<?"s);
 	writeXML(target);
 	if (!data.empty())
 	{
 		writeMarkup(MARKUP_SPACE);
 		writeXML(data);
 	}
-	writeMarkup("?>");
+	writeMarkup("?>"s);
 	if (_depth == 0)
 		writeNewLine();
 }
@@ -383,7 +386,7 @@ void XMLWriter::processingInstruction(const XMLString& target, const XMLString&
 
 namespace
 {
-	static const XMLString CDATA = toXMLString("CDATA");
+	static const XMLString CDATA = toXMLString("CDATA"s);
 }
 
 
@@ -456,32 +459,32 @@ void XMLWriter::comment(const XMLChar ch[], int start, int length)
 {
 	if (_unclosedStartTag) closeStartTag();
 	prettyPrint();
-	writeMarkup("<!--");
+	writeMarkup("<!--"s);
 	while (length-- > 0) writeXML(ch[start++]);
-	writeMarkup("-->");
+	writeMarkup("-->"s);
 	_contentWritten = false;
 }
 
 
 void XMLWriter::startDTD(const XMLString& name, const XMLString& publicId, const XMLString& systemId)
 {
-	writeMarkup("<!DOCTYPE ");
+	writeMarkup("<!DOCTYPE "s);
 	writeXML(name);
 	if (!publicId.empty())
 	{
-		writeMarkup(" PUBLIC \"");
+		writeMarkup(" PUBLIC \""s);
 		writeXML(publicId);
-		writeMarkup("\"");
+		writeMarkup("\""s);
 	}
 	if (!systemId.empty())
 	{
 		if (publicId.empty())
 		{
-			writeMarkup(" SYSTEM");
+			writeMarkup(" SYSTEM"s);
 		}
-		writeMarkup(" \"");
+		writeMarkup(" \""s);
 		writeXML(systemId);
-		writeMarkup("\"");
+		writeMarkup("\""s);
 	}
 	_inDTD = true;
 }
@@ -493,10 +496,10 @@ void XMLWriter::endDTD()
 	if (_inInternalDTD)
 	{
 		writeNewLine();
-		writeMarkup("]");
+		writeMarkup("]"s);
 		_inInternalDTD = false;
 	}
-	writeMarkup(">");
+	writeMarkup(">"s);
 	writeNewLine();
 	_inDTD = false;
 }
@@ -517,7 +520,7 @@ void XMLWriter::notationDecl(const XMLString& name, const XMLString* publicId, c
 	if (!_inDTD) throw XMLException("Notation declaration not within DTD");
 	if (!_inInternalDTD)
 	{
-		writeMarkup(" [");
+		writeMarkup(" ["s);
 		_inInternalDTD = true;
 	}
 	if (_options & PRETTY_PRINT)
@@ -525,21 +528,21 @@ void XMLWriter::notationDecl(const XMLString& name, const XMLString* publicId, c
 		writeNewLine();
 		writeMarkup(_indent);
 	}
-	writeMarkup("<!NOTATION ");
+	writeMarkup("<!NOTATION "s);
 	writeXML(name);
 	if (systemId && !systemId->empty())
 	{
-		writeMarkup(" SYSTEM \"");
+		writeMarkup(" SYSTEM \""s);
 		writeXML(*systemId);
-		writeMarkup("\"");
+		writeMarkup("\""s);
 	}
 	if (publicId && !publicId->empty())
 	{
-		writeMarkup(" PUBLIC \"");
+		writeMarkup(" PUBLIC \""s);
 		writeXML(*publicId);
-		writeMarkup("\"");
+		writeMarkup("\""s);
 	}
-	writeMarkup(">");
+	writeMarkup(">"s);
 }
 
 
@@ -548,7 +551,7 @@ void XMLWriter::unparsedEntityDecl(const XMLString& name, const XMLString* publi
 	if (!_inDTD) throw XMLException("Entity declaration not within DTD");
 	if (!_inInternalDTD)
 	{
-		writeMarkup(" [");
+		writeMarkup(" ["s);
 		_inInternalDTD = true;
 	}
 	if (_options & PRETTY_PRINT)
@@ -556,26 +559,26 @@ void XMLWriter::unparsedEntityDecl(const XMLString& name, const XMLString* publi
 		writeNewLine();
 		writeMarkup(_indent);
 	}
-	writeMarkup("<!ENTITY ");
+	writeMarkup("<!ENTITY "s);
 	writeXML(name);
 	if (!systemId.empty())
 	{
-		writeMarkup(" SYSTEM \"");
+		writeMarkup(" SYSTEM \""s);
 		writeXML(systemId);
-		writeMarkup("\"");
+		writeMarkup("\""s);
 	}
 	if (publicId && !publicId->empty())
 	{
-		writeMarkup(" PUBLIC \"");
+		writeMarkup(" PUBLIC \""s);
 		writeXML(*publicId);
-		writeMarkup("\"");
+		writeMarkup("\""s);
 	}
 	if (!notationName.empty())
 	{
-		writeMarkup(" NDATA ");
+		writeMarkup(" NDATA "s);
 		writeXML(notationName);
 	}
-	writeMarkup(">");
+	writeMarkup(">"s);
 }
 
 
@@ -1029,14 +1032,14 @@ void XMLWriter::writeIndent(int depth) const
 
 void XMLWriter::writeXMLDeclaration()
 {
-	writeMarkup("<?xml version=\"1.0\"");
+	writeMarkup("<?xml version=\"1.0\""s);
 	if (!_encoding.empty())
 	{
-		writeMarkup(" encoding=\"");
+		writeMarkup(" encoding=\""s);
 		writeMarkup(_encoding);
-		writeMarkup("\"");
+		writeMarkup("\""s);
 	}
-	writeMarkup("?>");
+	writeMarkup("?>"s);
 	writeNewLine();
 }
 
